use Time::Local;
use Archive::Tar;
use Tie::File;
use File::Path;
use File::stat;
use File::Copy;
use IO::Handle;

use strict;


sub listFiles {
   my ($destDir, $ext) = @_;
   my @files;

   opendir(DIR, $destDir) or die "Failed to open dir $destDir $!";
   @files = grep(/\.$ext$/,readdir(DIR));
   close(DIR);
   
   return @files;
}

sub getNumLines {
   my ($file) = @_;
   my $numLines;

   # open file and loop till last line is reached
   open(FH, $file) or die "Failed to open file: $file $!";
   while (<FH>) {};
   $numLines = $.;
   close(FH);

   return $numLines;
}

sub getFileSize {
   my ($file) = @_;

   my ($st)  = stat($file) or die "No $file: $!";

   return $st->size;
}


sub extractFile {
   my ($srcFile, $desFile) = @_;

   system("vmware-winutil.exe", "decompress", "\"$srcFile\"", "\"$desFile\"");
   if ($? != 0) {
      print "An error occurred while executing vmware-winutil.exe <decompress>\n";
      exit 1;
   }
}

sub copyFile {
   my ($srcFile, $desFile) = @_;

   system("copy", "\"$srcFile\"", "\"$desFile\"");
   if ($? != 0) {
      print "An error occurred while copying $srcFile -> $desFile\n";
      exit 1;
   }
}


my $srmLogsDir;
my $numLogs;
my $latestLog = "";
my @logFileList;


if (($#ARGV + 1) < 1) {
   print "Usage: srmcert-tag.pl <test-id>\n";
   exit 1;
}

my $testID = $ARGV[0];

my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
my $scratchDir = "srm-mantestlog-id_$testID" . "-$mon" . "_" . $mday . "_" . (1900 + $year) 
                  . "-$hour" . "_" . $min . "_" . $sec;

# prepare the scratch dir
if (-d $scratchDir) {
   print "Delete scratch directory $scratchDir (y/n)?";
   my $key = lc(<STDIN>);
   chomp($key);
   if ($key eq "y") {
     rmtree($scratchDir, 1, 1) or die "Could not delete $scratchDir\n";
   } else {
      exit 1;
   }
}
mkdir $scratchDir or die "Could not create directory \"$scratchDir\": $!\n";


$srmLogsDir = `vmware-winutil.exe print-srm-logspath`;
if ($srmLogsDir eq "") {
   print "Failed to locate SRM Logs directory\n";
   exit 1;
}

# Get the list of .log files from the srm logs dir.
@logFileList = &listFiles($srmLogsDir, "log");

my $logFile;

$numLogs = $#logFileList + 1;
if ($numLogs <= 0) {
   print "Did not find any SRM logs in $srmLogsDir\n";
   exit 1;
}

my $fileNum = -1;

foreach $logFile (@logFileList) {
   if ($logFile =~ m/(\d+)/) {
      if ($1 > $fileNum) {
         $fileNum = $1;
         $latestLog = $logFile;
      }
   }
}

my $numLines = &getNumLines("$srmLogsDir\\$latestLog");
my $latestLogFileSize = &getFileSize("$srmLogsDir\\$latestLog");

my $tmpLogNamesFile = "$scratchDir\\" . "tmp-logs.txt";
print "\nType \"srmcert-tag.pl $testID end\" or 'q' and 'return' when the manual test is complete\n";

system("vmware-winutil.exe watch-dir \"$srmLogsDir\" \"srmcert-tag.pl $testID end,q\"  > $tmpLogNamesFile");
if ($? != 0) {
   print "An error occurred while executing vmware-winutil.exe\n";
   exit 1;
}

# remove all elements from array list for creating a new list
delete @logFileList[0 .. $#logFileList];

# Add the latest log that was being written to
push(@logFileList, "$latestLog");

open (TMPFH, "< $tmpLogNamesFile") or die "Could not open file $tmpLogNamesFile: $!\n";
while(<TMPFH>) {
   chomp($_);
   push(@logFileList, $_);
}
close(TMPFH);


# Copy/Extract the dr logs to the scratch directory
# SRM zips the old logs except the most recent one and hence an unzip is
# required.
foreach $logFile (@logFileList) {
   print "Analyzing $logFile\n";
   if (-e "$srmLogsDir\\$logFile.gz") {
      print "Extracting file $logFile.gz\n";
      &extractFile("$srmLogsDir\\$logFile.gz", "$scratchDir\\$logFile");
   } else {
      print "Copying file $logFile -> $scratchDir\\$logFile\n";
      &copyFile("$srmLogsDir\\$logFile", "$scratchDir\\$logFile");
   }
}

# trucate all the unrelated logs from the initial latest log file
open(TMPFH1, "<$scratchDir\\$latestLog") or die "Failed to open $scratchDir\\$latestLog: $!\n";
open(TMPFH2, ">$scratchDir\\$latestLog.copy") or die "Failed to open $scratchDir\\$latestLog.copy: $!\n";

binmode TMPFH1; 
binmode TMPFH2; 

my ($data, $bytesRead);
seek(TMPFH1, $latestLogFileSize, 0); 
while (($bytesRead = read TMPFH1, $data, 131072) != 0) {
   print TMPFH2 $data;  
}
close(TMPFH1); 
close(TMPFH2); 

move("$scratchDir\\$latestLog.copy", "$scratchDir\\$latestLog") or die "Move failed for file $scratchDir\\$latestLog.copy: $!";

# Now create an archive of all the log files for this testID
my $tarZipFile = Archive::Tar->new();
foreach $logFile (@logFileList) {
   print "Archiving file \"$logFile\"\n";
   $tarZipFile->add_files("$scratchDir\\$logFile");
}
$tarZipFile->write("$scratchDir.tgz", 5);

rmtree($scratchDir, 1, 1);

print "\n\n**Done collecting manual test (id:$testID) logs to \"$scratchDir.tgz\"**\n";

