import os
import sys
import logging
import warnings
from logging.handlers import RotatingFileHandler

warnings.simplefilter("ignore", DeprecationWarning)

from lxml import etree

from srm.command import SRMCommand, SRMTestFailoverCommand, SRMFailoverCommand
from srm.response import SRMDiscoverArrays, SRMDiscoverLuns, generate_basic_response, SRMTestFailover, SRMFailover
from srm.response import RETURN_COMMAND_ERROR, RETURN_CONNECTION_ERROR, RETURN_AUTHENTICATION_ERROR, RETURN_UNKNOWN_ERROR
from srm.exceptions import IncorrectCredentials, UnableToConnect, SRMCommandError, SRMError

def set_logging_level(logger, srm_logging_level):
  """
  Translate srm logging level to 'logging' module logging level
  """
  logging.info("Setting log level to '%s'" % srm_logging_level)
  logging_level = logging.DEBUG
  if srm_logging_level == "Info":
    logging_level = logging.INFO
  if srm_logging_level == "Quiet":
    logging_level = logging.ERROR
  if srm_logging_level == "Verbose":
    logging_level = logging.DEBUG
  if srm_logging_level == "Trivia":
    logging_level = logging.DEBUG
  logger.setLevel(logging_level)
    

# Handle logging
logger = logging.getLogger()
logger.setLevel(logging.DEBUG)
console = logging.StreamHandler()
console.setLevel(logging.DEBUG)
formatter = logging.Formatter('%(asctime)-10s: %(levelname)-8s %(message)s')
console.setFormatter(formatter)
logger.addHandler(console)


xml_text = ''.join(sys.stdin.readlines())
xml_response, error_returncode = generate_basic_response()
srm_command = None
try:
  srm_command = SRMCommand.from_xml_string(xml_text)
  set_logging_level(logger, srm_command.log_level)
  if srm_command.name == "discoverArrays":
    srm_response = SRMDiscoverArrays(srm_command)
  elif srm_command.name == "discoverLuns":
    srm_response = SRMDiscoverLuns(srm_command)
  elif srm_command.name == "testFailover":
    srm_test_failover_command = SRMTestFailoverCommand.from_command(srm_command)
    srm_response = SRMTestFailover(srm_test_failover_command)
    srm_response.failover()
  elif srm_command.name == "failover":
    srm_failover_command = SRMFailoverCommand.from_command(srm_command)
    srm_response = SRMFailover(srm_failover_command)
    srm_response.failover()
  else:
    raise SRMCommandError(srm_command, "No such command name: " + srm_command.name)
  xml_response = srm_response.as_xml()
except SRMCommandError, e:
  logging.error("Command error: " + str(e))
  error_returncode.text = RETURN_COMMAND_ERROR
except UnableToConnect, e:
  logging.error("Connection error: " + str(e))
  error_returncode.text = RETURN_CONNECTION_ERROR
except IncorrectCredentials, e:
  logging.error("Invalid authentication: " + str(e))
  error_returncode.text = RETURN_AUTHENTICATION_ERROR 
except SRMError, e:
  logging.error("Unknown error: " + str(e))
  error_returncode.text = RETURN_UNKNOWN_ERROR 
response_xml_text = etree.tostring(xml_response, pretty_print=True)
if srm_command is not None:
  logging.info("Writing response to file '%s'" % srm_command.output_filename)
  output = file(srm_command.output_filename, "w")
  output.write(response_xml_text)
  output.close()
