import sys
import os

from xiv.pyutils import renumerate

class Canvas(object):
    def __init__(self, file = sys.stdout, maxLineLength=None):
        super(Canvas, self).__init__()
        self.file = file
        self._maxLineLength = maxLineLength
        self._written = []
    @property
    def dirty(self):
        return bool(self._written)
    def _write(self, data):
        self._written[-1] += len(data)
        self.file.write(data)
    def _flush(self):
        self.file.flush()
    def _beginLine(self):
        pass
    def _endLine(self):
        self.file.write("\n")
        self._written.append(0)

    def _isNewLine(self):
        return (not self._written) or self._written[-1] == 0
    def _isNewCanvas(self):
        return not self._written    
    def write(self, data):
        lines = data.split("\n")
        if not self._written:
            self._written = [0]
        for index, line in enumerate(lines):
            if self._isNewLine():
                self._beginLine()
            self._write(line)
            if index != len(lines) -1:
                self._endLine()
        self._flush()
    def wipe(self):        
        for index, line_length in renumerate(self._written):
            if self._maxLineLength is not None:
                line_length = self._maxLineLength
                assert line_length
            self.file.write("\r")
            self.file.write(" " * self._maxLineLength)
            self.file.write("\r")
            self.file.flush()
            if index != 0:
                os.system("tput cuu1")
                #self.file.write("\x08")
        self._written = []
    def __enter__(self):
        pass
    def __exit__(self, *unused):
        self.wipe()
    
        
            
    
