class Dummy(object):
    """
    simple class to implement stupid placeholder classes
    """
    def __init__(self, repr="<DUMMY>", str=None):
        super(Dummy, self).__init__()
        self.repr = repr
        self.str = str or repr
    def __str__(self):
        return self.str
    def __repr__(self):
        return self.repr

class SpecialValue(Dummy):
    _instances = {}
    def __init__(self, identifier):
        super(SpecialValue, self).__init__(identifier, identifier)
    def __new__(cls, identifier):
        if identifier not in cls._instances:
            cls._instances[identifier] = super(SpecialValue, cls).__new__(cls, identifier)
        return cls._instances[identifier]
        
#NOTHING is a special object which enables us to distinguish nothingness from
#None, which is sometimes a legal value...
NOTHING = SpecialValue('<NOTHING>')
#AUTOGENERATE is used to let tlib know we would like it to auto-generate a value for us
AUTOGENERATE = SpecialValue('<AUTOGENERATE>')
OMIT = SpecialValue('<OMIT>')

class _NO_OP(object):
    def __init__(self, *extra_func_names):
        for f in extra_func_names:
            setattr(self, f, self._empty_func)
    def __enter__(self):
        return self
    def _empty_func(self, *args, **kwargs):
        pass
    def __call__(self, *args, **kwargs):
        pass
    def __exit__(self, *args, **kwargs):
        pass

no_op = PASS = _NO_OP()

class FunctionList(list):
    def append(self, obj):
        super(FunctionList, self).append(obj)
        return obj
    contains = append
    def getNames(self):
        return [func.__name__ for func in self]

class FilterableList(list):
    """
    >>> from object_specs import ObjectSpecification
    >>> from xiv.dtypes import Bunch
    >>> OBJ = ObjectSpecification()
    >>> lst = FilterableList(Bunch(index=i) for i in range(4))
    >>> lst
    [Bunch(index=0), Bunch(index=1), Bunch(index=2), Bunch(index=3)]
    >>> lst[OBJ.index == 2]
    [Bunch(index=2)]
    """
    def __getitem__(self, item):
        import predicates
        if isinstance(item, predicates.Predicate):
            return [obj for obj in self if item.applies(obj)]
        else:
            return super(FilterableList, self).__getitem__(item)

class cistr(str):
    """
    Case-insensitive string

    >>> cistr("aBC") == cistr("AbC")
    True
    >>> cistr("rrr") == 2
    False
    >>> cistr("rrr") != 2
    True
    >>> cistr("rrr") == "rrr"
    True
    """
    def __eq__(self, other):
        if not isinstance(other, basestring):
            return False
        return self.lower() == other.lower()
    def __cmp__(self, other):
        if not isinstance(other, basestring):
            return -1
        return cmp(self.lower(),  other.lower())

class CustomOrderDict(dict):
    def __init__(self, *args, **kwargs):
        super(CustomOrderDict, self).__init__(*args, **kwargs)
        self._keys = super(CustomOrderDict, self).keys()
    def __new__(cls, *args, **kwargs):
        returned = dict.__new__(cls, *args, **kwargs)
        returned._keys = []
        return returned
    def _addKey(self, key):
        self._keys.append(key)
    def __setitem__(self, key, value):
        super(CustomOrderDict, self).__setitem__(key, value)
        self._addKey(key)
    def __getstate__(self):
        return dict(items=self.items(), order=self._keys)
    def __setstate__(self, state):
        self._keys = []
        self.update(state['items'])
        self._keys = state['order']
    def clear(self):
        super(CustomOrderDict, self).clear()
        self._keys = []
    def pop(self, item, *args, **kwargs):
        returned = super(CustomOrderDict, self).pop(item, *args, **kwargs)
        for index, key in enumerate(self._keys):
            if item == key:
                self._keys.pop(index)
                break
        return returned
    def __delitem__(self, item):
        super(CustomOrderDict, self).__delitem__(item)
        self._keys.remove(item)
    def iteritems(self):
        for key in self._keys:
            yield key, self[key]
    def items(self):
        return list(self.iteritems())
    def iterkeys(self):
        return iter(self._keys)
    def keys(self):
        return list(self.iterkeys())
    def itervalues(self):
        for key in self._keys:
            yield self[key]
    def values(self):
        return list(self.itervalues())
    def update(self, x, **kwargs):
        if isinstance(x, dict):
            x = x.iteritems()
            super(CustomOrderDict, self).update(x)
        else:
            for k, v in x:
                self[k] = v
        if kwargs:
            self.update(kwargs)

class SortedDict(CustomOrderDict):
    def __init__(self, *args, **kwargs):
        super(SortedDict, self).__init__(*args, **kwargs)
        self._keys.sort()
    def _addKey(self, key):
        index = -1
        for index, value in enumerate(self._keys):
            if value > key:
                break
        self._keys.insert(index + 1, key)
class OrderedDict(CustomOrderDict):
    pass

if __name__ == "__main__":
    import doctest
    doctest.testmod()
