"""A centerlized logger for all python packages:
This package contains two main methods:
1. A 'log' function that allows any module or package from the
   shared 'xiv' package to write a log.
2. A 'register' function that allows anyone who wants to receive
   logs from the 'xiv' package to register a callback function,
   that will be called with the log lines being written, each
   time a log is written.

This is useful when an application like tlib wants a simple way to
get the debug logs of internal python packages, without performing
surgical operations like overriding a class attribute (which may
break when the dude who implemented the package changes something
one day).
"""

# XXX keep the callbacks as weakrefs.
trace_callbacks = []
debug_callbacks = []
info_callbacks  = []
warn_callbacks  = []
error_callbacks = []

def register_trace(callback):
    global trace_callbacks
    trace_callbacks.append(callback)

def register_debug(callback):
    global debug_callbacks
    debug_callbacks.append(callback)

def register_info(callback):
    global info_callbacks
    info_callbacks.append(callback)

def register_warn(callback):
    global warn_callbask
    warn_callbacks.append(callback)

def register_error(callback):
    global error_callbacks
    error_callbacks.append(callback)

def register(callback):
    for func in (register_trace, register_debug, register_info, register_warn, register_error):
        func(callback)
    
def write_all_to_stderr():
    import sys

    def write_to_stderr(string, *args):
        sys.stderr.write(string % args)
        sys.stderr.write('\n')
        sys.stderr.flush()

    register(write_to_stderr)

def _call(callbacks, string, *args, **kwargs):
    for callback in callbacks:
        callback(string, *args)

def trace(string, *args, **kwargs):
    global trace_callbacks
    _call(trace_callbacks, string, *args, **kwargs)

def debug(string, *args, **kwargs):
    global debug_callbacks
    _call(debug_callbacks, string, *args, **kwargs)

def info(string, *args, **kwargs):
    global info_callbacks
    _call(info_callbacks, string, *args, **kwargs)

def warn(string, *args, **kwargs):
    global warn_callbacks
    _call(warn_callbacks, string, *args, **kwargs)

def error(string, *args, **kwargs):
    global error_callbacks
    _call(error_callbacks, string, *args, **kwargs)
