from xiv.network import command_runner
from xiv.network import fileutils
from xiv.osutils import sudo
from xiv         import logger

import Rpyc
from Rpyc import PipeConnection, SocketConnection
from Rpyc.Servers import std_server
from Rpyc.NetProxy import _get_conn as getConnection

import inspect
import os, sys, signal, itertools

MIN_RPYC_VERSION = (2, 60)

if Rpyc.__version__ < MIN_RPYC_VERSION:
    raise ImportError("Rpyc is too old (version %s). Expected at least %s" % (".".join(Rpyc.__version),
                                                                              ".".join(MIN_RPYC_VERSION)))

def deploy(chain):
    logger.debug("Deploying RPyC over %s", chain)
    path = '' # tlib_package.deploy(chain)
    fileutils.chainCopyFile(chain, std_server.__file__, "/tmp/std_server.py")
    runner = chain.getCommandRunner()
    p = runner.executePopen("PYTHONPATH=%s:%s/Rpyc/Servers python /tmp/std_server.py " % (path, path))
    p.stderr.close()
    return PipeConnection(p.stdout, p.stdin)

def rpyc_to(host, emptyPath = False, extra_paths=(), interactive=False, use_sudo=False):
    c = command_runner.RemoteCommandRunner(host)
    chain = command_runner.CommandRunnerChain(host)
    if emptyPath:
        path = ""
    else:
        path = ":".join(map(os.path.abspath, sys.path + list(extra_paths)))
    srv_code = """
    import socket, sys, os
    from Rpyc.Utils.Serving import serve_socket
    
    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    s.bind(('', 0))
    s.listen(1)
    print >> sys.stderr, s.getsockname()[1]
    sys.stderr.flush()
    x = file('/tmp/rpyc.stderr', 'ab')
    os.dup2(x.fileno(), sys.stderr.fileno())
    serve_socket(s.accept()[0])
    """
    if interactive:
        port = int(raw_input("Please enter port for RPYC server on %s:" % host))
    else:
        p = c.executePopen('cd /tmp; ulimit -c unlimited; PYTHONPATH=$PYTHONPATH:%s %spython -c "%s" >> /tmp/rpyc.log'
                           % (path, use_sudo and "sudo " or "", ';'.join(x.strip() for x in srv_code.splitlines() if x.strip())))
        port_line = p.stderr.readline()
        p.stdout.close()
        p.stdin.close()
        p.stderr.close()
        #this is only the ssh process...
        sudo.kill(p.pid, signal.SIGKILL)
        port = int(port_line.strip())
    return SocketConnection(host, port)

def terminate_connection(connection):
    logger.debug("terminatine rpyc connection")
    try:
        connection.modules.sys.exit()
    except:
        pass
