"""
surp: 
    Simple URL-based RPC

client usage:
    api = surp.Root("http://myserver/surp")
    print api.myfunc(1, 2, 3) # will invoke http://myserver/surp/myfunc

server usage:
    def myfunc(a, b, c):
        return a + b + c
    
    handlers = {}
    handlers["myfunc"] = myfunc
    
    def get_page(request, funcname):
        'a function that is called by the HTTP server to get a page 
        named ``funcname``'
        dispatch(handlers, funcname, request.raw_post_data)

"""
import sys
import traceback
import cPickle as pickle
import urllib2


class RemoteError(Exception):
    def __init__(self, remotetb):
        self.remotetb = remotetb
    def __str__(self):
        return "\n---------- Remote Traceback ----------\n" + self.remotetb


def request(url, args = (), kwargs = {}):
    """client side: make a request to server, return result (or exception).
    if an exception is raised by the server, it will be wrapped by a 
    RemoteError instance, holding the server's traceback"""
    data = pickle.dumps((args, kwargs))
    f = urllib2.urlopen(url, data)
    data2 = f.read()
    f.close()
    isexc, obj = pickle.loads(data2)
    if isexc:
        raise RemoteError(obj)
    else:
        return obj


def dispatch(namespace, funcname, data):
    """server side: dispatch a request, return result to caller"""
    try:
        isexc = False
        func = namespace[funcname] 
        args, kwargs = pickle.loads(data)
        res = func(*args, **kwargs)
    except:
        isexc = True
        res = "".join(traceback.format_exception(*sys.exc_info())[1:])
    return pickle.dumps((isexc, res))


class Root(object):
    """client side: a root namespace for surp-exposed functions"""
    def __init__(self, url):
        if not url.endswith("/"):
            url += "/"
        self._url = url
    def __getattr__(self, name):
        url = self._url + name + "/"
        def wrapper(*args, **kwargs):
            return request(url, args, kwargs)
        wrapper.__name__ = url
        return wrapper













