import os

############################# time functions ###################################
def ctime_with_microsec(when):
    '''
    str of time in ctime style with microseconds added
    
    >>> ctime_with_microsec(1141221938.8167729)
    'Wed Mar  1 16:05:38.816773 2006'
    '''
    import time
    ct = time.ctime(when).split(' ')
    ct[-2] += ('%.6f' % (when%1)).lstrip('0')
    return ' '.join(ct)


def be_time_no_msecs(when):
    '''
    big endian representation of the date and time without microseconds
    
    >>> be_time_no_msecs(1141221938.8167729)
    '2006/03/01 16:05:38'
    '''
    import time
    return time.strftime("%Y/%m/%d %H:%M:%S",time.localtime(when)) 


def be_time(when):
    '''
    big endian representation of the date and time
    
    >>> be_time(1141221938.8167729)
    '2006/03/01 16:05:38.816773'
    '''
    return be_time_no_msecs(when) + ('%.6f'%(when%1, )).lstrip('0')

################################################################################
def getusername():
    import os, pwd
    return pwd.getpwuid(os.geteuid())[0]

def getuserhome():
    import os,pwd
    return pwd.getpwuid(os.geteuid())[5]

def rel2abs(path, reference = None):
    """
    converts a relative path to an absolute path.
    Optionally, the relative path can be "seen" from the perspective of a
    certain file.

    >>> rel2abs("/absolute/path")
    '/absolute/path'
    >>> rel2abs("../test/me", "/tmp")
    '/test/me'
    >>> rel2abs("../../test/me", "/a/very/deep/directory/structure")
    '/a/very/test/me'

    @param path: relative path to make absolute
    @param reference: optional - filename or path from which the relative path
        should be expanded. If not given - this is identical to calling
        os.path.abspath
    @return: the absolute path corresponding to path
    """
    #if path is already absolute...
    if os.path.isabs(path):
        return path

    if (reference is not None):
        path = os.path.join(os.path.dirname(reference), path)

    return os.path.abspath(path)

def set_nonblock(fd, block):
    import fcntl
    fl = fcntl.fcntl(fd, fcntl.F_GETFL)
    if block:
        fl = ~os.O_NONBLOCK
    else:
        fl |= os.O_NONBLOCK
    fcntl.fcntl(fd, fcntl.F_SETFL, fl)

