import os
import shutil
import tempfile

class TemporaryDirectoryContext(object):
    def __init__(self, suffix='TemporaryDirectoryContext', exception_if_directory_not_empty_on_exit=None):
        self.suffix = suffix
        self.path = None
        self.exception_if_directory_not_empty_on_exit = exception_if_directory_not_empty_on_exit
    def __enter__(self):
        self.path = tempfile.mkdtemp(suffix=self.suffix)
        return self.path
    def __exit__(self, type, value, traceback):
        try:
            os.rmdir(self.path)
        except OSError, error:
            if error.errno != 66:
                raise
            if self.exception_if_directory_not_empty_on_exit is not None:
                raise self.exception_if_directory_not_empty_on_exit 
            shutil.rmtree(self.path)
        finally:
            self.path = None

class TemporaryDirectoryContextWithCarelessCleanup(object):
    "removes temporary directory even if it has files"
    def __init__(self, suffix='TemporaryDirectoryContext', exception_if_directory_not_empty_on_exit=None):
        self.suffix = suffix
        self.path = None
        self.exception_if_directory_not_empty_on_exit = exception_if_directory_not_empty_on_exit
    def __enter__(self):
        self.path = tempfile.mkdtemp(suffix=self.suffix)
        return self.path
    def __exit__(self, type, value, traceback):
        try:
            os.rmdir(self.path)
        except OSError, error:
            if error.errno != 66:
                raise
            if self.exception_if_directory_not_empty_on_exit is not None:
                raise self.exception_if_directory_not_empty_on_exit 
            shutil.rmtree(self.path)
        finally:
            self.path = None
