import os
import time
import signal
import subprocess

def get_python_process_pids(command_line):
    pids = []
    for pid in os.listdir("/proc"):
        if pid == 'self':
            continue
        exe = None
        try:
            exe = os.readlink("/proc/%s/exe" % (pid, ))
        except:
            pass
        if exe and (exe.endswith('python2.4') or exe.endswith('python')):
            pid = int(pid)
            if '\0'.join(command_line) in open("/proc/%s/cmdline" % (pid, )).read():
                pids.append(pid)
    return pids

def python_pkill(command_line, protect, pause_before_sigkill=1):
    def send_signal(pid_list, protect, signal_type):
        for pid in pid_list:
            if pid not in protect:
                os.kill(pid, signal_type)

    pid_list = get_python_process_pids(command_line)
    send_signal(pid_list, protect, signal.SIGTERM)
    time.sleep(0.001)
    
    pid_list = get_python_process_pids(command_line)
    if pid_list:
        time.sleep(pause_before_sigkill)
        send_signal(pid_list, protect, signal.SIGKILL)

def num_running_processes(name):
    """Returns the number of running processes with the given name.
    Note: this function will be fooled by things like:
    'administrator -m 10.10.x.y administrator.py'
    the above command will be counted as administrator.py.
    the -C flag of ps only checks the first 15 (12?) characters
    of the command line. the function checks that the full
    commnad name appears in the command line, but it will be
    fooled if the full command line is an argument of a command
    with the same prefix (as in the example above).
    """
    def same_process(proc, pid, ppid, rsz, cmd):
        if pid not in proc[0] and ppid not in proc[0]:
            return False
        return (rsz == proc[1] and cmd == proc[2])

    p = subprocess.Popen(['ps', '--no-headers', '-C', name,
                          '-o', 'pid,ppid,rsz,command'],
                         stdout=subprocess.PIPE)
    stdout = p.communicate()[0].split('\n')
    processes = []
    for line in stdout:
        if line and name in line:
            pid, ppid, rsz, cmd  = line.split(None, 3)
            pid  = int(pid)
            ppid = int(ppid)
            rsz  = int(rsz)
            found = False
            for proc in processes:
                if same_process(proc, pid, ppid, rsz, cmd):
                    found = True
                    break
            if found:            
                proc[0].add(pid)
                proc[0].add(ppid)
            else:
                new_proc = [set([pid, ppid]), rsz, cmd]
                processes.append(new_proc)

    np = len(processes)
    if p.returncode and np: # ps returns 1 if there are no such processes
        return None
    else:
        return np
