"""
A generic memoizer (http://en.wikipedia.org/wiki/Memoization).
"""

from xiv.pyutils import weakref
from time import time

class INFINITE(object):
    def __cmp__(self, obj):
        return 1
    def __sub__(self, obj):
        return self
    def __repr__(self):
        return '<INFINITE>'

def wrapper(memoizer, func, force_refresh=False):
    def wrapped_callable(*args, **kwargs):
        key = (str(func), args, tuple((kwargs.items())))
        value, creation_time = memoizer._cache.get(key, (None, None))
        if creation_time is None:
            age = INFINITE()
        else:
            age = time() - creation_time
        if force_refresh or value is None or memoizer.maximum_age <= age:
            memoizer._cache[key] = (func(*args, **kwargs), time())
        return memoizer._cache[key][0]
    return wrapped_callable

class Memoizer(object):
    """
    >>> class TestMemoizer(object):
    ...     def __init__(self):
    ...         super(TestMemoizer, self).__init__()
    ...         self.number = 0
    ...     
    ...     def call(self):
    ...         self.number += 1
    ...         return self.number
    ... 
    >>> myobj = TestMemoizer()
    >>> mm = Memoizer(myobj)
    >>> mm.call()
    1
    >>> mm.call()
    1
    >>> mm.REFRESH.call()
    2
    >>> mm.call()
    2
    >>> mm.CLEAR()
    >>> mm.call()
    3
    """
    def __init__(self, obj, maximum_age=INFINITE()):
        super(Memoizer, self).__init__()
        self._obj = obj
        self._cache = {}
        self.maximum_age = maximum_age
        self.REFRESH = ForceRefresh(self)

    def CLEAR(self):
        self._cache = {}

    def __getattr__(self, name):
        attribute = getattr(self._obj, name)
        if callable(attribute):
            return wrapper(self, attribute)
        else:
            return attribute

    def __repr__(self):
        return '<memoizer for %r>' % self._obj

    def __str__(self):
        return str(self._obj)

class ForceRefresh(object):
    def __init__(self, memoizer):
        super(ForceRefresh, self).__init__()
        self._parent = weakref(memoizer)

    def __getattr__(self, name):
        attribute = getattr(self._parent._obj, name)
        if callable(attribute):
            return wrapper(self._parent, attribute, force_refresh=True)
        else:
            return attribute
