import thread
import traceback
import signal
import pdb
import sys
import atexit
import os
import threading
import inspect
import ctypes
 
class Thread(threading.Thread):
    def __init__(self, *args, **kwargs):
        gracePeriod = kwargs.pop('gracePeriod', None)
        super(Thread, self).__init__(*args, **kwargs)
        self._id = None
        self._initializeSignals()
        self._stopped = False
    @property
    def id(self):
        assert self._id is not None
        return self._id

    @property
    def stopped(self):
        return self._stopped

    def start(self):
        self._stopped = False
        super(Thread, self).start()

    def stop(self):
        self._stopped = True

    def _stop(self, gracePeriod=None):
        self.stop()
        self.join()
    
    def terminate(self):
        _async_raise(self.id, ThreadTermination)
    #### BEHAVIOR AS CONTEXT MANAGER ##############################
    def __enter__(self):
        self.start()
        return self
    def __exit__(self, excType, excValue, tb):
        if excValue is None:
            self.stop()
    #### The following is a wrapper for run(), the hard way #######
    _ppid = os.getpid()
    def _initializeSignals(self):
        if os.getpid() == self._ppid:
            signal.signal(signal.SIGUSR1, self._parentSignalHandler)
    def _handleException(self):
        atexit.register(self._debug, *sys.exc_info())
        os.kill(self._ppid, signal.SIGUSR1)
    def _debug(self, exc_type, exc_value, exc_traceback):
        print >>sys.stderr, "----- Exception from thread %r -----" % (self.getName(), )
        traceback.print_exception(exc_type, exc_value, exc_traceback)
        pdb.post_mortem(exc_traceback)
    @staticmethod
    def _parentSignalHandler(signum, stack_frame):
        raise SystemExit(1)
    #############################################################################    
    def _runWrapper(self):
        real_run_func = type(self).run
        self._id = thread.get_ident()
        try:
            real_run_func(self)
        except:
            print "EXCEPTION IN THREAD!!!!"
            self._handleException()
        finally:
            self._id = None
    def __getattribute__(self, attr):
        if attr == "run":
            return self._runWrapper
        return super(Thread, self).__getattribute__(attr)

AbortingThread = Thread
