import functools
import unittest
import pdb
import sys

from xiv.pyutils import PreprocessedClass

_debug = True

def debug_wrapper(func):
    @functools.wraps(func)
    def new_func(self, *args, **kwargs):
        try:
            return func(self, *args, **kwargs)
        except:
            if _debug:
                exc_type, exc_value, exc_tb = sys.exc_info()
                print "* EXCEPTION OCCURRED".ljust(80, "*")
                print "* TEST FILE:", func.func_globals['__file__']
                print "* TEST CLASS:", self.__class__.__name__
                print "* TEST FUNC:", func.__name__
                print exc_type.__name__, ":", exc_value
                print "*" * 80
                pdb.post_mortem(exc_tb)
            raise
    return new_func

class TestCase(unittest.TestCase):
    __metaclass__ = PreprocessedClass

    def __process_class__(classname, classdict, bases):    
        for func_name in classdict.keys():
            if (not func_name.startswith("test")) and func_name not in ("runTest", "setUp", "tearDown"):
                continue
            classdict[func_name] = debug_wrapper(classdict[func_name])
    
def main(*args, **kwargs):
    global _debug
    _debug = kwargs.pop('debug', True)
    return unittest.main(*args, **kwargs)
