#!/usr/bin/env python

import socket
import re

def is_valid_ip(ip_addr):
    """
    Checks if the string supplied conforms to valid ip address
    """
    try:
        m = re.match('^([0-2][0-9][0-9]|[0-9][0-9]|[0-9])\.([0-2][0-9][0-9]|[0-9][0-9]|[0-9])\.([0-2][0-9][0-9]|[0-9][0-9]|[0-9])\.([0-2][0-9][0-9]|[0-9][0-9]|[0-9])$',ip_addr)
    except TypeError:
        return False
    if m is not None and len(m.groups()) == 4:
        return True
    return False


def is_port_open(host,port,timeout=10,protocol="tcp",tx_data=None,rx_handler=None):
    """
    Checks if remote port is accepting connections
    """
    if isinstance(port,int) :
        return  is_port_open_by_port_number(host,port,timeout,protocol,tx_data,rx_handler)
    if isinstance(port,str):
        if port.isdigit() :
            return  is_port_open_by_port_number(host,port,timeout,protocol,tx_data,rx_handler)
        else :
            return is_port_open_by_service_name(host,port,timeout,protocol,tx_data,rx_handler)

def is_port_open_by_service_name(host,service_name,timeout=10,protocol="tcp",tx_data=None,rx_handler=None):
    """
    Checks if remote port is accepting connections
    Port is extracted from service_name. i.e 
    "ftp" == 21
    """
    try:
        service_port = int(socket.getservbyname(service_name))
    except socket.error, e:
        raise ValueError("Unable to resolve service name:%s" % service_name)
    return is_port_open_by_port_number(host,service_port,timeout,protocol,tx_data,rx_handler)


def is_port_open_by_port_number(host,port,timeout=10,protocol="tcp",tx_data=None,rx_handler=None):
    """
    Checks if remote port is accepting connections
    """
    # Resolve hostname
    host = socket.gethostbyname(host)
    # Convert port to int
    port = int(port)

    if protocol == "tcp" :
        s = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
    else : # assume udp
        s = socket.socket(socket.AF_INET,socket.SOCK_DGRAM)

    s.settimeout(timeout)
    try:
        errno = s.connect_ex((host,port)) 
        if errno != 0:
            return False
        if tx_data is not None:
            s.send(tx_data)
            if rx_handler is not None:
                recv_data, address  = s.recvfrom(1024)
                print("Calling return data handler %s" % rx_handler.__name__)
                return rx_handler(recv_data)
        s.close()
    except socket.error, e:
        # Socket error occurs when connection failed, assume port is closed
        return False
    return True
