import time
import random
import cStringIO

def str_brief(obj, lim=20, dots='...', use_repr=True):
    """Truncates a string, starting from 'lim' chars. The given object
    can be a string, or something that can be casted to a string.

    >>> import string
    >>> str_brief(string.uppercase)
    "'ABCDEFGHIJKLMNOPQRST...'"
    >>> str_brief(2 ** 50, lim=10, dots='0')
    '11258999060'
    """
    if isinstance(obj, str) and use_repr:
	full = repr(obj)
    else:
	full = str(obj)
    postfix = []
    CLOSERS = {'(':')', '{':'}', '[':']', '"':'"', "'":"'", '<':'>'}
    for i, c in enumerate(full):
        if i >= lim+len(postfix):
            return full[:i]+dots+''.join(reversed(postfix))
        if postfix and postfix[-1] == c:
            postfix.pop(-1)
            continue
        closer = CLOSERS.get(c, None)
        if closer != None:
            postfix.append(closer)
    return full

def str_lbrief(obj, lim=20, dots='...'):
    """Same as str_brief, but trims chars from the left side of the
    string.
    >>> str_lbrief('Dude, wheres my car?', lim=10)
    "'...es my car?'"
    """
    return str_brief(obj[::-1], lim=lim, dots=dots)[::-1]

def random_data(length):
    r"""Produces a random string with a certain length. The length
    can also be a unit (from xiv.dtypes.units).
    >>> from pypackages.xiv.dtypes import units
    >>> random.seed(1234)
    >>> random_data(16)
    '\xf7p\x01\xe9\xf0\x95\xab\x15\xc4<\x07\xc9X\x9f\x9d&'
    >>> random_data(5)
    '.\x1d\x03|\xf7'
    >>> random_data(3 * units.byte)
    '\x10\x8aw'
    >>> len(random_data(4 * units.KiB))
    4096
    """
    from pypackages.xiv.dtypes import units
    if isinstance(length, units.DataSize):
        length = length.roundup(units.byte) // units.byte
    result = cStringIO.StringIO()
    for i in xrange(length):
        result.write(chr(random.randint(0, 255)))
    return result.getvalue()

class CutDown(object):
    count_after_seperator = ':'
    joker_char = '#'
    jokers_char = '*'
    def __init__(self,**kw):
        super(CutDown,self).__init__()
        self.__dict__.update(kw)
    
    def suffixate_string(self,orig,leave):
        colon = orig.find(self.count_after_seperator)
        if colon == -1:
            colon = 0
        leave += colon
        return orig[:leave]+self.joker_char*(len(orig)-leave)

    def _unsuffixate(self,x,lst):
        if len(lst)==1:
            return lst[0]
        return x

    def _compact_dict(self,dc,op):
        tdc = {}
        for x,lst in dc.iteritems():
            nx = op(x,lst)
            if not nx in tdc:
                tdc[nx] = lst
            else:
                tdc[nx].extend(lst)
        return tdc

    def _trailer(self,x):
        if not x.endswith(self.joker_char):
            return x
        return x.rstrip(self.joker_char) + self.jokers_char

    def cut_down(self,orig_seq,max_len = 80):
        """ cull down orig_seq to no more than max_len strings
        by replacing suffixes with ### or *
        if max_len is too small for even extreme compaction
        the result might be longer than max_len """
        dc = dict([(str(x),[str(x)]) for x in orig_seq])
        leave = max([len(x) for x in dc])
        while leave > 0 and len(dc) > max_len:
            dc = self._compact_dict(dc,lambda x,lst:self.suffixate_string(x,leave))
            leave -= 1
        if len(dc) > max_len:
            dc = self._compact_dict(dc,lambda x,lst:self._trailer(x))
        
        return sorted([self._unsuffixate(x,lst) for x,lst in dc.iteritems()])

def transcode(buff, charset):
    divisor = len(charset)
    remainders = []
        
    if len(buff) % 2 != 0:
        buff += "\x00"
        
    dividend = [((ord(x)<<8) | ord(y)) for x, y in  zip(buff[::2], buff[1::2])]

    while dividend:
        quotient = []
        x = 0
        for i in dividend:
            q = ((x << 16) + i) / divisor #integer division
            x = ((x << 16) + i) % divisor
            if quotient or q:
                quotient.append(q)
        remainders.append(x)
        dividend = quotient

    return "".join([charset[i] for i in remainders])

def plural(word):
    if word.endswith('s'):
        return word + "es"
    elif word.endswith('y'):        
        if word[-2] in "aeiou":
            return word[:-1] + 's'
        else:
            return word[:-1] + 'ies'
    else:
        return word + 's'

def find_common_prefix(strings):
    common_prefix = ""
    new_prefix = ""
    min_length = min(map(len, strings))
    while len(common_prefix) + 1 < min_length and all(s.startswith(new_prefix) for s in strings):
        common_prefix = new_prefix
        new_prefix = strings[0][:len(new_prefix) + 1]
    return common_prefix
    
def drop_common_prefix(strings):    
    prefix = find_common_prefix(strings)
    return [s[len(prefix):] for s in strings]

def format_columns(*strings, **kwargs):
    r"""Takes several multiline strings, and format them in columns,
    so that each string is placed in a column, and all columns are
    formatted side by side.
    >>> print format_columns(
    ...     'once upon a time\nthere was a little\nlamb...',
    ...     'dude wheres my car?\nwheres my car dude?\ndude?\ndude!\ndude!',
    ...     '1\n2\n3\n4\n5\n6\n7\n8\n9\n0')
    once upon a time     dude wheres my car?   1
    there was a little   wheres my car dude?   2
    lamb...              dude?                 3
                         dude!                 4
                         dude!                 5
                                               6
                                               7
                                               8
                                               9
                                               0
    """
    seperator = kwargs.get('seperator', '   ')
    strings = [string.split('\n') for string in strings]

    rows = []
    for row_num in range(max([len(string) for string in strings])):
        row = []
        for string in strings:
            try:
                row.append(string[row_num])
            except IndexError:
                row.append('')
        rows.append(row)

    column_lens = [max([len(row[column_num]) for row in rows])
                   for column_num in range(len(strings))]

    return '\n'.join([seperator.join([string.ljust(column_lens[column_num])
                                      for column_num, string in enumerate(row)])
                      for row in rows])

