import cStringIO as StringIO

def string_diff(s1, s2):
    """
    @return: list of tuples of (begin, end) indices of differences between s1, s2
    """
    diffs = []
    start = None
    
    for index, (c1, c2) in enumerate(zip(s1, s2)):
        if start is not None:
            if c1 == c2:
                diffs.append((start, index))
                start = None
        else:
            if c1 != c2:
                start = index
    if start is not None:
        diffs.append((start, max(len(s1), len(s2)) ))
    return diffs

def mark_differences(s1, s2, replfunc):
    """
    given two strings, return copies of those strings, where each difference
    between them is replaced by text returned for it by replfunc
    
    >>> mark_differences("this is the first  string: bla",
    ...                  "this is the second string: blo",
    ...                  lambda text: "<" + text + ">")
    ('this is the <first > string: bl<a>', 'this is the <second> string: bl<o>')
    """
    diffs = string_diff(s1, s2)
    
    returned = []
    for s in (s1, s2):
        current_pos = 0
        output = StringIO.StringIO()
        
        for diff in diffs:
            output.write(s[current_pos:diff[0]])
            output.write(replfunc(s[diff[0]:diff[1]]))
            current_pos = diff[1]
        output.write(s[current_pos:])
        returned.append(output.getvalue())
    return tuple(returned)
        

if __name__ == "__main__":
    import doctest
    doctest.testmod()