from xml.parsers.expat import ExpatError
try:
    from xml.etree import ElementTree as _implementation
except ImportError:
    from elementtree import ElementTree as _implementation
from pdis.xpath import compile


class _ElementInterfaceWithXPath(_implementation._ElementInterface):
    def __init__(self, tag, attrib):
        _implementation._ElementInterface.__init__(self, tag, attrib)
        self.xpath_cache = {}
    def xpath(self, xpath):
        if xpath not in self.xpath_cache:
            self.xpath_cache[xpath] = compile(xpath)
        return self.xpath_cache[xpath].evaluate(self)
    def xeval(self, xpath):
        result = self.xpath(xpath)
        if not result:
            raise LookupError("unable to find %r in %r" % (xpath, self.tag), self)
        if len(result) > 1:
            raise LookupError("searching %r in %r returned %d results" % (xpath, self.tag, len(result)), self)
        return result[0]
    def __str__(self):
        return tostring(self)
    def indent(self, elem=None, level=0):
        if elem is None:
            elem = self
        i = "\n" + level*"  "
        if len(elem):
            if not elem.text or not elem.text.strip():
                elem.text = i + "  "
            for e in elem:
                self.indent(e, level+1)
                if not e.tail or not e.tail.strip():
                    e.tail = i + "  "
            if not e.tail or not e.tail.strip():
                e.tail = i
        else:
            if level and (not elem.tail or not elem.tail.strip()):
                elem.tail = i
        return self

class TerminationDetectingTreeBuilder(_implementation.TreeBuilder):
    def __init__(self, element_factory=_ElementInterfaceWithXPath):
        _implementation.TreeBuilder.__init__(self, element_factory)
        self.top_element = None
        self.top_element_closed = False
    def start(self, tag, attrs):
        element = _implementation.TreeBuilder.start(self, tag, attrs)
        if self.top_element is None:
            self.top_element = element
        return element
    def end(self, tag):
        element = _implementation.TreeBuilder.end(self, tag)
        if self.top_element is element:
            self.top_element_closed = True
        return element

class TerminationDetectingXMLParser(object):
    def __init__(self):
        self.tree_builder = TerminationDetectingTreeBuilder()
        self.xml_tree_builder = _implementation.XMLTreeBuilder(target=self.tree_builder)
    def feed(self, data):
        self.xml_tree_builder.feed(data)
    def close(self):
        return self.xml_tree_builder.close()
    @property
    def top_element_closed(self):
        return self.tree_builder.top_element_closed

def fromstring(text):
    """
    >>> fromstring("<a><b v='5'>t</b><c/><b v='7'/></a>").xpath('a/b/@v')
    ['5', '7']
    >>> 
    """
    target = _implementation.TreeBuilder(element_factory = _ElementInterfaceWithXPath)
    parser = _implementation.XMLTreeBuilder(target = target)
    parser.feed(text)
    return parser.close()

tostring = _implementation.tostring
