import os
import tempfile

from xiv_xsf.utils.osutils import OsUtils

class CxOracleWrapper(object):
    """A workaround to overcome the bad behaviour of Oracle Client
    On instantiation, generates a new sqlnet.ora file in a temporary path,
    and sets TNS_ADMIN to point there.
    On delete, brings things back to normal.

    See descriptions in:
    http://sourceforge.net/mailarchive/forum.php?thread_name=48C21800.9050401%40gaius.org.uk&forum_name=cx-oracle-users
    http://sourceforge.net/mailarchive/forum.php?thread_name=200902112125.54841.oren%40held.org.il&forum_name=cx-oracle-users
    """

    BAD_BEHAVIOR_OS_LIST = ["sunos", "aix"]

    def __init__(self):
        """Creates a new sqlnet.ora and sets TNS_ADMIN to point at its dir"""
        if self.os_needs_this_wrapper():
            self.sqlnet_ora_dir = tempfile.mkdtemp(prefix="cx_oracle_")
            self.sqlnet_ora_path = os.path.join(self.sqlnet_ora_dir, "sqlnet.ora")
            self.generate_sqlnet_ora()

            # Keep previous TNS_ADMIN value
            try:
                self.original_tnsadmin = os.environ["TNS_ADMIN"]
            except KeyError, e:
                self.original_tnsadmin = None
            
            os.environ["TNS_ADMIN"] = self.sqlnet_ora_dir

    def __del__(self):
        """Cleanup"""
        try:
            os.unlink(self.sqlnet_ora_path)
        except OSError, e:
            pass 

        os.rmdir(self.sqlnet_ora_dir)

        # Roll back the env. vars we've modified
        if self.original_tnsadmin is None:
            del os.environ["TNS_ADMIN"]
        else:
            os.environ["TNS_ADMIN"] = self.original_tnsadmin

    def os_needs_this_wrapper(self):
        """Returns True only for OS that suffers from the bad behaviour"""
        osutils = OsUtils()
        osname = osutils.get_os_name()
        if (osname in self.BAD_BEHAVIOR_OS_LIST):
            return True
        else:
            return False

    def generate_sqlnet_ora(self):
        """Currently a very small file. Maybe in the future we'll want to read
        the original sqlnet.ora and append this at the end"""
        f = open(self.sqlnet_ora_path, 'w')
        f.write("BEQUEATH_DETACH = yes\n")
        f.close()
