from dialogbinary import DialogBinary
from sets import Set
from widget import Widget
import geometry
from errors import CanvasException

__all__ = ['Canvas']

class Canvas(Widget):

    default_properties = {'render_automatically': False, 'backtitle': None, 'colors': True}
    SCREEN_SIZE_REFRESH_INTERVAL = 1

    def __init__(self, geometry_manager, **kwargs):

        Widget.__init__(self, canvas=None, **kwargs)

        self.dialog_binary = DialogBinary()
        self.geometry_manager = geometry_manager
        self.geometry_manager.set_canvas(self)
        
        self.interactive_widget = None

        self.widgets = Set()


    def get_screen_size(self):

        results = self.dialog_binary.call('--print-maxsize', validate=True)
        return map(int, results.stderr.strip().split(': ')[1].split(', '))

    def add(self, widget):
        
        if widget.interactive:
            if self.interactive_widget:
                raise CanvasError("Canvas is already interactive, cannot add another interactive widget")
            else:
                self.interactive_widget = widget

        self.widgets.add(widget)
            
        if self['render_automatically']:
            self.render()

    def add_grid(self, widget, *args, **kwargs):

        if not isinstance(self.geometry_manager, geometry.Grid):
            raise CanvasError("Geometry manager is not Grid, cannot use add_grid")
    
        self.geometry_manager.place(widget, *args, **kwargs)
        self.add(widget)


    def remove(self, widget, **kwargs):
    
        if widget.interactive:
            self.interactive_widget = None

        self.widgets.remove(widget)
        self.geometry_manager.remove(widget)


    def repr_string(self, widget):
        
        geometry = self.geometry_manager.get_geometry(widget)

        s = []

        if self['colors']:
            s.append('--colors')

        s.append('--begin %d %d' % (geometry.y, geometry.x))
        s.append(widget.command_repr(geometry.height, geometry.width))

        return ' '.join(s)
       

    def render(self):

        options = []

        if self['backtitle'] is not None:
            options.append('--backtitle "%s"' % self['backtitle'])
       
        all_options = " ".join(options)    

        repr_strings = []

        wait_for_dialog = True
        for widget in self.widgets:
            if widget != self.interactive_widget:
                repr_strings.append(self.repr_string(widget))
            if widget.wait_for_dialog == False:
                wait_for_dialog = False

        if self.interactive_widget is not None:
            repr_strings.append(self.repr_string(self.interactive_widget))

        all_repr_strings = " --and-widget ".join(repr_strings)
        command = "%s %s" % (all_options, all_repr_strings)

        if wait_for_dialog:
            results = self.dialog_binary.call(command)
        else:
            self.dialog_binary.call(command, wait=False, capture_stdin=True)
        #results.show()
        
        if wait_for_dialog and self.interactive_widget is not None:
            self.interactive_widget.process_results(results)
        
    @property
    def screen_width(self):

        if time.time() - self._screen_measurement_time > self.SCREEN_SIZE_REFRESH_INTERVAL:
            self.detect_screen_size()
	return self._screen_width


    @property
    def screen_height(self):
	
        if time.time() - self._screen_measurement_time > self.SCREEN_SIZE_REFRESH_INTERVAL:
            self.detect_screen_size()
        return self._screen_height
