import subprocess, commands, os

from errors import *

class CommandResults(object):

    def __init__(self, return_value=None, stdout=None, stderr=None):

        self.return_value = return_value
        self.stdout = stdout
        self.stderr = stderr

    def show(self):

        print 'Return value:', self.return_value
        print 'Output:', self.stdout
        print 'Error:', self.stderr


class DialogBinary(object):

    def __init__(self):

        super(DialogBinary, self).__init__()
        self.path = self.find_binary_in_paths('dialog')
        self.version, self.date = self.detect_dialog_version()


    def call(self, command, **kwargs):
        # HACK: in Python 2.6 we'll be able to simply specify these keyword arguments, rather than use **kwargs
        validate = kwargs.pop('validate', True)
        capture_stdout = kwargs.pop('capture_stdout', False)
        capture_stdin = kwargs.pop('capture_stdin', False)
        wait = kwargs.pop('wait', True)
        if kwargs:
            raise TypeError('call got unexpected keyword argument %s' % kwargs.popitem()[0])

        try:
            command_line = "%s %s" % (self.path, command)
            #print 'Running:', command_line
            kwargs = {'shell': True, 'stderr': subprocess.PIPE, 'close_fds': True}
            
            if capture_stdout:
                kwargs['stdout'] = subprocess.PIPE
            if capture_stdin:
                kwargs['stdin'] = subprocess.PIPE
            
            self.process = subprocess.Popen(command_line, **kwargs)

        except OSError, error:
            raise DialogExecutionError("can't run dialog: %s" % error[1])

        if wait:
            return_value = self.process.wait()
            results = CommandResults(self.process.returncode, '', self.process.stderr.read())
            if validate and results.return_value == 255:
                raise DialogExecutionError("dialog returned value %d, error is: '%s'" % (results.return_value, results.stderr.strip()))

            if capture_stdout:
                results.stdout = self.process.stdout.read()

            return results


    def yield_args_with_binary(self, args):
        yield self.path
        for arg in args:
            yield arg

    def detect_dialog_version(self):
        results = self.call('--version', validate=True, capture_stdout=True)
        version, date = results.stdout.strip().split(': ')[1].split('-')
        return version, date

    def find_binary_in_paths(self, binary, prepend_paths='', append_paths=''):
        for possible_path in self.yield_single_path(binary, prepend_paths, append_paths):
            if os.access(possible_path, os.X_OK) and not os.path.isdir(os.path.join(possible_path, binary)):
                return possible_path
        raise CantFindDialogBinary('%s not found in search paths' % binary)

    def yield_single_path(self, binary, prepend_paths, append_paths):
        yielded = []
        environment_path = os.environ.get('PATH', '')
        for path in (prepend_paths, environment_path, append_paths):
            for path_component in path.split(':'):
                if path_component not in yielded:
                    yielded.append(path_component)
                    yield os.path.join(path_component, binary)

    def __repr__(self):
        return '<dialog at %s>' % self.path

