from HTMLParser import HTMLParser

from errors import ParseError

__all__ = ['ColorParser', 'Text'] 


class ColorParser(HTMLParser):

    color_codes = {'black': 0, 'red': 1, 'green': 2, 'yellow': 3,
        'blue': 4, 'magenta': 5, 'cyan': 6, 'white': 7}

    def __init__(self, discard_colors=False):
        HTMLParser.__init__(self)
        self.strings = []
        self.strings_without_colors = []
        self.discard_colors = discard_colors
        self.active_tags = []

    def tag_to_code(self, tag):

        if tag in self.color_codes:
            return '\\Z%d' % self.color_codes[tag]
        elif tag in ['r', 'b', 'u']:
            return '\\Z%s' % tag
        else:
            raise ParseError("Unrecognized HTML tag: %s" % tag)


    def handle_starttag(self, tag, attrs):
        if self.discard_colors:
            return

        self.strings.append(self.tag_to_code(tag))
        self.active_tags.append(tag)

    def handle_endtag(self, tag):
        if tag not in self.active_tags:
            raise ParseError("HTML tag closed but not opened")

        self.active_tags.remove(tag)
        if tag in self.color_codes:
            self.strings.append('\\Zn')
            for active_tag in self.active_tags:
                self.strings.append(self.tag_to_code(active_tag))
        elif tag == 'b':
            self.strings.append('\\ZB')
        elif tag == 'r':
            self.strings.append('\\ZR')
        elif tag == 'u':
            self.strings.append('\\ZU')
        else:
            raise ParseError("Unrecognized HTML tag: %s" % tag)

    def handle_data(self, data):
        self.strings.append(data)
        self.strings_without_colors.append(data)

    def get(self):
        return ''.join(self.strings)

    def get_without_colors(self):
        return ''.join(self.strings_without_colors)


class Text(object):

    def __init__(self, raw):
        object.__init__(self)
        self.raw = raw
        self.parser = ColorParser()
        self.parser.feed(self.raw)
    
    def get(self):
        return self.parser.get()

    def __len__(self):
        return len(self.parser.get_without_colors())

    def fit(self, max_height, max_width):

        plain = self.parser.get_without_colors().split('\n')
        text_width = min(max_width, max([len(x) for x in plain]) + 1)
        text_height = min(max_height, 
            sum([len(x) / text_width + 1 for x in plain]))
        return text_height, text_width    

