from errors import CancelPressed

from text import Text

__all__ = ['Widget', 'InteractiveWidget', 'NonInteractiveWidget']

class Widget(object):

    AUTO = -1
    CANCEL = -2
    global_default_props = {'height': AUTO, 'width': AUTO, 
        'shadow': False, 'title': None}

    widget_frame_height = 2
    widget_frame_width = 4
    button_row_height = 2
    button_row_width_ok_cancel = len('<  OK  > <Cancel>')

    wait_for_dialog = True

    def _text(self):
        if not hasattr(self, 'text') or self._last_label != self['label']:
            self.text = Text(self['label'])
            self._last_label = self['label']
        return self.text

    def check_property(self, property):

        if property not in self.properties:
            raise ValueError("Property '%s' is invalid for widget '%s'" % 
                (property, self.__class__.__name__))

    def __getitem__(self, key):
    
        self.check_property(key)        
        return self.properties[key]

    def __setitem__(self, key, value):

        self.check_property(key)
        self.properties[key] = value

    def __init__(self, canvas, **kwargs):
        
        self.canvas = canvas
        self.properties = self.global_default_props.copy()
        self.properties.update(self.default_properties)

        for arg, value in kwargs.iteritems():
            self[arg] = value

    def command_repr(self, height, width):

        strings = []
        if self['shadow']:
            strings.append('--shadow')
        else:
            strings.append('--no-shadow')

        if self['title'] is not None:
            strings.append('--title "%s"' % self['title']) 

        strings.append(self.specific_repr(height, width))

        return ' '.join(strings)

    def best_fit(self, max_height, max_width):
        # Should be overriden
        return max_height, max_width


class NonInteractiveWidget(Widget):

    interactive = False    


class InteractiveWidget(Widget):

    interactive = True 
    
    def validate_return_value(self, command_results):

        if command_results.return_value == 1:
            raise CancelPressed()

        elif command_results.return_value != 0:
            raise ValueError("Unknown dialog status %d" % \
                command_results.return_value) 

    def process_results(self, program_results):
        pass
        

