from ..widget import Widget, InteractiveWidget

class Form(InteractiveWidget):

    internal_frame_height = 2
    internal_frame_width = 4

    default_properties = {'label': '', 'form_height': Widget.AUTO,
        'align_fields': True, 'manual_positioning': False}

    class Item(object):

        def __init__(self, label='', label_y=Widget.AUTO, label_x=Widget.AUTO,
            value='', value_y=Widget.AUTO, value_x=Widget.AUTO,
            visible_size=10, max_size=256):

            self.label = label          # No colors: not supported by dialog
            self.label_y = label_y
            self.label_x = label_x
            self.value = value
            self.value_y = value_y
            self.value_x = value_x
            self.visible_size = visible_size
            self.max_size = max_size

    def __init__(self, canvas, **kwargs):
       
        InteractiveWidget.__init__(self, canvas, **kwargs) 
        self.items = []

    def specific_repr(self, height, width): 
        
        s = []
        s.append('--form "%s" "%d" "%d" "%d"' % \
            (self._text().get(), height, width, self['form_height']))

        for item in self.items:
            s.append('"%s" "%d" "%d" ' % (item.label, item.label_y, \
                                          item.label_x) + 
                '"%s" "%d" "%d" ' % (item.value, item.value_y, item.value_x) +
                '"%d" "%d"' % (item.visible_size, item.max_size))

        return ' '.join(s)

    def deal_rows(self):

        if self['manual_positioning']:
            return

        max_label_length = max([len(x.label) for x in self.items])

        for index, item in enumerate(self.items):
            item.label_y = index + 1
            item.label_x = 1
            item.value_y = index + 1
            if self['align_fields']:
                item.value_x = max_label_length + 2
            else:
                item.value_x = 1 + len(item.label) + 2

    def best_fit(self, max_height, max_width):

        self.deal_rows()

        height_overhead = self.widget_frame_height + self.button_row_height + \
            self.internal_frame_height
        width_overhead = self.widget_frame_width + self.internal_frame_width

        text_height, text_width = self._text().fit( \
            max_height - height_overhead, max_width - self.widget_frame_width)

        max_form_height = max_height - height_overhead - text_height
        max_requested_y = max_requested_x = 0

        for item in self.items:
            y = max(item.label_y, item.value_y)
            x = max(item.label_x + len(item.label), \
                    item.value_x + item.visible_size)
            if y > max_requested_y:
                max_requested_y = y
            if x > max_requested_x:
                max_requested_x = x

        if self['form_height'] == Widget.AUTO:
            self['form_height'] = min(max_form_height, max_requested_y)

        height = self['form_height'] + height_overhead + text_height
        width = max(text_width + self.widget_frame_width, \
            self.button_row_width_ok_cancel, max_requested_x + width_overhead)

        return height, width

    def process_results(self, program_results):

        self.validate_return_value(program_results)

        s = program_results.stderr
        answers = []
        try:
            while True:
                newline = s.index('\n')
                answers.append(s[:newline])
                s = s[newline+1:]
        except ValueError:
            pass
    
        assert len(self.items) == len(answers)
        for item, answer in zip(self.items, answers):
            item.answer = answer

