from ..widget import Widget, InteractiveWidget

class ListWidget(InteractiveWidget):

    default_properties = {'label': '', 'list_height': Widget.AUTO, 
        'default_item': Widget.AUTO}
    OFF = 'off'
    ON = 'on'

    list_frame_height = 2

    class Item(object):

        def __init__(self, tag, description, default=None):
        
            object.__init__(self)

            if default is None:
                self.default = ListWidget.OFF
            else:
                self.default = default

            self.tag = tag
            self.description = description

    def __init__(self, canvas, **kwargs):
        
        InteractiveWidget.__init__(self, canvas, **kwargs)
        self.items = []
        #change this:
        if self.properties['list_height'] == Widget.AUTO:
            self.properties['list_height'] = len(self.items)

    def specific_repr(self, height, width):

        if len(self.items) == 0:
            raise CanvasException("No items in list widget")
        elif self['default_item'] == Widget.AUTO:
            self['default_item'] = self.items[0].tag

        strings = []
        strings.append('--default-item %s ' % self['default_item'])
        strings.append('--%s ' % self._widget_name())
        strings.append('"%s" "%d" "%d" "%s"' % 
            (self['label'], height, width, self['list_height']))

        for index, item in enumerate(self.items):
            strings.append(self._format_item(item))

        return ' '.join(strings)

    def best_fit(self, max_height, max_width):

        label_height, label_width = self._text().fit(max_height, max_width)
        list_width = max([len('| ( ) ]') + len(x.tag) + len('  ') + \
            len(x.description) + len(' |') for x in self.items])

        height = label_height + self.widget_frame_height + \
            self['list_height'] + self.list_frame_height + \
            self.button_row_height 

        width = max(label_width, self.button_row_width_ok_cancel, list_width) +\
            self.widget_frame_width

        return height, width

    def process_results(self, command_results):

        self.validate_return_value(command_results)

        self.answer = command_results.stderr.split()

    def _format_item(self, item):
        return '"%s" "%s" "%s"' % (item.tag, item.description, item.default) 
        

class RadioList(ListWidget):

    def _widget_name(self):
        return 'radiolist'    


class CheckList(ListWidget):

    def _widget_name(self):
        return 'checklist'

    
class Menu(ListWidget):

    def _widget_name(self):
        return 'menu'

    def _format_item(self, item):
        return '"%s" "%s"' % (item.tag, item.description)

