from ..widget import Widget, InteractiveWidget

class ProgressBar(InteractiveWidget):

    default_properties = {'total_steps': 20, 'label': '', 'percent': 0, 
        'bar_width': Widget.AUTO}

    wait_for_dialog = False
    progressbar_height = 3

    def __init__(self, canvas, **kwargs):

        InteractiveWidget.__init__(self, canvas, **kwargs)

        if self['bar_width'] == Widget.AUTO:
            self['bar_width'] = self['total_steps'] + 1

        self.step = 0
        self.dialog_binary = self.canvas.dialog_binary

    def specific_repr(self, height, width):
        return '--gauge "%s" "%d" "%d" "%d"' % \
            (self._text().get(), height, width, self['percent'])

    def close(self):
        self.dialog_binary.process.stdin.close()
        self.dialog_binary.process.wait()

    def next_step(self):
        self.step += 1
        if self.step > self['total_steps']:
            raise IndexError("Progress bar passing 100%")

        self['percent'] = 100 * float(self.step) / self['total_steps']
        self.dialog_binary.process.stdin.write("%d\n" % self['percent'])
        

    def best_fit(self, max_height, max_width):
        
        height_overhead = self.widget_frame_height + self.progressbar_height

        label_height, label_width = self._text().fit( \
            max_height - height_overhead, max_width)

        return label_height + height_overhead, \
            max(label_width, self['bar_width'] + 2) + self.widget_frame_width



