#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 

import glob
import os

from common import CommonDevices
from xiv_xsf.utils.system_command import SystemCommand, ExternalCommandError

class LinuxDeviceMapper(object):
    DMSETUP_BIN = "/sbin/dmsetup"
    def read_dm_device(self, dm_file):
        system_command = SystemCommand([self.DMSETUP_BIN, "table", dm_file])
        try:
            system_command.run()
        except ExternalCommandError, e:
            return None

        dm_info = system_command.out.split("\n")[0].split(" ")

        return dm_info

    def get_dev_by_major_minor(self, major_minor):
        sys_files = glob.glob("/sys/block/sd*")

        for block in sys_files:
            dev_file = file(block + "/dev")
            line = dev_file.readline().strip()
            dev_file.close()
            if (major_minor == line):
                return "/dev/" + os.path.basename(block)

class OsDevices(CommonDevices):
    def get_list_of_scsi_disk_devices(self):
        # Logic was taken from 'fdisk -l' implementation.
        sys_files = glob.glob("/sys/block/sd*")

        list_of_scsi_disk_devices = map(lambda x: x.replace("/sys/block/", "/dev/"), sys_files)

        return list_of_scsi_disk_devices

    def get_multipath_tree(self):
        multipath_tree = {}
        dm_files = glob.glob("/dev/mapper/*")
        linux_dm = LinuxDeviceMapper()

        for dm_device in dm_files:
            dm_info = linux_dm.read_dm_device(dm_device)
            
            # Skip if it's not a multipath device
            if dm_info[2] != "multipath":
                break

            paths = []

            for i in range(12, len(dm_info)-1, 2):
                major_minor = dm_info[i]
                paths.append(linux_dm.get_dev_by_major_minor(major_minor))

            multipath_tree[dm_device] = paths

        return multipath_tree

    def get_all_paths(self):
        singlepaths = set(self.get_list_of_scsi_disk_devices())
        multipaths = self.get_multipath_tree()

        for key in multipaths:
            singlepaths = singlepaths - set(multipaths[key])

        return {"multipath": multipaths, "singlepath": list(singlepaths)}
