#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 

import re

from xiv_xsf.utils.system_command import SystemCommand

class VeritasMultipathInfo(object):
    VXDMPADM_BIN = "/sbin/vxdmpadm"

    def list_enclosures(self):
        """Get a list of veritas enclosure names"""
        enclosures = []
        system_command = SystemCommand([self.VXDMPADM_BIN, "listenclosure",
            "all"])
        system_command.run()
        out = system_command.out.split("\n")

        regexp = re.compile("^(\S+)")
        for i in range(2, len(out)):
            result = regexp.match(out[i])
            if (result is not None):
                enclosures.append(result.groups()[0])

        return enclosures

    def getdmpnode(self):
        """
        Returns a list of disk nodes discovered by vxvm
        """
        dmpnodes = []
        for enclosure in self.list_enclosures():
            system_command = SystemCommand([self.VXDMPADM_BIN, "getdmpnode",
                "enclosure=%s" % enclosure])

            system_command.run()
            out=system_command.out.split("\n")

            regexp = re.compile("^(\S+)")
            for i in range(2, len(out)):
                result = regexp.match(out[i])
                if (result is not None):
                    dmpnodes.append(result.groups()[0])

        return dmpnodes

    def getsubpaths(self, dmpnodename):
        """Accepts a disk node and returns all the enabled subpath devices
        """

        system_command = SystemCommand([self.VXDMPADM_BIN, "getsubpaths",
            "dmpnodename=%s" % dmpnodename])
        system_command.run()
        out = system_command.out.split("\n")
        output_list = filter(lambda(x): x.count("ENABLED"), out)
        output_list = map(lambda(x): x[:x.index(" ")], output_list)
        output_list = filter(lambda(x): len(x), output_list)

        return output_list

    def get_multipath_tree(self):
        multipaths = {}
        singlepaths = {}
        for dmpnode in self.getdmpnode():
                subpaths = self.getsubpaths(dmpnode)
                if (len(subpaths) == 1):
                    singlepaths[dmpnode] = subpaths
                elif (len(subpaths) > 1):
                    multipaths[dmpnode] = subpaths

        return {"multipath": multipaths, "singlepath": list(singlepaths)}
        

        return list
