#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 

import re

from xiv_xsf.host.storage.filesystems.common import FsUtils, MountTabParser
from xiv_xsf.utils.system_command import SystemCommand

class SpecificFsUtils(FsUtils):
    MOUNT_TAB_BIN = '/usr/sysv/bin/df'
    LSFS_CMDLINE = ["/usr/sbin/lsfs", "-c" ]

    def get_device_of_mount_point(self, mount_point):
        device = None

        proc = SystemCommand([self.MOUNT_TAB_BIN, '-l', mount_point])
        proc.run()

        mount_tab = proc.out.split("\n")

        regexp_string = "^%s\s+\((\S+)" % (mount_point)
        mount_regexp = re.compile(regexp_string)

        for line in mount_tab:
            match = mount_regexp.match(line)
            if match is not None:
                device = match.groups()[0]

        return device
    
    def get_mount_tab_data(self):
        """Returns a dict representing a mount-tab-like format,
        dict's key is the mount point"""
        system_command = SystemCommand(self.LSFS_CMDLINE)
        
        system_command.run()
        lsfs_output = system_command.out.split("\n")
        # Chop first comment line
        lsfs_output = lsfs_output[1:]
        data = MountTabParser(data = lsfs_output,
            regexp="^([^:]+):([^:]+):([^:]+)")

        return data.parse()
