from xiv_xsf.host.storage.nextravolume import crossplatform
from xiv_xsf.host.specific.aix import odm
import subprocess
import re
import os

class NextraVolume(crossplatform.CrossPlatformNextraVolume):
    pass

class FileSystemCacheError(Exception):
    pass
class FileSystemWithNoVolumeGroup(Exception):
    pass

DF_PATH = ['/usr/sysv/bin/df', '-l']
class FilesystemCacheHandler(object):
    def __init__(self):
        if hasattr(self.__class__, 'cached_filesystem_handler'):
            self.filesystem_handler = self.__class__.cached_filesystem_handler
        else:
            self.filesystem_handler = FilesystemHandler()
            self.__class__.cached_filesystem_handler = self.filesystem_handler

class FilesystemHandler(object):
    def __init__(self):
        self.file_system_to_volume_group = {}
        self.volume_group_to_unique_ids = {}
        self.volume_group_set = set()
        for filesystem in self.get_filesystems():
            try:
                self.file_system_to_volume_group[filesystem] = self.get_volume_group(filesystem)
            except FileSystemWithNoVolumeGroup, e:
                pass
        self.volume_group_set.update(self.file_system_to_volume_group.values())
        for volume_group in self.volume_group_set:
            self.volume_group_to_unique_ids[volume_group] = list(self.get_volume_group_unique_ids(volume_group))

    def get_filesystems(self):
        self.filesystem_list = []
        try:
            proc = subprocess.Popen(DF_PATH, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
            out, err = proc.communicate()
            fs_regexp = re.compile('^(/\S*).*$')
            for line in out.split('\n'):
                if fs_regexp.match(line) is not None:
                    yield fs_regexp.match(line).groups()[0]
        except (OSError, ValueError, subprocess.CalledProcessError), e:
            raise FileSystemCacheError('Failed executing %s: %s' % (DF_PATH, e))

    def get_volume_group(self, file_system):
        try:
            odm_util = odm.ODM()
            fs_odm_dict_list = odm_util.query("value='%s'" % file_system, 'CuAt')
            if len(fs_odm_dict_list) == 0:
                raise FileSystemWithNoVolumeGroup()
            if not fs_odm_dict_list[0].has_key('name'):
                raise FileSystemWithNoVolumeGroup()

            vg_odm_dict_list = odm_util.query("name='%s'" % fs_odm_dict_list[0]['name'], 'CuDv')
            if len(vg_odm_dict_list) == 0:
                raise FileSystemCacheError('Unexpected results from odm query %s of class %s' % ("name='%s'" % fs_odm_dict['name'], 'CuDv'))
            if not vg_odm_dict_list[0].has_key('parent'):
                raise FileSystemCacheError('Unexpected results from odm query %s of class %s' % ("name='%s'" % fs_odm_dict['name'], 'CuDv'))
            return vg_odm_dict_list[0]['parent']
        except odm.ODMError, e:
            raise FileSystemCacheError('Failed to query information from AIX ODM: %s' % e)

    def get_volume_group_unique_ids(self, volume_group):
        try:
            odm_util = odm.ODM()
            pv_record_list = odm_util.query("name='%s' and attribute='pv'" % volume_group, 'CuAt')
            if len(pv_record_list) == 0:
                raise FileSystemCacheError('Unexpected results from odm query %s of class %s' % ("name='%s' and attribute='pv'" % volume_group, 'CuAt'))

            for pv_record in pv_record_list:
                disk_pvid_odm_dict_list = odm_util.query("attribute='pvid' and value='%s'" % pv_record['value'], 'CuAt')
                if len(disk_pvid_odm_dict_list) == 0:
                    raise FileSystemCacheError('Unexpected results from odm query %s of class %s' % ("attribute='pvid' and value='%s'" % pv_record['value'], 'CuAt'))
                if not disk_pvid_odm_dict_list[0].has_key('name'):
                    raise FileSystemCacheError('Unexpected results from odm query %s of class %s' % ("attribute='pvid' and value='%s'" % pv_record['value'], 'CuAt'))
                disk_unique_id_odm_dict_list = odm_util.query("name='%s' and attribute='unique_id'" % disk_pvid_odm_dict_list[0]['name'], 'CuAt')
                if len(disk_unique_id_odm_dict_list) == 0:
                    raise FileSystemCacheError('Unexpected results from odm query %s of class %s' % ("name='%s' and attribute='unique_id'" % disk_pvid_odm_dict_list[0]['name'], 'CuAt'))
                if disk_unique_id_odm_dict_list[0].has_key('value'):
                    yield disk_unique_id_odm_dict_list[0]['value']
        except odm.ODMError, e:
            raise FileSystemCacheError('Failed to query information from AIX ODM: %s' % e)


def instanciate_from_unique_id(unique_id, generation):
    if generation == 1:
        return NextraVolume(unique_id[11:17], str(int(unique_id[17:21], 16)))
    elif generation == 2:
        return NextraVolume(unique_id[11:13]+str(int(unique_id[13:18], 16)), str(int(unique_id[18:22], 16)))
    else:
        raise crossplatform.InstanciateError('generation %s is not valid' % generation)

def instanciate_from_path(path, generation = 1):
    """
    return NextraVolume objects that are underlying the path entered, as itterable
    """
    potential_filesystem = os.path.realpath(path)
    while potential_filesystem not in FilesystemCacheHandler().filesystem_handler.file_system_to_volume_group:
        potential_filesystem = os.path.dirname(potential_filesystem)
    filesystem_handler = FilesystemCacheHandler().filesystem_handler
    for unique_id in filesystem_handler.volume_group_to_unique_ids[filesystem_handler.file_system_to_volume_group[potential_filesystem]]:
        yield instanciate_from_unique_id(unique_id, generation)

def get_filesystem_list():
    filesystem_handler = FilesystemCacheHandler().filesystem_handler
    return filesystem_handler.file_system_to_volume_group.keys()
