import inspect

class NextraVolumeError(Exception):
    pass
class InstanciateError(NextraVolumeError):
    pass

def notimplemented(func):
	def callable(*args, **kwargs):
		raise NotImplementedError
	callable.__name__ = func.__name__
	callable.notimplemented = True
	return callable

class CrossPlatformNextraVolume(object):
    """
    A cross platform Nextra Volume object
    A cache is managed to generate only one object for a volume if system_id and scsi_serial_number are identical
    """
    volume_id_cache_table = {}
    def __new__(classtype, system_id, scsi_serial_number):
        if classtype.volume_id_cache_table.has_key(system_id+scsi_serial_number):
            return classtype.volume_id_cache_table[system_id+scsi_serial_number]
        else:
            classtype.volume_id_cache_table[system_id+scsi_serial_number] = object.__new__(classtype, system_id, scsi_serial_number)
            return classtype.volume_id_cache_table[system_id+scsi_serial_number]


    def __init__(self, system_id, scsi_serial_number):
        """
        nextra_id: xxxxxx (ex: 010140)
        nextra_vol_id: xxxxxx
        """
        self.system_id = system_id
        self.scsi_serial_number = scsi_serial_number

for name, method in inspect.getmembers(CrossPlatformNextraVolume, inspect.ismethod):
    if name != '__init__':
        setattr(CrossPlatformNextraVolume, name, notimplemented(method))

