from xiv_xsf.host.storage.nextravolume import crossplatform
import win32file
import wmi

class WMIVolumePathTranslator(object):
    def __init__(self, volume_path):
        """
        return all serial numbers that belong to underlying physical media of the volume path, as itterable
        """
        self.serial_numbers = []
        if volume_path[1:4] == ':\\':   # of form 'C:'
            volume_path = volume_path[0:2]  # cut from 'C:\\' to 'C:'
        else:
            raise NotImplementedError("Path %s is located on an unsupported host configuration" % volume_path)
        for disk in wmi.WMI().Win32_LogicalDisk(DriveType = 3):
            if disk.DeviceID == volume_path:
                for partition in disk.associators(wmi_result_class="Win32_DiskPartition"):
                    for device in partition.associators(wmi_result_class="Win32_DiskDrive"):
                        for physical_media in device.associators(wmi_result_class="Win32_PhysicalMedia"):
                            self.serial_numbers.append(physical_media.SerialNumber)

class WMIVolumePathTranslatorCacheHandler(object):
    """
    A class that keeps cache of volume path names already translated to nextra serial number
    """
    volume_path_name_cache_table = {}
    def __new__(classtype, volume_path):
        if classtype.volume_path_name_cache_table.has_key(volume_path):
            return classtype.volume_path_name_cache_table[volume_path]
        else:
            classtype.volume_path_name_cache_table[volume_path] = WMIVolumePathTranslator(volume_path)
            return classtype.volume_path_name_cache_table[volume_path]

class NextraVolume(crossplatform.CrossPlatformNextraVolume):
    pass

def instanciate_from_serial_number(serial_number, generation):
    if generation == 1:
        return NextraVolume(serial_number[0:6], serial_number[6:12])
    elif generation == 2:
        return NextraVolume(serial_number[0:2]+str(int(serial_number[2:7], 16)), str(int(serial_number[7:11], 16)))
    else:
        raise crossplatform.InstanciateError('generation %s is not valid' % generation)

def instanciate_from_path(path, generation = 1):
    """
    return NextraVolume objects that are underlying the path entered, as itterable
    """
    try:
        serial_numbers = []
        volume_path = win32file.GetVolumePathName(path)
        path_translator = WMIVolumePathTranslatorCacheHandler(volume_path)

        if len(path_translator.serial_numbers) > 0:
            for serial_number in path_translator.serial_numbers:
                yield instanciate_from_serial_number(serial_number, generation)
        else:
            raise crossplatform.InstanciateError("Could not instanciate NextraVolume from path %s" % path)
    except wmi.x_wmi, e:
        raise crossplatform.InstanciateError("Could not instanciate NextraVolume from path %s due to WMI error: %s" % (path, e))

def get_filesystem_list():
    filesystem_list = []
    for disk in wmi.WMI().Win32_LogicalDisk(DriveType = 3):
        filesystem_list.append(disk.DeviceID)
    return filesystem_list

