#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 

import re
from xiv_xsf.host.specific.aix import odm

from xiv_xsf.host.storage.volume_managers.common import VolumeManagerMapping, \
    VolumeManagerVolumeError, VolumeManagerDeviceError, \
    OsVolumeManagerTools

class AixVolumeManagerTools(OsVolumeManagerTools):
    """General OS-specific volume management stuff"""
    def generate_device_datatype(self, device_list):
        """Returns a dict holding block device and character device"""
        char_block_list = []

        regexp_string = "^\/dev\/hdisk\d+"
        regexp = re.compile(regexp_string)
        for block_device in device_list:
            char_device = None
            block_device = "/dev/" + block_device # nice name -> filename

            if (regexp.search(block_device)):
                char_device = block_device.replace("hdisk", "rhdisk")

            char_block_list.append({
                "char": char_device, "block": block_device
            })
        return char_block_list

class AixLVM(VolumeManagerMapping):
    """Support the AIX Logical Volume Manager"""

    odm_util = odm.ODM()

    def get_volume_name_of_device(self, device):
        """Returns the volume name for a given device"""
        # Should it be done with odmget -q"value=mntpnt" CuAt?
        regexp_string = "^/dev/(\S+)"
        regexp = re.compile(regexp_string)
        match = regexp.match(device)
        if (match is None):
            raise VolumeManagerDeviceError(device)

        return match.groups()[0]

    def get_volume_group_of_volume(self, volname):
        """Returns the volume group name"""
        vol_group = self.odm_util.query("name=%s" % volname, "CuDv")
        if (len(vol_group) == 0 or "parent" not in vol_group[0]):
            raise VolumeManagerVolumeError(volname)

        return vol_group[0]["parent"]

    def get_physical_devices_of_volume_group(self, volume_group):
        """Returns the physical disk devices of the volume group"""
        devices = []
        pv_records_list = self.odm_util.query(\
            "name='%s' and attribute='pv'" % volume_group, 'CuAt')
        if (len(pv_records_list) == 0):
            raise VolumeManagerDiskGroupError("Bad volume group name")

        for pv_record in pv_records_list:
            disks = self.odm_util.query(
                "value='%s' and attribute='pvid'" % pv_record['value'], \
                'CuAt')
            for disk in disks:
                devices.append(disk["name"])

        return devices

    def get_physical_devices_of_mount_device(self, mount_device):
        """Gets the physical devices related to the given mount device"""
        vol_name = self.get_volume_name_of_device(mount_device)
        vol_group = self.get_volume_group_of_volume(vol_name)
        devices = self.get_physical_devices_of_volume_group(vol_group)

        devices_datatype = self.os_vm_tools.generate_device_datatype(devices)
        return devices_datatype


class VolumeManagerDetector(object):
    """Detect and inistantiate the matching Volume Manager object"""
    
    def __init__(self, device):
        self.device = device

    def detect_vm(self):
        """Checks volume type, by the way the device name looks"""
        pass

    def get_vm_object(self):
        """Returns a volume manager object, after detecting the correct
        volume manager (based on self.device)"""
        os_vm_tools = AixVolumeManagerTools()
        vm_type = self.detect_vm()

        vm_obj = AixLVM(os_vm_tools)

        return vm_obj
