#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 

import re

from xiv_xsf.host.storage.volume_managers.common import VolumeManagerMapping, \
    VeritasVM, VolumeManagerDeviceError, OsVolumeManagerTools
from xiv_xsf.utils.system_command import SystemCommand
from xiv_xsf.utils.parse import ParseUtils

class SolarisVolumeManagerTools(OsVolumeManagerTools):
    """General OS-specific volume management stuff"""
    def generate_device_datatype(self, device_list):
        """Returns a dict holding block + character devices"""
        return self.generate_device_datatype_rdsk_trick(device_list)

class SolarisNative(VolumeManagerMapping):
    """Native device mode"""
    pass

class SolarisSVM(VolumeManagerMapping):
    """Solaris Volume Manager support class"""

    # Creating SVM volumes
    # RAID5: d80 -r /dev/dsk/c3t00173800001A02EBd0s2 /dev/dsk/c3t00173800001A01AFd0s2 /dev/dsk/c3t00173800001A02C4d0s2 -k -i 40b
    # RAID1:
    #d50 -m d51 d52 1
    #d51 1 1 /dev/dsk/c3t00173800001A01AFd0s2
    #d52 1 1 /dev/dsk/c3t00173800001A02C4d0s2
    # RAID 0+1:
    #d30 -m d10 d20 1
    #d10 1 2 /dev/dsk/c3t00173800001A01AFd0s2 /dev/dsk/c3t00173800001A02C4d0s2 -i 32b
    #d20 1 2 /dev/dsk/c3t00173800001A02EBd0s2 /dev/dsk/c3t00173800001A02ECd0s2 -i 32b

    METASTAT="/usr/sbin/metastat"

    def get_physical_devices_of_mount_device(self, mount_device):
        """Returns the SVM Physical Volumes of a given volume"""
        devices = []

        cmdline = [ self.METASTAT, "-p", mount_device ]
        proc = SystemCommand(cmdline)
        proc.run()

        # TODO ???
        regexp = re.compile("\s(/dev/dsk/\S+)")

        for line in proc.out.split("\n"):
            for device in regexp.findall(line):
                devices.append(device)

        devices_datatype = self.os_vm_tools.generate_device_datatype(devices)
        return devices_datatype

class VolumeManagerDetector(object):
    """Detect and inistantiate the matching Volume Manager object"""

    def __init__(self, device):
        self.device = device

    def detect_vm(self):
        """Checks volume type, by the way the device name looks"""
        vm_types = {
            "solaris_native": ["^/dev/dsk/", "^/dev/rdsk/"],
            "vxvm": ["^/dev/vx/"],
            "svm": ["^/dev/md/"],
        }

        vm_type = ParseUtils().regexp_dictionary_match(vm_types, self.device)

        return vm_type

    def get_vm_object(self):
        """Returns a volume manager object, after detecting the correct
        volume manager (based on self.device)"""
        os_vm_tools = SolarisVolumeManagerTools()
        vm_type = self.detect_vm()

        if (vm_type == "svm"):
            vm_obj = SolarisSVM(os_vm_tools)
        elif (vm_type == "vxvm"):
            vm_obj = VeritasVM(os_vm_tools, "/dev/dsk")
        elif (vm_type == "solaris_native"):
            vm_obj = SolarisNative(os_vm_tools)
        else:
            raise VolumeManagerDeviceError(self.device)

        return vm_obj
