#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 

import clr
clr.AddReference("System.Management")

import System.Management

from xiv_xsf.host.storage.volume_managers.common import \
    VolumeManagerGeneralError

class WindowsVolumesWMI(object):
    def get_physical_devices_of_mount_device(self, mount_point):
        """Returns a list of 'physical names' for each mount point"""
        devices = []

        # TODO support mount points! currently support only drive letters
        if (len(mount_point) > 3):
            raise VolumeManagerGeneralError("Bad mount point %s" % mount_point)
        mount_point = mount_point[0:2]

        query = System.Management.WqlObjectQuery('ASSOCIATORS OF {Win32_LogicalDisk.DeviceID="'+mount_point+'"} where resultClass=Win32_DiskPartition')
        result = System.Management.ManagementObjectSearcher(query).Get()
        enum = result.GetEnumerator()

        while (enum.MoveNext()):
            partition_id = enum.Current.GetPropertyValue("DeviceID")

            query = 'ASSOCIATORS OF {Win32_DiskPartition.DeviceID="%s"} where resultClass=Win32_DiskDrive' % partition_id
            result = System.Management.ManagementObjectSearcher(query).Get()
            if (result.Count < 1):
                raise VolumeManagerGeneralError("Cannot get disk info for %s" \
                    % mount_point)
            enum2 = result.GetEnumerator()
            while (enum2.MoveNext()):
                devices.append(enum2.Current.GetPropertyValue("DeviceID"))

        return devices

class VolumeManagerDetector(object):
    """Detect and inistantiate the matching Volume Manager object"""

    def __init__(self, device):
        self.device = device

    def detect_vm(self):
        """Not needed on Windows platform"""
        return None

    def get_vm_object(self):
        """Returns a volume manager object"""
        vm_obj = WindowsVolumesWMI()

        return vm_obj
