#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 

import platform
import os

from shared import PosixTasks, PathDoesntExistError, InstantiateError
from xiv_xsf.datatypes.xiv_scsi_id import XivScsiId
from xiv_xsf.utils.osutils import OsUtils
from xiv_xsf.host.storage.volume_managers import instantiate_vm_from_device
from xiv_xsf.host.storage.filesystems import instantiate_filesystem_utils

class PathToVolumeCache(object):
    """A caching singleton, holds all data in the "cache_data" dict"""
    cache_data = {}

    def __new__(cls, *args, **kwargs):
        if not hasattr(cls, 'self'):
            cls.self = object.__new__(cls)
        return cls.self

def instantiate_from_path(path, use_cache = True):
    """Gets a path, returns a list of the XIV volumes that form its filesystem.
    Returns value is a list of XivScsiId objects.
    Using cache by default, set use_cache = False to disable
    """
    os_utils = OsUtils()
    filesystem_utils = instantiate_filesystem_utils()

    if (not os.path.exists(path)):
        raise PathDoesntExistError(path)

    mount_point = filesystem_utils.get_mount_point_of_path(path)

    # Search the cache
    if use_cache:
        path_to_volume_cache = PathToVolumeCache()
        if mount_point in path_to_volume_cache.cache_data:
            return path_to_volume_cache.cache_data[mount_point]

    os_name = os_utils.get_os_name()
    try:
        os_obj = __import__(__name__ + "." + os_name, {}, {}, [1])
    except ImportError, e:
        raise InstantiateError("OS: " + os_name + " is not supported")

    os_specific = getattr(os_obj, "OsSpecific")()

    mounted_device = filesystem_utils.get_device_of_mount_point(mount_point)

    volume_manager_object = instantiate_vm_from_device(mounted_device)

    physical_devices = volume_manager_object.\
        get_physical_devices_of_mount_device(mounted_device)

    lun_serials = []
    for physical_device in physical_devices:
        print physical_device["char"]
        lun_serial = os_specific.get_lun_serial(physical_device["char"])
        lun_serials.append(lun_serial)

    xiv_volumes = map(XivScsiId, lun_serials)

    # Update cache
    if use_cache:
        path_to_volume_cache.cache_data[mount_point] = xiv_volumes

    return xiv_volumes
