import time

from xiv.dtypes import Bunch
from xiv_xsf.nextra.p9constants import MANAFACE_NUMBERS, MANAFACE_NODES, CACHE_NODE_NUMBERS, \
    DISK_NUMBERS

MAX_LINE_LENGTH=80

class NextraExplorerResults(Bunch):
    def __init__(self, technician_name, technician_email, system_id, version, *args, **kwargs):
        super(NextraExplorerResults, self).__init__(*args, **kwargs)
        self.technician_name = technician_name
        self.technician_email = technician_email
        self.system_id = system_id
        self.collection_date = time.gmtime()
        self.explorer_version = version
        self.executed_collectors = {}

    def __repr__(self):
        return '<NextraExplorerResults (%s) for system %s>' % (self.explorer_version, self.system_id)

    def __str__(self):
        if 'collecting_basic_information' not in self.executed_collector_names():
            return 'Uninitialized %r' % self
        results = dict(self)
        results['nextra_version'] = self.version.version
        results['system_id'] = self.system_id
        results['formatted_date'] = time.strftime('%Y-%m-%d-%H%M', self.collection_date)
        results['totals'] = '%s/%s' % (len(self.nodes), len(self.disks))
        results['faulted_nodes'] = self.beautify_fault_sequence(self.faulted_nodes())
        results['faulted_disks'] = self.beautify_fault_sequence(self.faulted_disks())
        return """NextraExplorer data, collected on %(formatted_date)s by NextraExplorer %(explorer_version)s

Technician Name:    %(technician_name)s
Technician's email: %(technician_email)s
Nextra Version:     %(nextra_version)s
System ID:          %(system_id)s
Total nodes/disks:  %(totals)s
Non-alive nodes:    %(faulted_nodes)s
Non-OK disks:       %(faulted_disks)s """ % results

    def executed_collector_names(self):
        return tuple(name for name, args, kwargs in self.executed_collectors.keys())

    def faulted_nodes(self):
        result = []
        living_nodes = tuple(node.nextra_element_id for node in self.nodes if node.status_str == 'alive')
        for cache_node in CACHE_NODE_NUMBERS:
            if str(cache_node) not in living_nodes:
                result.append(str(cache_node))
        for manaface in MANAFACE_NUMBERS:
            for node_number in MANAFACE_NODES:
                expected_manaface_node = '%s%s' % (node_number, manaface)
                if expected_manaface_node not in living_nodes:
                    result.append(expected_manaface_node)
        return result
    
    def faulted_disks(self):
        result = []
        OK_disks = tuple(
            '%s.%s' % (disk.disk_id.node, disk.disk_id.disk)
            for disk in self.disks
            if disk.status == 'MANAGER_DISK_OK'
        )
        for cache_node in CACHE_NODE_NUMBERS:
            for disk_number in DISK_NUMBERS:
                expected_disk = "%s.%s" % (cache_node, disk_number)
                if expected_disk not in OK_disks:
                    result.append(expected_disk)
        return result

    def beautify_fault_sequence(self, fault_sequence):
        if len(fault_sequence) == 0:
            return 'None'
        # screen formatting crap: X chars in a line, -20 chars for indentation (hard coded), -2 chars per fault for the
        #  comman and the space
        max_faults_per_line = (MAX_LINE_LENGTH - 20) / (len(fault_sequence[0])+2)
        result = []
        for fault_index in range(0, len(fault_sequence), max_faults_per_line):
            result.append(', '.join(fault_sequence[fault_index:fault_index+max_faults_per_line]))
        return ("\n"+" "*20).join(result)
