#!/usr/bin/python

import sys
from  subprocess import Popen, PIPE, STDOUT, call
from optparse import OptionParser, make_option
import re
import os
import time
import drivers
import traceback

VERSION="2.0.2"

FIRMWARE_DEFUALT_DIRECTORY = "/root_dir/stable"
#FIRMWARE_DEFUALT_DIRECTORY = "/root/fc" ## for cruiser USB
LOG_DIR = "/tmp/"

log_file = None 

color_dict = {
    'black' : 0,
    'red' : 1,
    'green' : 2,
    'yellow' : 3,
    'blue' : 4,
    'magenta' : 5,
    'cyan' : 6,
    'white' : 7,
}

def stylify(str, name='white', lighting=1):
    addition = ''
    if lighting:
        addition = ';1'        
    return "\033[%d%sm%s\033[0m" % (color_dict[name] + 30, addition, str)

class FatalError(Exception):
    pass

NO_RESET = 0
LINK_RESET = 1
HARD_RESET = 2
RELOAD_DRIVERS = 3

class lsi_fc_port:

    def __init__(self, port_num):
        self.port_num = port_num
        self.reset_needed = NO_RESET
        self.needed_conf = {}
        self.cur_conf = {}
        
        try:
            self.get_port_current_conf()
        except:
            self.set_fc_port_conf({})
            self.get_port_current_conf()

        self.set_fc_port_conf(self.cur_conf)
            
    conf_get_REs = {
        'link_topology': (re.compile("Link Topology:\s*(?P<link_topology>Auto|NL_Port|N_Port)"), {'Auto':0, 'NL_Port':1, 'N_Port':2, },),
        'active_firmware': (re.compile("Current active firmware version is [0-9a-f]+ \((?P<active_firmware>[0-9.]+)\)"), None),
        'firmware_version': (re.compile("Firmware image's version is (?P<hba_model>[A-Z0-9]+)-(?P<firmware_version>[0-9.]+).*"), None),
        'link_speed': (re.compile("Link Speed:\s*(?P<link_speed>Auto|[0-9](?= +Gb))"), {'Auto':0}, ),
        'is_initiator': (re.compile("FCP Initiator protocol:\s*(?P<is_initiator>Disabled|Enabled)"), {'Disabled':0, 'Enabled':1},),
        'is_target': (re.compile("FCP Target protocol:\s*(?P<is_target>Disabled|Enabled)"), {'Disabled':0, 'Enabled':1}),
        'is_lan': (re.compile("LAN protocol:\s*(?P<is_lan>Disabled|Enabled)"), {'Disabled':0, 'Enabled':1}),
        'sort_by': (re.compile("Assignment of Bus/Target IDs:\s*(?P<sort_by>SortByWWN|SortByDID)"), {'SortByWWN':0, 'SortByDID':1}),
        'immediate_error_reply': (re.compile("Immediate Error Reply:\s*(?P<immediate_error_reply>Disabled|Enabled)"), {'Disabled':0, 'Enabled':1}),
        'maintain_logins': (re.compile("Maintain Logins:\s*(?P<maintain_logins>Disabled|Enabled)"), {'Disabled':0, 'Enabled':1}),
        'hard_al_pa': (re.compile("Hard AL_PA:\s*(?P<hard_al_pa>[0-9a-fA-F]+)"), None),
        'device_timeout': (re.compile("Initiator Device Timeout:\s*(?P<device_timeout>[0-9]+)"), None),
        'io_pending_timeout': (re.compile("Initiator I/O Pending Timeout:\s*(?P<io_pending_timeout>[0-9]+)"), None),
        'multi_pathing': (re.compile("Multi-pathing:\s*(?P<multi_pathing>Disabled|Enabled)"), {'Disabled':0, 'Enabled':1}),
        'int_co_switch': (re.compile("Interrupt Coalescing:\s*(?P<int_co_switch>Disabled|Enabled)(, timeout is (?P<int_co_timeout>[0-9]+) us, depth is (?P<int_co_depth>[0-9]+))?"), {'Disabled':0, 'Enabled':1})
        }

    def get_port_current_conf(self):
        start = time.time()
        
        conf_dict = {}
        unmatched = self.conf_get_REs.keys()[:]

        p = Popen(['lsiutil', '-p', "%s"%(self.port_num+1,), '-i'], stdout=PIPE, stderr=STDOUT)
        output = p.communicate()[0].split('\n')

        for line in output:
            for key in unmatched:
                expr = self.conf_get_REs[key][0]
                match = expr.match(line)
                if match:
                    conf_dict.update(match.groupdict())
                    unmatched.remove(key)
                    break
  
        ## allow the matching of firmware version to fail but make sure it will be updated
        if ('firmware' in unmatched):
            print >> log_file, "firmware not recognized for port %d"%(self.port_num)
            conf_dict['hba_model'], conf_dict['firmware_version'] = ('', '0')
            unmatched.remove('firmware')

        assert unmatched == [], "the following were not matched:\n %s\n\n%s"%("\n ".join(unmatched), "\n".join(output))
            
        if conf_dict['firmware_version'] != conf_dict['active_firmware']:
            self.set_reset_needed(HARD_RESET)

        if conf_dict['link_speed'] == 'Auto':
            conf_dict['link_speed'] = 0
        else:
            conf_dict['link_speed'] = int(conf_dict['link_speed'])

        self.cur_conf.update(conf_dict)
        self.get_fc_port_wwn()
        print >> log_file, "port %d configuration: %r"%(self.port_num, self.cur_conf,)
        print >> log_file, "getting the configuration of ioc%d took %f secs"%(self.port_num, time.time()-start)
        
    def set_fc_port_conf(self, port_conf, module_info = None):
        ioc = self.port_num
        reset = NO_RESET        
        ## add to port_conf fields we would like to assert to a certain value
        port_conf['link_topology'] = 'Auto'
        port_conf['is_lan'] = 'Disabled'
        port_conf['sort_by'] = 'SortByWWN'
        port_conf['immediate_error_reply'] = 'Enabled'
        port_conf['maintain_logins'] = 'Disabled'
        port_conf['hard_al_pa'] = 'ff'
        port_conf['device_timeout'] = '60'
        port_conf['io_pending_timeout'] = '8'
        port_conf['multi_pathing'] = 'Enabled'
        port_conf['int_co_switch'] = 'Enabled'
        port_conf['int_co_timeout'] = '200'
        port_conf['int_co_depth'] = '3'
        port_conf.setdefault('link_speed', 0)

        self.needed_conf.update(port_conf)
        
        if (module_info != None):
            self.set_fc_port_name(module_info)
            
    def set_fc_port_name(self, module_info):
        self.needed_conf['wwnn'] = '2000001738%04X00'%(module_info['system_id'])
        self.needed_conf['wwpn'] = '1000001738%04X%X%X'%(module_info['system_id'], module_info['module_id'], self.port_num)

    def set_fc_firmware_file(self, filename):
        self.firmware_filename, self.needed_conf['firmware_version'] = get_firmware_file(self.cur_conf['hba_model'], filename)
        ## the active firmware should be the same as the loaded firmware version (since we reset the adapter)
        self.needed_conf['active_firmware'] = self.needed_conf['firmware_version']
        
    def get_diff(self):
        """ returns the diff between the current conf and the needed conf
            it currently performs only one sided diff but it's ok for now. """
        diff = {}

        for key, val in self.cur_conf.items():
            if (key not in self.needed_conf):
                ## no change is needed
                print >> log_file, "ioc%d: '%s' is not defined in needed configuration, present value is '%s'"%(self.port_num, key, val)
                continue
            if (self.needed_conf[key] == val):
                continue
            diff[key] = (val, self.needed_conf[key])

        for key, val in self.needed_conf.items():
            if (key in self.cur_conf) and (self.cur_conf[key] == val):
                continue
            self.cur_conf.setdefault(key, None)
            diff[key] = (self.cur_conf[key], val)

        return diff
               
    def is_synced(self):
        diff = self.get_diff()

        for key, val in diff.items():
            print >> log_file, "%s should be changed from %s to %s for port %d"%(key, val[0], val[1], self.port_num)

        return diff == {}
        
    def sync(self):

        ioc = self.port_num
        port_conf = {}
        port_conf.update(self.needed_conf)

        if (self.is_synced()):
            print >> log_file, "port %d is already synced"%(ioc,)
            return
        print >> log_file, "target configuration for port %d: %r"%(ioc, port_conf)
        
        reset = self.calc_reset_needed()
        
        for key in port_conf:
            if ((key in self.conf_get_REs) and (self.conf_get_REs[key][1])):
                translator = self.conf_get_REs[key][1]
                if (port_conf[key] in translator):
                    port_conf[key] = translator[port_conf[key]]
            port_conf[key] = str(port_conf[key])
                            
        conf = [str(ioc+1), '13', 
                port_conf['link_topology'], 
                port_conf['link_speed'], 
                port_conf['is_initiator'],
                port_conf['is_target'],
                port_conf['is_lan'],
                port_conf['sort_by'],
                port_conf['immediate_error_reply'],
                port_conf['maintain_logins'],
                port_conf['hard_al_pa'],
                port_conf['device_timeout'],
                port_conf['io_pending_timeout'],]
        
        run_lsiutil(conf)
        if (port_conf['int_co_switch']):
            run_lsiutil([str(ioc+1), '10', port_conf['int_co_switch'], port_conf['int_co_timeout'], port_conf['int_co_depth']])
        else:
            run_lsiutil([str(ioc+1), '10', port_conf['int_co_switch']])
            
        run_lsiutil([str(ioc+1), '14', '1'])
        
        if ('wwnn' in port_conf) or ('wwpn' in port_conf):
            self.sync_fc_port_name()

        if ('firmware_version' in port_conf):
            self.sync_fc_firmware()

        self.set_reset_needed(reset)
        
    def get_fc_port_wwn(self):
        ioc = self.port_num
        for line in open('/proc/mpt/ioc%d/info'%(ioc,), 'r').readlines():
            m = re.match('\s+WWN\s+=\s+(?P<wwnn>[0-9a-fA-F]+):(?P<wwpn>[0-9a-fA-F]+)', line)
            if (m != None):
                break
            
        if m == None:
            raise FatalError("Error: cannot get wwn for port %d"%(self.port_num,))

        self.cur_conf['wwnn'] = m.group('wwnn')
        self.cur_conf['wwpn'] = m.group('wwpn')

        print >> log_file, "port %d wwn: %s:%s"%(self.port_num, self.cur_conf['wwnn'], self.cur_conf['wwpn'])

    def sync_fc_firmware(self):
        if self.needed_conf['firmware_version'] == self.cur_conf['firmware_version']:
            return
        if 'firmware_filename' not in self.__dict__:
            raise FatalError("Error: no firmware filename supplied for port %d"%(self.port_num,))
        if not os.path.exists(self.firmware_filename):
            raise FatalError("Error: firmware file '%s' does not exist"%(self.firmware_filename,))
        run_lsiutil([str(self.port_num+1), '2', self.firmware_filename, 'Yes', '0', '0'])
        self.set_reset_needed(HARD_RESET)

        print >> log_file, "firmware of ioc%d upgraded from %s to %s using '%s'"%(self.port_num, self.cur_conf['firmware_version'], 
                                                                                  self.needed_conf['firmware_version'], self.firmware_filename)
        
    def sync_fc_port_name(self):
        ioc = self.port_num
        wwnn = self.needed_conf['wwnn']
        wwpn = self.needed_conf['wwpn']

        print >> log_file, "setting wwpn for port ioc%d"%(ioc,)

        self.get_fc_port_wwn()
        
        if (wwnn == self.cur_conf['wwnn']) and (wwpn == self.cur_conf['wwpn']):
            print >> log_file, "ioc%d wwpn is already set"%(self.port_num)
            return NO_RESET

        base = ((ioc % 2) * 0x20) + 0x8
        conf = [str(ioc+1), '9', '9', '3', '??', 'yes', "%x"%(base,), wwpn[8:], "%x"%(base+4,), wwpn[:8], "%x"%(base+8,), wwnn[8:], "%x"%(base+0xc,), wwnn[:8], '', 'yes', '', '0', '0']
        conf[4] = '0'
        run_lsiutil(conf)
        conf[4] = '1'
        run_lsiutil(conf)

        conf = [str(ioc+1), '9', '5', '1', '??', 'yes', '0008', wwnn[8:], '000c', wwnn[:8], '0010', wwpn[8:], '0014', wwpn[:8], '', 'yes', '', '0', '0']
        conf[4] = '0'
        run_lsiutil(conf)
        conf[4] = '1'
        run_lsiutil(conf)

        self.set_reset_needed(RELOAD_DRIVERS)

    def set_reset_needed(self, reset_level, force=False):
        if (self.reset_needed < reset_level) or (force):
            self.reset_needed = reset_level

    def calc_reset_needed(self):
        diff = self.get_diff()
        if not diff:
            return NO_RESET
        
        reset = LINK_RESET
        if [x for x in ['is_initiator', 'is_target', 'is_lan', 'firmware_version'] if x in diff] != []:
            reset = RELOAD_DRIVERS ## in p9 mptbase must be reloaded after changing roles
        return reset

    def do_reset(self, implicit_reset = NO_RESET):
        if (implicit_reset >= self.reset_needed):
            print >> log_file, "ioc%d has been implicitly reset. level=%d"%(self.port_num, implicit_reset)
            self.reset_needed = NO_RESET
        reset = self.reset_needed

        if reset == NO_RESET:
            return NO_RESET
        elif reset == LINK_RESET:
            print >> log_file, "performing link reset on ioc%d"%(self.port_num,)
            run_lsiutil([str(self.port_num+1), '98'])
            self.reset_needed = NO_RESET
            return LINK_RESET
        elif reset == HARD_RESET:
            print >> log_file, "ioc%d has been reset"%(self.port_num)
            run_lsiutil([str(self.port_num+1), '99'])
        elif reset == RELOAD_DRIVERS:
            print >> log_file, "ioc%d requires MPT drivers to be reloaded"%(self.port_num)
            run_lsiutil([str(self.port_num+1), '99'])
            return RELOAD_DRIVERS

        self.get_port_current_conf()

        self.reset_needed = NO_RESET
        return reset

    def get_module_name(self):
        return str(int(self.cur_conf['wwpn'][-6:-2], 16)), self.cur_conf['wwpn'][-2:-1]

def get_avail_ports():
    rc = []
    ioc_re = re.compile("ioc(?P<ioc_idx>[0-9]+):.*")
    for line in open('/proc/mpt/summary'):
        ioc = int(ioc_re.match(line).group('ioc_idx'))
        rc.append(int(ioc))
    rc.sort()
    return rc

def get_firmware_file(model, fw_file="auto"):
    if (fw_file == "auto"):
        firmware_dir = FIRMWARE_DEFUALT_DIRECTORY
        all_files = os.listdir(firmware_dir)
        firmware_files = filter(lambda x: model.upper() in x.upper(), all_files)

        assert len(firmware_files) == 1, "more or less than one firmware file exist for model %s (%s)"%(model, ", ".join(firmware_files))
        fw_file = os.path.join(firmware_dir, firmware_files[0])
    
        print >> log_file, "found firmware file '%s'"%(fw_file ,)

    fw_ver_match = re.compile(".*([0-9]+\.[0-9]+\.[0-9]+)\.rom").match(os.path.basename(fw_file))
    if (fw_ver_match is None):
        raise FatalError("firmware file '%s' is not a valid firmware file"%(fw_file,))

    if (model.upper() not in fw_file.upper()):
        raise FatalError("firmware file '%s' cannot be installed on HBA of model '%s'"%(fw_file, model))
    fw_version = fw_ver_match.group(1)
    
    return fw_file, fw_version


def run_lsiutil(input):
    start = time.time()

    input_str = "\n".join(input) + '\n0\n0\n'
    print >> log_file, 'running "printf %r | lsiutil"'%(input_str)
    p = Popen(['lsiutil'], shell=True, stdout=PIPE, stdin=PIPE, stderr = STDOUT)
    print >> p.stdin, input_str
    sts = os.waitpid(p.pid, 0)
    stdout = p.stdout.read()
    
    print >> log_file, 'running "printf %r | lsiutil" took %f secs'%(input_str, time.time()-start)
    
    if sts[1] != 0:
        print >> log_file, "running 'printf %r | %s' failed with code %d"%(input_str, cmdline, sts[1],)
        print >> log_file, stdout
        raise FatalError('lsiutil returned with a failure %d'%(sts))

def get_default_input(conf):
    if (conf.wwpn == None):
        raise FatalError("Error: -w must be used when -d is used")
    if (conf.default_port_setting not in ['p9.1', 'p9.2']):
        raise FatalError("Error: invalid phase '%s' given with -d option, must be either '-d p9.1' or -d 'p9.2'"%(conf.default_port_setting))
    if (conf.ports):
        raise FatalError("Error: -p can't be used when -d is used")

    avail_ports = get_avail_ports()
    conf.ports = []

    for port in avail_ports[:-1]:
        conf.ports.append((port, 'target', 0))
    conf.ports.append((avail_ports[-1], 'initiator', 0))

    phase = conf.default_port_setting
    if (not conf.firmware):
        if (phase == 'p9.2'):
            conf.firmware = os.path.join(FIRMWARE_DEFUALT_DIRECTORY, "lsifc929xl-1.02.24.rom")
        elif (phase == 'p9.1'):
            conf.firmware = os.path.join(FIRMWARE_DEFUALT_DIRECTORY, "lsifc929xl-1.02.14.rom")

    return conf

def normalize_input():
    parser = OptionParser( usage = "usage: %prog [options]",
                           option_list = [ make_option("-u", "--update_firmware",action="store",
                                                       type="string", nargs=1, dest="firmware",
                                                       help="updates the firmware of all the HBAs to the given firmware or find one if 'auto' is given"),
                                           make_option("-w", "--wwpn", action="store",
                                                       type="int", nargs=2, dest="wwpn", metavar="SYSTEM_ID MODULE_ID",
                                                       help="-w <system id e.g. 10123> <module id e.g. 1>: sets the wwnn & wwpn of all the ports to the XIV format"),
                                           make_option("-p", "--port", action="append",
                                                       nargs=3, dest="ports", metavar="PORT_NUM ROLE LINK_SPEED",
                                                       help="-p <port num> <role: initiator/target/both> <link speed in Gbps: 0 for Auto negotiation> set port configuration"),
                                           make_option("-d", "--default_port_setting", action="store",
                                                       type="string", nargs=1, dest="default_port_setting",
                                                       help="sets the ports configuration to the default setting according to the phase given (p9.1 or p9.2), if -d is used -w must also be used to specify module & system IDs."),
                                           make_option("-t", "--test_only", action="store_true",
                                                       dest="test_only", default=False,
                                                       help="Don't make any changes to the adapters just check that the configuration is as specified."),
                                           
                                           ]
                           )

    if (len(sys.argv) < 2):
        print
        print "config_system_fc.py Ver %s"%(VERSION,)
        print
        parser.print_help()
        print
        print "e.g. '%s -p 0 i 0 -p 1 t 0 -p 2 b 0' will set port 0 as initiator 1 as target and 2 as both initiator and target (all with auto negotiated link speed)"%(sys.argv[0],)
        print
        print "Notice: the script currently makes no effort to load the neccsary drivers.",
        print "manual intervention may be needed to load mptctl"
        return None
    
    conf, junk = parser.parse_args(sys.argv[1:])
    
    ## now check the given arguments, normalize them and use defaults if needed

    ## wwpn
    if conf.wwpn is not None:
        wwpn_dict = dict(zip(['system_id', 'module_id'], conf.wwpn))
        wwpn_dict['system_id'] = wwpn_dict['system_id'] % 100000
        wwpn_dict['module_id'] = wwpn_dict['module_id'] % 0x10        
        conf.wwpn = wwpn_dict

    ## are we going for default settings ?
    if conf.default_port_setting:
        conf = get_default_input(conf)
    elif conf.ports == None:
        conf.ports = []

    ports_dict = {}
    for x,y,z in conf.ports:
        ports_dict[int(x)] = {'role':y.lower(), 'link_speed':int(z)}
    conf.ports = {}

    avail_ports = get_avail_ports()
            
    for ioc in ports_dict:
        port = ports_dict[ioc]
        if ioc not in avail_ports:
            print >> log_file, "%r %r"%(avail_ports, ioc)
            print >> log_file, "ioc%d does not exist on this system"%(int(ioc),)
            continue
        port['is_initiator'] = 'Disabled'
        port['is_target'] = 'Disabled'
        port['is_lan'] = 'Disabled'        
        if 'initiator'.startswith(port['role']):
            port['is_initiator'] = 'Enabled'
        elif 'target'.startswith(port['role']):
            port['is_target'] = 'Enabled'
        elif 'both'.startswith(port['role']):
            port['is_initiator'] = 'Enabled'
            port['is_target'] = 'Enabled'
        else:
            raise FatalError('role "%s" unrecognized'%(port['role'],))
        del port['role']
        conf.ports[ioc] = port
    return conf

def test_all(ports):
    rc = 0
    for port in ports.values():
        if (port.is_synced()):
            system, module = port.get_module_name()
            port.get_fc_port_wwn()
            print stylify('port %d on system %s module %s is OK - FW version is %s, wwpn=%16s'%(port.port_num, system, module, port.cur_conf['firmware_version'], port.cur_conf['wwpn']), 'cyan')
        else:
            rc = -1
            print stylify('port %d is NOT configured correctly, fix:'%(port.port_num,), 'red')
            for key, val in port.get_diff().items():
                print "\t", key, "is '%s' should be '%s'"%val

    return rc

def perform_resets(ports):
    reload_drivers = False    
    ## assume that bound ports has consecutive id numbers
    for port in ports.values():
        print "Reseting port %d"%(port.port_num,)
        ## the firmware download affects both bound ports and is invisible until the hard reset so we should 'link' the bound ports together
        reset = port.do_reset()
        if reset == HARD_RESET:
            ## find the bound port
            bound_port_num = port.port_num + 1 - (port.port_num % 2)*2
            if bound_port_num in ports:
                ports[bound_port_num].do_reset(implicit_reset = HARD_RESET)
        elif reset == RELOAD_DRIVERS:
            reload_drivers = True
    if reload_drivers:
        print "Reloading Drivers..."
        print >> log_file, "Reloading Drivers..."
        if not drivers.reload_mpt():
            raise FatalError("can't reload drivers")            
        for port in ports.values():
            port.do_reset(implicit_reset = RELOAD_DRIVERS)

def main():
    global log_file

    drivers.load_mpt()
    configuration = normalize_input()
    if configuration == None:
        return -1

    if configuration.wwpn is not None:
        ## we have a system defined, reroute the log_file to a module specific log file.
        log_file = open(os.path.join(LOG_DIR, 'config_system_fc_%(system_id)d.10%(module_id)d.log'%configuration.wwpn), 'a+')        
        print >> log_file, "="*80
        print >> log_file, time.ctime(), ":", " ".join(sys.argv)

    if not configuration.test_only:
        print "Reloading Drivers..."
        rc = drivers.reload_mpt()
        if (not rc):
            raise FatalError("can't reload drivers")

    ports = dict([(x, lsi_fc_port(x)) for x in get_avail_ports()])

    if configuration.wwpn:
        for port in ports.values():
            port.set_fc_port_name(configuration.wwpn)

    if configuration.firmware:
        for port in ports.values():
            port.set_fc_firmware_file(configuration.firmware)
            
    for ioc, port_conf in configuration.ports.items():
        port = ports[ioc]
        port.set_fc_port_conf(port_conf)

    if not configuration.test_only:
        print "Setting Ports Configuration..."
        for port in ports.values():
            port.sync()
        perform_resets(ports)
        for port in ports.values():
            port.get_port_current_conf()

    return test_all(ports)

if __name__ == '__main__':
    log_file = open(os.path.join(LOG_DIR, 'config_system_fc.log'), 'a+')
    print >> log_file, "="*80
    print >> log_file, time.ctime(), ":", " ".join(sys.argv)
    try:
        rc = main()
    except:
        type, value, tb = sys.exc_info()
        print >> log_file, "\nException Occured:"
        print >> log_file, "".join(traceback.format_exception( type, value, tb))     
        print "".join(traceback.format_exception( type, value, tb))     
        rc = -1
    print >> log_file, "%s: '%s' is quitting"%(time.ctime(), " ".join(sys.argv))
    sys.exit(rc)

