"""
facilitates the management of Phase9 Nextra systems from Python

READ ME I'M ACTUALLY HELPFUL:
The main classes available to a p9client user are Nextra and NextraState. Nextra objects enable the creation, delivery and basic parsing of Nextra XCLI commands. NextraState objects contain a Nextra object and automagically do the required XCLI commands to provide a more holistic Pythonic view of a Nextra systems as a Python object, complete with inter-object relations. p9client users are assumed to be familiar with the Nextra, its key concepts and commands. Good (not best) Python familiarity is also required; if you don't know what a generator is, you better learn. In p9client.instantiators you will find several helper function that will help you create new Nextra objects easily.

Some good recommendations:
 * read help(p9client.instantiators)
 * try instantiating a Nextra with an instantiator
 * assuming your Nextra object is called n, try:
   - for volume in n.vol_list(): print volume.name
   - n.config_get().as_single_element
 * try instantiating a NextraState object with an instantiator
 * assuming your Nextra object is called ns, try:
   - list(ns.objects.volumes[5].mapped_for_hosts)
 * read the basic example below; p9client lets you concentrate on logic, not API usage (I hope)

Example:
>>> from xiv_xsf.nextra import p9client
>>> n140 = p9client.instantiators.xiv_net('10.140')
>>> n250 = p9client.Nextra({101: '10.10.250.101'})
>>> n140_volume_names = list(volume.name for volume in n140.vol_list())
>>> n250_volume_names = list(volume.name for volume in n250.vol_list())
>>> print '%s and %s share the volumes %s' % \
...     (n140.config_get().as_single_element.machine_id,
...     n250.config_get().as_single_element.machine_id,
...     ', '.join(volume_name for volume_name in n140_volume_names if volume_name in n250_volume_names))
10140 and 10250 share the volumes bll_h1_1, bll_h1_2, bll_h1_3, bll_h1_4, bll_h1_5, bll_h2_1, bll_h2_2, bll_h2_3, bll_h2_4, bll_h2_5, bll_cl_1, bll_cl_2, bll_cl_3, bll_cl_4, bll_cl_5
>>> 

"""
__author__ = 'yaniva@il.ibm.com'
__version__ = '1.0'

DEFAULT_OPTIONS = {'xiv-mode': 'yes'}
import exceptions
import instantiators
from xcli import Nextra
from state import NextraState
