class NextraClientException(Exception):
    def __init__(self, *args, **extra_parameters):
        Exception.__init__(self, *args)
        self.extra_parameters = extra_parameters

class CantInstantiateError(NextraClientException):
    pass

class DeliveryFailedError(NextraClientException):
    pass

class ExecutionFailedError(NextraClientException):
    pass

class NotSupportedError(NextraClientException):
    pass

class ElementResolutionFailed(NextraClientException):
    """Thrown when an element is expected inside a NextraState object but couldn't be found. For example, ElementResolutionFailed might be raised when trying to get the Map element of a given Volume, but the former couldn't be found. The most likely cause for this is a NextraState object instantiated on a Nextra which was undergoing changes during instantiation (i.e., the NextraState object is inconsistent).
    """
    def __init__(self, type, name, parent, requester=None):
        self.name = name
        self.type = type
        self.requester = requester
        self.parent = parent

    def __str__(self):
        result = "Can't resolve %s %s '%s'" % (self.parent, self.type.description, self.name)
        if self.requester is not None:
            result += ' requested by %r' % self.requester
        return result

class GUIConfigurationNotFoundError(NextraClientException):
    pass

