from elementtree import ElementTree
from xiv import osutils
import exceptions
import sys
import os

class GUIConfig(object):
    """This class reads the GUI's XML files and returns a list of configured Nextra machines."""
    NEXTRA_VERSIONS = ['Nextra10', 'Nextra9']
    PLATFORMS = dict(darwin='unix', nt='windows', posix='unix')
    def __init__(self):
        self.raw = self.load_configuration_xml_file()
        self.elements = ElementTree.fromstring(self.raw)
        self.nextras = self.process_configuration_elements(self.elements)

    def load_configuration_xml_file(self):
        path = getattr(self, 'find_nextra_gui_dir_on_%s' % self.PLATFORMS[sys.platform])()
        return file(os.path.join(path, 'xiv-systems.xml'), 'r').read()

    @staticmethod
    def find_nextra_gui_dir_on_unix():
        paths = []
        for version in GUIConfig.NEXTRA_VERSIONS:
            path = os.path.join(osutils.getuserhome(), '.xiv', version, 'properties')
            paths.append(path)
            if os.path.isdir(path):
                return path
        raise exceptions.GUIConfigurationNotFoundError("attempted paths %s" % paths)

    @staticmethod
    def find_nextra_gui_dir_on_windows():
        raise exceptions.NotSupportedError()

    def process_configuration_elements(self, elements):
        systems = {}
        for system_element in elements.findall('system'):
            system_name = system_element.find('name').attrib['value']
            systems[system_name] = {}
            for management_element in system_element.findall('management'):
                module_number = '10' + management_element.attrib['id']
                module_ip = management_element.find('ip').attrib['value']
                systems[system_name][module_number] = module_ip
        return systems
