import types
from xiv_xsf.nextra.p9client.common import string_amount
from xiv_xsf.nextra.p9client import exceptions
from xiv.pyutils import weakref
from xiv.strutils import plural

class ElementPartition(types.ListType):
    def __init__(self, element_type, nextrastate_parent, internal, sequence=()):
        super(ElementPartition, self).__init__(
            element_type(nextrastate_parent, element, internal) for element in sequence
        )
        self.element_type = element_type
        self.nextrastate_parent = weakref(nextrastate_parent)
        self.internal = internal

    def __repr__(self):
        if self.internal:
            partition = 'Internal '
        else:
            partition = ''
        return '<%sElementPartition of %s %s; %s>' % (partition, self.nextrastate_parent, 
            plural(self.element_type.description), string_amount(self, self.element_type.description))

    def __getitem__(self, lookup_key):
        if type(lookup_key) is types.IntType:
            return super(ElementPartition, self).__getitem__(lookup_key)
        if type(lookup_key) is types.StringType:
            for element in self:
                if getattr(element, self.element_type.name_attribute) == lookup_key:
                    return element
            raise exceptions.ElementResolutionFailed(lookup_key, self.element_type, self.nextrastate_parent)
        raise TypeError('ElementPartitions supports lookup by integer or string along')

class ElementContainer(object):
    """
    """
    def __init__(self, nextrastate_parent, element_type):
        self.nextrastate_parent = weakref(nextrastate_parent)
        self.element_type = element_type
        self.external = self._fetch_element_partition()
        if element_type.has_internal_partition:
            self.internal = self._fetch_element_partition(internal=True)

    def _fetch_element_partition(self, internal=False):
        fetch_command_arguments = {}
        if internal:
            fetch_command_arguments['internal'] = 'yes'
        raw_elements = \
            getattr(self.nextrastate_parent.system, self.element_type.fetching_command)(fetch_command_arguments)
        return ElementPartition(self.element_type, self.nextrastate_parent, internal, raw_elements)
        
    def __repr__(self):
        result = '<ElementContainer; external: %s' % string_amount(self.external, self.element_type.description)
        if hasattr(self, 'internal'):
            result += '; internal: %s' % string_amount(self.internal, self.element_type.description)
        return result+'>'

    def get_element_partition(self, internal=False):
        if internal:
            if not hasattr(self, 'internal'):
                raise TypeError('%s does not support internal elements' % self.element_type.__name__)
            return self.internal
        else:
            return self.external

    def __getitem__(self, lookup_key):
        return self.external.__getitem__(lookup_key)

    def __iter__(self):
        return self.external.__iter__()

