import re

def _verify_octets(string, expected_octets=None):
    match = re.compile('^([0-9.]+)$').match(string)
    if match is None or match.groups()[0] != string:
        raise ValueError("%r has invalid characters" % (string))
    octets = string.split('.')
    if expected_octets is not None and len(octets) != expected_octets:
        raise ValueError("%s has %d octets, expected %d" % (string, len(octets), expected_octets))
    for octet in octets:
        if int(octet) < 1 or int(octet) > 254:
            raise ValueError("octet %s of %s is invalid" % (octet, string))

def verify_dotted_system_id_string(system_id_octet_str):
    return _verify_octets(system_id_octet_str, expected_octets = 2)

def system_id_string_to_high_octet(system_id_str):
    return int(system_id_str[:len(system_id_str)-3])

def system_id_string_to_low_octet(system_id_str):
    return int(system_id_str[len(system_id_str)-3:])

def raw_system_id_string_to_dotted_octet_string(system_id_str):
        return '%s.%s' % (system_id_string_to_high_octet(system_id_str), system_id_string_to_low_octet(system_id_str))

def reraise_value_error_as_cant_instantiate_error(func):
    """
    This patch function is necessary because older versions of p9client would raise exceptions.CantInstantiateError upon receiving invalid initializationg parameters (incorrect system_id, for example). Since system_id handling functions were extracted to system_id_utils, this decorator preserves identical functionality for the instantiators.
    The 'more Pythonically correct way', btw, is of course to raise ValueError and not exceptions.CantInstantiateError.
    """
    def callable(*args, **kwargs):
        try:
            return func(*args, **kwargs)
        except ValueError, e:
            raise exceptions.CantInstantiateError(str(e))
    callable.__doc__ = func.__doc__
    callable.__name__ = func.__name__
    return callable
