class BaseNextraClientException(Exception):
    def __init__(self, message=None, original_exception=None):
        if message is None and original_exception is None:
            raise ValueError("either message or original_exception must be set")
        self.message = message
        self.original_exception = original_exception
    def __str__(self):
        if self.message:
            return self.message
        return str(self.original_exception)

class NextraClientException(BaseNextraClientException):
    pass
class CantInstantiateError(NextraClientException):
    @staticmethod
    def choose_best_fit_instantiation_exception_class(error):
        try:
            error_code = error.response_etree.xeval('command/code/@value')
            for credential_exception in (IncorrectUsername, IncorrectPassword):
                if error_code == credential_exception.CODE:
                    return credential_exception
        except LookupError:
            return UnparseableErrorCodeDuringInstantiation
        return CantInstantiateError
class UnparseableErrorCodeDuringInstantiation(CantInstantiateError):
    pass
class IncorrectCredentials(NextraClientException):
    pass
class IncorrectUsername(IncorrectCredentials):
    CODE = 'USER_NAME_DOES_NOT_EXIST'
class IncorrectPassword(IncorrectCredentials):
    CODE = 'INCORRECT_PASSWORD'
class UnsupportedNextraVersion(CantInstantiateError):
    pass
