from xiv_xsf.nextra.phase10.client.exceptions import BaseNextraClientException
from xiv_xsf.nextra.phase10.client.xcli.transport import TransportSendError, TransportReceiveError
from xiv_xsf.nextra.phase10.client.xcli.delivery.exceptions import DeliveryFailure, DeliveryAmbiguity

class AServerError(BaseNextraClientException):
    pass

class XCLIDelivery(object):
    def __init__(self, transport, command):
        self.transport = transport
        self.command = command
        self.delivery_exceptions = []
        self.potential_endpoints = list(transport.endpoints)

    def execute(self):
        for attempt in range(0, self.transport.ALLOWED_DELIVERY_ATTEMPTS):
            try:
                return self._do_delivery_cycle()
            except (TransportSendError, AServerError), error:
                self.delivery_exceptions.append(error)
            except (TransportReceiveError), error:
                self.delivery_exceptions.append(error)
                raise self._build_ambiguity_exception()
            self._replace_endpoint_if_possible()
        raise self._build_exception('retries exhausted')

    def _build_failure_exception(self, message):
        return DeliveryFailure(message=message, delivery_exceptions=self.delivery_exceptions)

    def _build_ambiguity_exception(self):
        return DeliveryAmbiguity(message='reception failure', delivery_exceptions=self.delivery_exceptions)

    def _do_delivery_cycle(self):
        self.transport.send_command_xml(self.command.xml)
        response_etree = self.transport.receive_response_etree()
        return self._extract_command_etree(response_etree)

    def _extract_command_etree(self, response_etree):
        try:
            aserver_status = response_etree.xeval('command/aserver/@status')
        except LookupError, error:
            raise AServerError(message='aserver status missing', original_exception=error)
        if aserver_status != 'DELIVERY_SUCCESSFUL':
            raise AServerError(message='invalid aserver status %s' % aserver_status)
        try:
          inner_command = response_etree.xeval('command/administrator/command')
        except LookupError, e:
          inner_command = response_etree.xeval('command/command/administrator/command')
        return inner_command
    def _replace_endpoint_if_possible(self):
        self.potential_endpoints.remove(self.transport.connected_endpoint)
        if not self.potential_endpoints:
            raise self._build_exception('enpoints exhausted')
        try:
            self.transport.connect(self.potential_endpoints)
        except UnableToConnect, error:
            raise self._build_exception('reconnect failed')
