from xiv_xsf.nextra.phase10.client.exceptions import NextraClientException

class XCLIException(NextraClientException):
    RELEVANT_XPATH = None
    def __init__(self, command, response_etree):
        self.command = command
        self.response_etree = response_etree
    def raise_if_necessary(self):
        assert self.RELEVANT_XPATH is not None, 'should subclass'
        if self.should_raise():
            raise self
    @property
    def relevant_value(self):
        return self.response_etree.xeval(self.RELEVANT_XPATH)
    def __repr__(self):
        return '<%s: %s>' % (self.__class__.__name__, self.relevant_value)

class ExecutionFailedError(XCLIException):
    "Base class for execution failures"
    RELEVANT_XPATH = 'command/status/@value'
    def should_raise(self):
        return self.relevant_value in self.RELEVANT_RETURN_CODES_MAP
    def __str__(self):
        return '%s: %s' % (self.RELEVANT_RETURN_CODES_MAP[self.relevant_value], self.response_status_str)
    @property
    def response_status_str(self):
        return self.response_etree.xeval('command/status_str/@value')

class UnknownExecutionFailedError(ExecutionFailedError):
    "Raised when execution failure code doesn't match any known code"
    SUCCESS_VALUE = "0"
    def should_raise(self):
        return self.relevant_value not in HardExecutionFailedError.RELEVANT_RETURN_CODES_MAP and \
               self.relevant_value not in SoftExecutionFailedError.RELEVANT_RETURN_CODES_MAP and \
               self.relevant_value != self.SUCCESS_VALUE
    def __str__(self):
        return 'unknown execution failure of %s' % self.command

class HardExecutionFailedError(ExecutionFailedError):
    "Raised when execution failed due to an internal issue (halted node, timeout, etc)."
    RELEVANT_RETURN_CODES_MAP = {"1": "Connection Error", "4": "Passive Manager", "5": "Internal Error",
                                 "6": "Obsolete Command"} # from cli_retcodes.h in spec

class SoftExecutionFailedError(ExecutionFailedError):
    "Raised when execution failed due to designed behaviour (syntax error, delete a non-existent element, etc)"
    RELEVANT_RETURN_CODES_MAP = {"2": "Syntax Error", "3": "Runtime Error"} # from cli_retcodes.h in spec

class ExecutionWarning(XCLIException): 
    "Raised when execution wasn't carried out because the confirmation flag was missing"
    RELEVANT_XPATH = 'command/warning/@value'
    def __str__(self):
        return '"are you sure" warning for command %s' % self.command
    def should_raise(self):
        try:
            return self.relevant_value == 'yes'
        except LookupError:
            return False

ORDER_OF_CONCRETE_XCLI_EXCEPTIONS = (ExecutionWarning, HardExecutionFailedError,
                                     SoftExecutionFailedError, UnknownExecutionFailedError)
