from weakref import proxy

class CommandStub(object):
    def __init__(self, parent, command):
        super(CommandStub, self).__init__()
        self.parent = proxy(parent)
        self.name = command.name
        self.description = command.description
        self.syntax = command.syntax
        self.category = command.category
        self.__doc__ = "%s: %s (syntax: %s, category: %s)" % (self.name, self.description, self.syntax, self.category)

    def _get_category(self):
        return self._category
    def _set_category(self, raw):
        self._category = raw.replace('-', '_')
        if self._category == '':
            self._category = 'unspecified'
    category = property(_get_category, _set_category)

    def __str__(self):
        return self.name
    def __repr__(self):
        return "<command %s.%s>" % (self.parent, self.name)

    def __call__(self, *args, **kwargs):
        return self.parent._execute(self.name, **kwargs)
