class LocalTransportError(Exception):
    "Base class for internal transport errors; these will be masked by a higher level delivery error."
    def __init__(self, endpoint, message=None, original_exception=None):
        if message is None and original_exception is None:
            raise ValueError("either message or original_exception must be set")
        self.endpoint = endpoint
        self.message = message
        self.original_exception = original_exception
    def __str__(self):
        if self.message:
            return self.message
        return str(self.original_exception)
class TransportSendError(LocalTransportError):
    pass
class TransportReceiveError(LocalTransportError):
    pass

class NextraClientTransport(object):
    def connect(self):
        raise NotImplementedError("should be subclassed")
    def send_command_xml(self, command):
        raise NotImplementedError("should be subclassed")
    def receive_response_etree(self):
        raise NotImplementedError("should be subclassed")
    def __repr__(self):
        if self.connected_endpoint:
            return '<%s (%s)>' % (self.__class__.__name__, self.connected_endpoint)
        return '<%s>' % self.__class__.__name__
    def __str__(self):
        if self.connected_endpoint:
            return str(self.connected_endpoint)
        return 'disconnected'
