#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 
from construct import *

# set of Additional Sense Code data generated from the asc-num.txt file.
# use generate_asc.py to update these values

additional_sense_code = SymmetricMapping(UBInt16("additional_sense_code"),
       mapping = {
  "NO ADDITIONAL SENSE INFORMATION" : 0x0000,
  "FILEMARK DETECTED" : 0x0001,
  "END-OF-PARTITION/MEDIUM DETECTED" : 0x0002,
  "SETMARK DETECTED" : 0x0003,
  "BEGINNING-OF-PARTITION/MEDIUM DETECTED" : 0x0004,
  "END-OF-DATA DETECTED" : 0x0005,
  "I/O PROCESS TERMINATED" : 0x0006,
  "PROGRAMMABLE EARLY WARNING DETECTED" : 0x0007,
  "AUDIO PLAY OPERATION IN PROGRESS" : 0x0011,
  "AUDIO PLAY OPERATION PAUSED" : 0x0012,
  "AUDIO PLAY OPERATION SUCCESSFULLY COMPLETED" : 0x0013,
  "AUDIO PLAY OPERATION STOPPED DUE TO ERROR" : 0x0014,
  "NO CURRENT AUDIO STATUS TO RETURN" : 0x0015,
  "OPERATION IN PROGRESS" : 0x0016,
  "CLEANING REQUESTED" : 0x0017,
  "ERASE OPERATION IN PROGRESS" : 0x0018,
  "LOCATE OPERATION IN PROGRESS" : 0x0019,
  "REWIND OPERATION IN PROGRESS" : 0x001A,
  "SET CAPACITY OPERATION IN PROGRESS" : 0x001B,
  "VERIFY OPERATION IN PROGRESS" : 0x001C,
  "ATA PASS THROUGH INFORMATION AVAILABLE" : 0x001D,
  "CONFLICTING SA CREATION REQUEST" : 0x001E,
  "NO INDEX/SECTOR SIGNAL" : 0x0100,
  "NO SEEK COMPLETE" : 0x0200,
  "PERIPHERAL DEVICE WRITE FAULT" : 0x0300,
  "NO WRITE CURRENT" : 0x0301,
  "EXCESSIVE WRITE ERRORS" : 0x0302,
  "LOGICAL UNIT NOT READY, CAUSE NOT REPORTABLE" : 0x0400,
  "LOGICAL UNIT IS IN PROCESS OF BECOMING READY" : 0x0401,
  "LOGICAL UNIT NOT READY, INITIALIZING COMMAND REQUIRED" : 0x0402,
  "LOGICAL UNIT NOT READY, MANUAL INTERVENTION REQUIRED" : 0x0403,
  "LOGICAL UNIT NOT READY, FORMAT IN PROGRESS" : 0x0404,
  "LOGICAL UNIT NOT READY, REBUILD IN PROGRESS" : 0x0405,
  "LOGICAL UNIT NOT READY, RECALCULATION IN PROGRESS" : 0x0406,
  "LOGICAL UNIT NOT READY, OPERATION IN PROGRESS" : 0x0407,
  "LOGICAL UNIT NOT READY, LONG WRITE IN PROGRESS" : 0x0408,
  "LOGICAL UNIT NOT READY, SELF-TEST IN PROGRESS" : 0x0409,
  "LOGICAL UNIT NOT ACCESSIBLE, ASYMMETRIC ACCESS STATE TRANSITION" : 0x040A,
  "LOGICAL UNIT NOT ACCESSIBLE, TARGET PORT IN STANDBY STATE" : 0x040B,
  "LOGICAL UNIT NOT ACCESSIBLE, TARGET PORT IN UNAVAILABLE STATE" : 0x040C,
  "LOGICAL UNIT NOT READY, STRUCTURE CHECK REQUIRED" : 0x040D,
  "LOGICAL UNIT NOT READY, AUXILIARY MEMORY NOT ACCESSIBLE" : 0x0410,
  "LOGICAL UNIT NOT READY, NOTIFY (ENABLE SPINUP) REQUIRED" : 0x0411,
  "LOGICAL UNIT NOT READY, OFFLINE" : 0x0412,
  "LOGICAL UNIT NOT READY, SA CREATION IN PROGRESS" : 0x0413,
  "LOGICAL UNIT DOES NOT RESPOND TO SELECTION" : 0x0500,
  "NO REFERENCE POSITION FOUND" : 0x0600,
  "MULTIPLE PERIPHERAL DEVICES SELECTED" : 0x0700,
  "LOGICAL UNIT COMMUNICATION FAILURE" : 0x0800,
  "LOGICAL UNIT COMMUNICATION TIME-OUT" : 0x0801,
  "LOGICAL UNIT COMMUNICATION PARITY ERROR" : 0x0802,
  "LOGICAL UNIT COMMUNICATION CRC ERROR (ULTRA-DMA/32)" : 0x0803,
  "UNREACHABLE COPY TARGET" : 0x0804,
  "TRACK FOLLOWING ERROR" : 0x0900,
  "TRACKING SERVO FAILURE" : 0x0901,
  "FOCUS SERVO FAILURE" : 0x0902,
  "SPINDLE SERVO FAILURE" : 0x0903,
  "HEAD SELECT FAULT" : 0x0904,
  "ERROR LOG OVERFLOW" : 0x0A00,
  "WARNING" : 0x0B00,
  "WARNING - SPECIFIED TEMPERATURE EXCEEDED" : 0x0B01,
  "WARNING - ENCLOSURE DEGRADED" : 0x0B02,
  "WARNING - BACKGROUND SELF-TEST FAILED" : 0x0B03,
  "WARNING - BACKGROUND PRE-SCAN DETECTED MEDIUM ERROR" : 0x0B04,
  "WARNING - BACKGROUND MEDIUM SCAN DETECTED MEDIUM ERROR" : 0x0B05,
  "WARNING - NON-VOLATILE CACHE NOW VOLATILE" : 0x0B06,
  "WARNING - DEGRADED POWER TO NON-VOLATILE CACHE" : 0x0B07,
  "WRITE ERROR" : 0x0C00,
  "WRITE ERROR - RECOVERED WITH AUTO REALLOCATION" : 0x0C01,
  "WRITE ERROR - AUTO REALLOCATION FAILED" : 0x0C02,
  "WRITE ERROR - RECOMMEND REASSIGNMENT" : 0x0C03,
  "COMPRESSION CHECK MISCOMPARE ERROR" : 0x0C04,
  "DATA EXPANSION OCCURRED DURING COMPRESSION" : 0x0C05,
  "BLOCK NOT COMPRESSIBLE" : 0x0C06,
  "WRITE ERROR - RECOVERY NEEDED" : 0x0C07,
  "WRITE ERROR - RECOVERY FAILED" : 0x0C08,
  "WRITE ERROR - LOSS OF STREAMING" : 0x0C09,
  "WRITE ERROR - PADDING BLOCKS ADDED" : 0x0C0A,
  "AUXILIARY MEMORY WRITE ERROR" : 0x0C0B,
  "WRITE ERROR - UNEXPECTED UNSOLICITED DATA" : 0x0C0C,
  "WRITE ERROR - NOT ENOUGH UNSOLICITED DATA" : 0x0C0D,
  "DEFECTS IN ERROR WINDOW" : 0x0C0F,
  "ERROR DETECTED BY THIRD PARTY TEMPORARY INITIATOR" : 0x0D00,
  "THIRD PARTY DEVICE FAILURE" : 0x0D01,
  "COPY TARGET DEVICE NOT REACHABLE" : 0x0D02,
  "INCORRECT COPY TARGET DEVICE TYPE" : 0x0D03,
  "COPY TARGET DEVICE DATA UNDERRUN" : 0x0D04,
  "COPY TARGET DEVICE DATA OVERRUN" : 0x0D05,
  "INVALID INFORMATION UNIT" : 0x0E00,
  "INFORMATION UNIT TOO SHORT" : 0x0E01,
  "INFORMATION UNIT TOO LONG" : 0x0E02,
  "INVALID FIELD IN COMMAND INFORMATION UNIT" : 0x0E03,
  "reserved_0F00" : 0x0F00,
  "ID CRC OR ECC ERROR" : 0x1000,
  "LOGICAL BLOCK GUARD CHECK FAILED" : 0x1001,
  "LOGICAL BLOCK APPLICATION TAG CHECK FAILED" : 0x1002,
  "LOGICAL BLOCK REFERENCE TAG CHECK FAILED" : 0x1003,
  "UNRECOVERED READ ERROR" : 0x1100,
  "READ RETRIES EXHAUSTED" : 0x1101,
  "ERROR TOO LONG TO CORRECT" : 0x1102,
  "MULTIPLE READ ERRORS" : 0x1103,
  "UNRECOVERED READ ERROR - AUTO REALLOCATE FAILED" : 0x1104,
  "L-EC UNCORRECTABLE ERROR" : 0x1105,
  "CIRC UNRECOVERED ERROR" : 0x1106,
  "DATA RE-SYNCHRONIZATION ERROR" : 0x1107,
  "INCOMPLETE BLOCK READ" : 0x1108,
  "NO GAP FOUND" : 0x1109,
  "MISCORRECTED ERROR" : 0x110A,
  "UNRECOVERED READ ERROR - RECOMMEND REASSIGNMENT" : 0x110B,
  "UNRECOVERED READ ERROR - RECOMMEND REWRITE THE DATA" : 0x110C,
  "DE-COMPRESSION CRC ERROR" : 0x110D,
  "CANNOT DECOMPRESS USING DECLARED ALGORITHM" : 0x110E,
  "ERROR READING UPC/EAN NUMBER" : 0x110F,
  "ERROR READING ISRC NUMBER" : 0x1110,
  "READ ERROR - LOSS OF STREAMING" : 0x1111,
  "AUXILIARY MEMORY READ ERROR" : 0x1112,
  "READ ERROR - FAILED RETRANSMISSION REQUEST" : 0x1113,
  "READ ERROR - LBA MARKED BAD BY APPLICATION CLIENT" : 0x1114,
  "ADDRESS MARK NOT FOUND FOR ID FIELD" : 0x1200,
  "ADDRESS MARK NOT FOUND FOR DATA FIELD" : 0x1300,
  "RECORDED ENTITY NOT FOUND" : 0x1400,
  "RECORD NOT FOUND" : 0x1401,
  "FILEMARK OR SETMARK NOT FOUND" : 0x1402,
  "END-OF-DATA NOT FOUND" : 0x1403,
  "BLOCK SEQUENCE ERROR" : 0x1404,
  "RECORD NOT FOUND - RECOMMEND REASSIGNMENT" : 0x1405,
  "RECORD NOT FOUND - DATA AUTO-REALLOCATED" : 0x1406,
  "LOCATE OPERATION FAILURE" : 0x1407,
  "RANDOM POSITIONING ERROR" : 0x1500,
  "MECHANICAL POSITIONING ERROR" : 0x1501,
  "POSITIONING ERROR DETECTED BY READ OF MEDIUM" : 0x1502,
  "DATA SYNCHRONIZATION MARK ERROR" : 0x1600,
  "DATA SYNC ERROR - DATA REWRITTEN" : 0x1601,
  "DATA SYNC ERROR - RECOMMEND REWRITE" : 0x1602,
  "DATA SYNC ERROR - DATA AUTO-REALLOCATED" : 0x1603,
  "DATA SYNC ERROR - RECOMMEND REASSIGNMENT" : 0x1604,
  "RECOVERED DATA WITH NO ERROR CORRECTION APPLIED" : 0x1700,
  "RECOVERED DATA WITH RETRIES" : 0x1701,
  "RECOVERED DATA WITH POSITIVE HEAD OFFSET" : 0x1702,
  "RECOVERED DATA WITH NEGATIVE HEAD OFFSET" : 0x1703,
  "RECOVERED DATA WITH RETRIES AND/OR CIRC APPLIED" : 0x1704,
  "RECOVERED DATA USING PREVIOUS SECTOR ID" : 0x1705,
  "RECOVERED DATA WITHOUT ECC - DATA AUTO-REALLOCATED" : 0x1706,
  "RECOVERED DATA WITHOUT ECC - RECOMMEND REASSIGNMENT" : 0x1707,
  "RECOVERED DATA WITHOUT ECC - RECOMMEND REWRITE" : 0x1708,
  "RECOVERED DATA WITHOUT ECC - DATA REWRITTEN" : 0x1709,
  "RECOVERED DATA WITH ERROR CORRECTION APPLIED" : 0x1800,
  "RECOVERED DATA WITH ERROR CORR. & RETRIES APPLIED" : 0x1801,
  "RECOVERED DATA - DATA AUTO-REALLOCATED" : 0x1802,
  "RECOVERED DATA WITH CIRC" : 0x1803,
  "RECOVERED DATA WITH L-EC" : 0x1804,
  "RECOVERED DATA - RECOMMEND REASSIGNMENT" : 0x1805,
  "RECOVERED DATA - RECOMMEND REWRITE" : 0x1806,
  "RECOVERED DATA WITH ECC - DATA REWRITTEN" : 0x1807,
  "RECOVERED DATA WITH LINKING" : 0x1808,
  "DEFECT LIST ERROR" : 0x1900,
  "DEFECT LIST NOT AVAILABLE" : 0x1901,
  "DEFECT LIST ERROR IN PRIMARY LIST" : 0x1902,
  "DEFECT LIST ERROR IN GROWN LIST" : 0x1903,
  "PARAMETER LIST LENGTH ERROR" : 0x1A00,
  "SYNCHRONOUS DATA TRANSFER ERROR" : 0x1B00,
  "DEFECT LIST NOT FOUND" : 0x1C00,
  "PRIMARY DEFECT LIST NOT FOUND" : 0x1C01,
  "GROWN DEFECT LIST NOT FOUND" : 0x1C02,
  "MISCOMPARE DURING VERIFY OPERATION" : 0x1D00,
  "RECOVERED ID WITH ECC CORRECTION" : 0x1E00,
  "PARTIAL DEFECT LIST TRANSFER" : 0x1F00,
  "INVALID COMMAND OPERATION CODE" : 0x2000,
  "ACCESS DENIED - INITIATOR PENDING-ENROLLED" : 0x2001,
  "ACCESS DENIED - NO ACCESS RIGHTS" : 0x2002,
  "ACCESS DENIED - INVALID MGMT ID KEY" : 0x2003,
  "ILLEGAL COMMAND WHILE IN WRITE CAPABLE STATE" : 0x2004,
  "Obsolete" : 0x2005,
  "ILLEGAL COMMAND WHILE IN EXPLICIT ADDRESS MODE" : 0x2006,
  "ILLEGAL COMMAND WHILE IN IMPLICIT ADDRESS MODE" : 0x2007,
  "ACCESS DENIED - ENROLLMENT CONFLICT" : 0x2008,
  "ACCESS DENIED - INVALID LU IDENTIFIER" : 0x2009,
  "ACCESS DENIED - INVALID PROXY TOKEN" : 0x200A,
  "ACCESS DENIED - ACL LUN CONFLICT" : 0x200B,
  "LOGICAL BLOCK ADDRESS OUT OF RANGE" : 0x2100,
  "INVALID ELEMENT ADDRESS" : 0x2101,
  "INVALID ADDRESS FOR WRITE" : 0x2102,
  "INVALID WRITE CROSSING LAYER JUMP" : 0x2103,
  "ILLEGAL FUNCTION (USE 20 00, 24 00, OR 26 00)" : 0x2200,
  "reserved_2300" : 0x2300,
  "INVALID FIELD IN CDB" : 0x2400,
  "CDB DECRYPTION ERROR" : 0x2401,
  "Obsolete" : 0x2402,
  "Obsolete" : 0x2403,
  "SECURITY AUDIT VALUE FROZEN" : 0x2404,
  "SECURITY WORKING KEY FROZEN" : 0x2405,
  "NONCE NOT UNIQUE" : 0x2406,
  "NONCE TIMESTAMP OUT OF RANGE" : 0x2407,
  "INVALID XCDB" : 0x2408,
  "LOGICAL UNIT NOT SUPPORTED" : 0x2500,
  "INVALID FIELD IN PARAMETER LIST" : 0x2600,
  "PARAMETER NOT SUPPORTED" : 0x2601,
  "PARAMETER VALUE INVALID" : 0x2602,
  "THRESHOLD PARAMETERS NOT SUPPORTED" : 0x2603,
  "INVALID RELEASE OF PERSISTENT RESERVATION" : 0x2604,
  "DATA DECRYPTION ERROR" : 0x2605,
  "TOO MANY TARGET DESCRIPTORS" : 0x2606,
  "UNSUPPORTED TARGET DESCRIPTOR TYPE CODE" : 0x2607,
  "TOO MANY SEGMENT DESCRIPTORS" : 0x2608,
  "UNSUPPORTED SEGMENT DESCRIPTOR TYPE CODE" : 0x2609,
  "UNEXPECTED INEXACT SEGMENT" : 0x260A,
  "INLINE DATA LENGTH EXCEEDED" : 0x260B,
  "INVALID OPERATION FOR COPY SOURCE OR DESTINATION" : 0x260C,
  "COPY SEGMENT GRANULARITY VIOLATION" : 0x260D,
  "INVALID PARAMETER WHILE PORT IS ENABLED" : 0x260E,
  "INVALID DATA-OUT BUFFER INTEGRITY CHECK VALUE" : 0x260F,
  "DATA DECRYPTION KEY FAIL LIMIT REACHED" : 0x2610,
  "INCOMPLETE KEY-ASSOCIATED DATA SET" : 0x2611,
  "VENDOR SPECIFIC KEY REFERENCE NOT FOUND" : 0x2612,
  "WRITE PROTECTED" : 0x2700,
  "HARDWARE WRITE PROTECTED" : 0x2701,
  "LOGICAL UNIT SOFTWARE WRITE PROTECTED" : 0x2702,
  "ASSOCIATED WRITE PROTECT" : 0x2703,
  "PERSISTENT WRITE PROTECT" : 0x2704,
  "PERMANENT WRITE PROTECT" : 0x2705,
  "CONDITIONAL WRITE PROTECT" : 0x2706,
  "NOT READY TO READY CHANGE, MEDIUM MAY HAVE CHANGED" : 0x2800,
  "IMPORT OR EXPORT ELEMENT ACCESSED" : 0x2801,
  "FORMAT-LAYER MAY HAVE CHANGED" : 0x2802,
  "IMPORT/EXPORT ELEMENT ACCESSED, MEDIUM CHANGED" : 0x2803,
  "POWER ON, RESET, OR BUS DEVICE RESET OCCURRED" : 0x2900,
  "POWER ON OCCURRED" : 0x2901,
  "SCSI BUS RESET OCCURRED" : 0x2902,
  "BUS DEVICE RESET FUNCTION OCCURRED" : 0x2903,
  "DEVICE INTERNAL RESET" : 0x2904,
  "TRANSCEIVER MODE CHANGED TO SINGLE-ENDED" : 0x2905,
  "TRANSCEIVER MODE CHANGED TO LVD" : 0x2906,
  "I_T NEXUS LOSS OCCURRED" : 0x2907,
  "PARAMETERS CHANGED" : 0x2A00,
  "MODE PARAMETERS CHANGED" : 0x2A01,
  "LOG PARAMETERS CHANGED" : 0x2A02,
  "RESERVATIONS PREEMPTED" : 0x2A03,
  "RESERVATIONS RELEASED" : 0x2A04,
  "REGISTRATIONS PREEMPTED" : 0x2A05,
  "ASYMMETRIC ACCESS STATE CHANGED" : 0x2A06,
  "IMPLICIT ASYMMETRIC ACCESS STATE TRANSITION FAILED" : 0x2A07,
  "PRIORITY CHANGED" : 0x2A08,
  "CAPACITY DATA HAS CHANGED" : 0x2A09,
  "ERROR HISTORY I_T NEXUS CLEARED" : 0x2A0A,
  "ERROR HISTORY SNAPSHOT RELEASED" : 0x2A0B,
  "ERROR RECOVERY ATTRIBUTES HAVE CHANGED" : 0x2A0C,
  "DATA ENCRYPTION CAPABILITIES CHANGED" : 0x2A0D,
  "TIMESTAMP CHANGED" : 0x2A10,
  "DATA ENCRYPTION PARAMETERS CHANGED BY ANOTHER I_T NEXUS" : 0x2A11,
  "DATA ENCRYPTION PARAMETERS CHANGED BY VENDOR SPECIFIC EVENT" : 0x2A12,
  "DATA ENCRYPTION KEY INSTANCE COUNTER HAS CHANGED" : 0x2A13,
  "SA CREATION CAPABILITIES DATA HAS CHANGED" : 0x2A14,
  "COPY CANNOT EXECUTE SINCE HOST CANNOT DISCONNECT" : 0x2B00,
  "COMMAND SEQUENCE ERROR" : 0x2C00,
  "TOO MANY WINDOWS SPECIFIED" : 0x2C01,
  "INVALID COMBINATION OF WINDOWS SPECIFIED" : 0x2C02,
  "CURRENT PROGRAM AREA IS NOT EMPTY" : 0x2C03,
  "CURRENT PROGRAM AREA IS EMPTY" : 0x2C04,
  "ILLEGAL POWER CONDITION REQUEST" : 0x2C05,
  "PERSISTENT PREVENT CONFLICT" : 0x2C06,
  "PREVIOUS BUSY STATUS" : 0x2C07,
  "PREVIOUS TASK SET FULL STATUS" : 0x2C08,
  "PREVIOUS RESERVATION CONFLICT STATUS" : 0x2C09,
  "PARTITION OR COLLECTION CONTAINS USER OBJECTS" : 0x2C0A,
  "NOT RESERVED" : 0x2C0B,
  "OVERWRITE ERROR ON UPDATE IN PLACE" : 0x2D00,
  "INSUFFICIENT TIME FOR OPERATION" : 0x2E00,
  "COMMANDS CLEARED BY ANOTHER INITIATOR" : 0x2F00,
  "COMMANDS CLEARED BY POWER LOSS NOTIFICATION" : 0x2F01,
  "COMMANDS CLEARED BY DEVICE SERVER" : 0x2F02,
  "INCOMPATIBLE MEDIUM INSTALLED" : 0x3000,
  "CANNOT READ MEDIUM - UNKNOWN FORMAT" : 0x3001,
  "CANNOT READ MEDIUM - INCOMPATIBLE FORMAT" : 0x3002,
  "CLEANING CARTRIDGE INSTALLED" : 0x3003,
  "CANNOT WRITE MEDIUM - UNKNOWN FORMAT" : 0x3004,
  "CANNOT WRITE MEDIUM - INCOMPATIBLE FORMAT" : 0x3005,
  "CANNOT FORMAT MEDIUM - INCOMPATIBLE MEDIUM" : 0x3006,
  "CLEANING FAILURE" : 0x3007,
  "CANNOT WRITE - APPLICATION CODE MISMATCH" : 0x3008,
  "CURRENT SESSION NOT FIXATED FOR APPEND" : 0x3009,
  "CLEANING REQUEST REJECTED" : 0x300A,
  "WORM MEDIUM - OVERWRITE ATTEMPTED" : 0x300C,
  "WORM MEDIUM - INTEGRITY CHECK" : 0x300D,
  "MEDIUM NOT FORMATTED" : 0x3010,
  "INCOMPATIBLE VOLUME TYPE" : 0x3011,
  "INCOMPATIBLE VOLUME QUALIFIER" : 0x3012,
  "MEDIUM FORMAT CORRUPTED" : 0x3100,
  "FORMAT COMMAND FAILED" : 0x3101,
  "ZONED FORMATTING FAILED DUE TO SPARE LINKING" : 0x3102,
  "NO DEFECT SPARE LOCATION AVAILABLE" : 0x3200,
  "DEFECT LIST UPDATE FAILURE" : 0x3201,
  "TAPE LENGTH ERROR" : 0x3300,
  "ENCLOSURE FAILURE" : 0x3400,
  "ENCLOSURE SERVICES FAILURE" : 0x3500,
  "UNSUPPORTED ENCLOSURE FUNCTION" : 0x3501,
  "ENCLOSURE SERVICES UNAVAILABLE" : 0x3502,
  "ENCLOSURE SERVICES TRANSFER FAILURE" : 0x3503,
  "ENCLOSURE SERVICES TRANSFER REFUSED" : 0x3504,
  "ENCLOSURE SERVICES CHECKSUM ERROR" : 0x3505,
  "RIBBON, INK, OR TONER FAILURE" : 0x3600,
  "ROUNDED PARAMETER" : 0x3700,
  "EVENT STATUS NOTIFICATION" : 0x3800,
  "ESN - POWER MANAGEMENT CLASS EVENT" : 0x3802,
  "ESN - MEDIA CLASS EVENT" : 0x3804,
  "ESN - DEVICE BUSY CLASS EVENT" : 0x3806,
  "SAVING PARAMETERS NOT SUPPORTED" : 0x3900,
  "MEDIUM NOT PRESENT" : 0x3A00,
  "MEDIUM NOT PRESENT - TRAY CLOSED" : 0x3A01,
  "MEDIUM NOT PRESENT - TRAY OPEN" : 0x3A02,
  "MEDIUM NOT PRESENT - LOADABLE" : 0x3A03,
  "MEDIUM NOT PRESENT - MEDIUM AUXILIARY MEMORY ACCESSIBLE" : 0x3A04,
  "SEQUENTIAL POSITIONING ERROR" : 0x3B00,
  "TAPE POSITION ERROR AT BEGINNING-OF-MEDIUM" : 0x3B01,
  "TAPE POSITION ERROR AT END-OF-MEDIUM" : 0x3B02,
  "TAPE OR ELECTRONIC VERTICAL FORMS UNIT NOT READY" : 0x3B03,
  "SLEW FAILURE" : 0x3B04,
  "PAPER JAM" : 0x3B05,
  "FAILED TO SENSE TOP-OF-FORM" : 0x3B06,
  "FAILED TO SENSE BOTTOM-OF-FORM" : 0x3B07,
  "REPOSITION ERROR" : 0x3B08,
  "READ PAST END OF MEDIUM" : 0x3B09,
  "READ PAST BEGINNING OF MEDIUM" : 0x3B0A,
  "POSITION PAST END OF MEDIUM" : 0x3B0B,
  "POSITION PAST BEGINNING OF MEDIUM" : 0x3B0C,
  "MEDIUM DESTINATION ELEMENT FULL" : 0x3B0D,
  "MEDIUM SOURCE ELEMENT EMPTY" : 0x3B0E,
  "END OF MEDIUM REACHED" : 0x3B0F,
  "MEDIUM MAGAZINE NOT ACCESSIBLE" : 0x3B11,
  "MEDIUM MAGAZINE REMOVED" : 0x3B12,
  "MEDIUM MAGAZINE INSERTED" : 0x3B13,
  "MEDIUM MAGAZINE LOCKED" : 0x3B14,
  "MEDIUM MAGAZINE UNLOCKED" : 0x3B15,
  "MECHANICAL POSITIONING OR CHANGER ERROR" : 0x3B16,
  "READ PAST END OF USER OBJECT" : 0x3B17,
  "ELEMENT DISABLED" : 0x3B18,
  "ELEMENT ENABLED" : 0x3B19,
  "DATA TRANSFER DEVICE REMOVED" : 0x3B1A,
  "DATA TRANSFER DEVICE INSERTED" : 0x3B1B,
  "reserved_3C00" : 0x3C00,
  "INVALID BITS IN IDENTIFY MESSAGE" : 0x3D00,
  "LOGICAL UNIT HAS NOT SELF-CONFIGURED YET" : 0x3E00,
  "LOGICAL UNIT FAILURE" : 0x3E01,
  "TIMEOUT ON LOGICAL UNIT" : 0x3E02,
  "LOGICAL UNIT FAILED SELF-TEST" : 0x3E03,
  "LOGICAL UNIT UNABLE TO UPDATE SELF-TEST LOG" : 0x3E04,
  "TARGET OPERATING CONDITIONS HAVE CHANGED" : 0x3F00,
  "MICROCODE HAS BEEN CHANGED" : 0x3F01,
  "CHANGED OPERATING DEFINITION" : 0x3F02,
  "INQUIRY DATA HAS CHANGED" : 0x3F03,
  "COMPONENT DEVICE ATTACHED" : 0x3F04,
  "DEVICE IDENTIFIER CHANGED" : 0x3F05,
  "REDUNDANCY GROUP CREATED OR MODIFIED" : 0x3F06,
  "REDUNDANCY GROUP DELETED" : 0x3F07,
  "SPARE CREATED OR MODIFIED" : 0x3F08,
  "SPARE DELETED" : 0x3F09,
  "VOLUME SET CREATED OR MODIFIED" : 0x3F0A,
  "VOLUME SET DELETED" : 0x3F0B,
  "VOLUME SET DEASSIGNED" : 0x3F0C,
  "VOLUME SET REASSIGNED" : 0x3F0D,
  "REPORTED LUNS DATA HAS CHANGED" : 0x3F0E,
  "ECHO BUFFER OVERWRITTEN" : 0x3F0F,
  "MEDIUM LOADABLE" : 0x3F10,
  "MEDIUM AUXILIARY MEMORY ACCESSIBLE" : 0x3F11,
  "iSCSI IP ADDRESS ADDED" : 0x3F12,
  "iSCSI IP ADDRESS REMOVED" : 0x3F13,
  "iSCSI IP ADDRESS CHANGED" : 0x3F14,
  "RAM FAILURE (SHOULD USE 40 NN)" : 0x4000,
  "DIAGNOSTIC FAILURE ON COMPONENT 00 (80h-FFh)" : 0x4000,
  "DIAGNOSTIC FAILURE ON COMPONENT 01 (80h-FFh)" : 0x4001,
  "DIAGNOSTIC FAILURE ON COMPONENT 02 (80h-FFh)" : 0x4002,
  "DIAGNOSTIC FAILURE ON COMPONENT 03 (80h-FFh)" : 0x4003,
  "DIAGNOSTIC FAILURE ON COMPONENT 04 (80h-FFh)" : 0x4004,
  "DIAGNOSTIC FAILURE ON COMPONENT 05 (80h-FFh)" : 0x4005,
  "DIAGNOSTIC FAILURE ON COMPONENT 06 (80h-FFh)" : 0x4006,
  "DIAGNOSTIC FAILURE ON COMPONENT 07 (80h-FFh)" : 0x4007,
  "DIAGNOSTIC FAILURE ON COMPONENT 08 (80h-FFh)" : 0x4008,
  "DIAGNOSTIC FAILURE ON COMPONENT 09 (80h-FFh)" : 0x4009,
  "DIAGNOSTIC FAILURE ON COMPONENT 0A (80h-FFh)" : 0x400A,
  "DIAGNOSTIC FAILURE ON COMPONENT 0B (80h-FFh)" : 0x400B,
  "DIAGNOSTIC FAILURE ON COMPONENT 0C (80h-FFh)" : 0x400C,
  "DIAGNOSTIC FAILURE ON COMPONENT 0D (80h-FFh)" : 0x400D,
  "DIAGNOSTIC FAILURE ON COMPONENT 0E (80h-FFh)" : 0x400E,
  "DIAGNOSTIC FAILURE ON COMPONENT 0F (80h-FFh)" : 0x400F,
  "DIAGNOSTIC FAILURE ON COMPONENT 10 (80h-FFh)" : 0x4010,
  "DIAGNOSTIC FAILURE ON COMPONENT 11 (80h-FFh)" : 0x4011,
  "DIAGNOSTIC FAILURE ON COMPONENT 12 (80h-FFh)" : 0x4012,
  "DIAGNOSTIC FAILURE ON COMPONENT 13 (80h-FFh)" : 0x4013,
  "DIAGNOSTIC FAILURE ON COMPONENT 14 (80h-FFh)" : 0x4014,
  "DIAGNOSTIC FAILURE ON COMPONENT 15 (80h-FFh)" : 0x4015,
  "DIAGNOSTIC FAILURE ON COMPONENT 16 (80h-FFh)" : 0x4016,
  "DIAGNOSTIC FAILURE ON COMPONENT 17 (80h-FFh)" : 0x4017,
  "DIAGNOSTIC FAILURE ON COMPONENT 18 (80h-FFh)" : 0x4018,
  "DIAGNOSTIC FAILURE ON COMPONENT 19 (80h-FFh)" : 0x4019,
  "DIAGNOSTIC FAILURE ON COMPONENT 1A (80h-FFh)" : 0x401A,
  "DIAGNOSTIC FAILURE ON COMPONENT 1B (80h-FFh)" : 0x401B,
  "DIAGNOSTIC FAILURE ON COMPONENT 1C (80h-FFh)" : 0x401C,
  "DIAGNOSTIC FAILURE ON COMPONENT 1D (80h-FFh)" : 0x401D,
  "DIAGNOSTIC FAILURE ON COMPONENT 1E (80h-FFh)" : 0x401E,
  "DIAGNOSTIC FAILURE ON COMPONENT 1F (80h-FFh)" : 0x401F,
  "DIAGNOSTIC FAILURE ON COMPONENT 20 (80h-FFh)" : 0x4020,
  "DIAGNOSTIC FAILURE ON COMPONENT 21 (80h-FFh)" : 0x4021,
  "DIAGNOSTIC FAILURE ON COMPONENT 22 (80h-FFh)" : 0x4022,
  "DIAGNOSTIC FAILURE ON COMPONENT 23 (80h-FFh)" : 0x4023,
  "DIAGNOSTIC FAILURE ON COMPONENT 24 (80h-FFh)" : 0x4024,
  "DIAGNOSTIC FAILURE ON COMPONENT 25 (80h-FFh)" : 0x4025,
  "DIAGNOSTIC FAILURE ON COMPONENT 26 (80h-FFh)" : 0x4026,
  "DIAGNOSTIC FAILURE ON COMPONENT 27 (80h-FFh)" : 0x4027,
  "DIAGNOSTIC FAILURE ON COMPONENT 28 (80h-FFh)" : 0x4028,
  "DIAGNOSTIC FAILURE ON COMPONENT 29 (80h-FFh)" : 0x4029,
  "DIAGNOSTIC FAILURE ON COMPONENT 2A (80h-FFh)" : 0x402A,
  "DIAGNOSTIC FAILURE ON COMPONENT 2B (80h-FFh)" : 0x402B,
  "DIAGNOSTIC FAILURE ON COMPONENT 2C (80h-FFh)" : 0x402C,
  "DIAGNOSTIC FAILURE ON COMPONENT 2D (80h-FFh)" : 0x402D,
  "DIAGNOSTIC FAILURE ON COMPONENT 2E (80h-FFh)" : 0x402E,
  "DIAGNOSTIC FAILURE ON COMPONENT 2F (80h-FFh)" : 0x402F,
  "DIAGNOSTIC FAILURE ON COMPONENT 30 (80h-FFh)" : 0x4030,
  "DIAGNOSTIC FAILURE ON COMPONENT 31 (80h-FFh)" : 0x4031,
  "DIAGNOSTIC FAILURE ON COMPONENT 32 (80h-FFh)" : 0x4032,
  "DIAGNOSTIC FAILURE ON COMPONENT 33 (80h-FFh)" : 0x4033,
  "DIAGNOSTIC FAILURE ON COMPONENT 34 (80h-FFh)" : 0x4034,
  "DIAGNOSTIC FAILURE ON COMPONENT 35 (80h-FFh)" : 0x4035,
  "DIAGNOSTIC FAILURE ON COMPONENT 36 (80h-FFh)" : 0x4036,
  "DIAGNOSTIC FAILURE ON COMPONENT 37 (80h-FFh)" : 0x4037,
  "DIAGNOSTIC FAILURE ON COMPONENT 38 (80h-FFh)" : 0x4038,
  "DIAGNOSTIC FAILURE ON COMPONENT 39 (80h-FFh)" : 0x4039,
  "DIAGNOSTIC FAILURE ON COMPONENT 3A (80h-FFh)" : 0x403A,
  "DIAGNOSTIC FAILURE ON COMPONENT 3B (80h-FFh)" : 0x403B,
  "DIAGNOSTIC FAILURE ON COMPONENT 3C (80h-FFh)" : 0x403C,
  "DIAGNOSTIC FAILURE ON COMPONENT 3D (80h-FFh)" : 0x403D,
  "DIAGNOSTIC FAILURE ON COMPONENT 3E (80h-FFh)" : 0x403E,
  "DIAGNOSTIC FAILURE ON COMPONENT 3F (80h-FFh)" : 0x403F,
  "DIAGNOSTIC FAILURE ON COMPONENT 40 (80h-FFh)" : 0x4040,
  "DIAGNOSTIC FAILURE ON COMPONENT 41 (80h-FFh)" : 0x4041,
  "DIAGNOSTIC FAILURE ON COMPONENT 42 (80h-FFh)" : 0x4042,
  "DIAGNOSTIC FAILURE ON COMPONENT 43 (80h-FFh)" : 0x4043,
  "DIAGNOSTIC FAILURE ON COMPONENT 44 (80h-FFh)" : 0x4044,
  "DIAGNOSTIC FAILURE ON COMPONENT 45 (80h-FFh)" : 0x4045,
  "DIAGNOSTIC FAILURE ON COMPONENT 46 (80h-FFh)" : 0x4046,
  "DIAGNOSTIC FAILURE ON COMPONENT 47 (80h-FFh)" : 0x4047,
  "DIAGNOSTIC FAILURE ON COMPONENT 48 (80h-FFh)" : 0x4048,
  "DIAGNOSTIC FAILURE ON COMPONENT 49 (80h-FFh)" : 0x4049,
  "DIAGNOSTIC FAILURE ON COMPONENT 4A (80h-FFh)" : 0x404A,
  "DIAGNOSTIC FAILURE ON COMPONENT 4B (80h-FFh)" : 0x404B,
  "DIAGNOSTIC FAILURE ON COMPONENT 4C (80h-FFh)" : 0x404C,
  "DIAGNOSTIC FAILURE ON COMPONENT 4D (80h-FFh)" : 0x404D,
  "DIAGNOSTIC FAILURE ON COMPONENT 4E (80h-FFh)" : 0x404E,
  "DIAGNOSTIC FAILURE ON COMPONENT 4F (80h-FFh)" : 0x404F,
  "DIAGNOSTIC FAILURE ON COMPONENT 50 (80h-FFh)" : 0x4050,
  "DIAGNOSTIC FAILURE ON COMPONENT 51 (80h-FFh)" : 0x4051,
  "DIAGNOSTIC FAILURE ON COMPONENT 52 (80h-FFh)" : 0x4052,
  "DIAGNOSTIC FAILURE ON COMPONENT 53 (80h-FFh)" : 0x4053,
  "DIAGNOSTIC FAILURE ON COMPONENT 54 (80h-FFh)" : 0x4054,
  "DIAGNOSTIC FAILURE ON COMPONENT 55 (80h-FFh)" : 0x4055,
  "DIAGNOSTIC FAILURE ON COMPONENT 56 (80h-FFh)" : 0x4056,
  "DIAGNOSTIC FAILURE ON COMPONENT 57 (80h-FFh)" : 0x4057,
  "DIAGNOSTIC FAILURE ON COMPONENT 58 (80h-FFh)" : 0x4058,
  "DIAGNOSTIC FAILURE ON COMPONENT 59 (80h-FFh)" : 0x4059,
  "DIAGNOSTIC FAILURE ON COMPONENT 5A (80h-FFh)" : 0x405A,
  "DIAGNOSTIC FAILURE ON COMPONENT 5B (80h-FFh)" : 0x405B,
  "DIAGNOSTIC FAILURE ON COMPONENT 5C (80h-FFh)" : 0x405C,
  "DIAGNOSTIC FAILURE ON COMPONENT 5D (80h-FFh)" : 0x405D,
  "DIAGNOSTIC FAILURE ON COMPONENT 5E (80h-FFh)" : 0x405E,
  "DIAGNOSTIC FAILURE ON COMPONENT 5F (80h-FFh)" : 0x405F,
  "DIAGNOSTIC FAILURE ON COMPONENT 60 (80h-FFh)" : 0x4060,
  "DIAGNOSTIC FAILURE ON COMPONENT 61 (80h-FFh)" : 0x4061,
  "DIAGNOSTIC FAILURE ON COMPONENT 62 (80h-FFh)" : 0x4062,
  "DIAGNOSTIC FAILURE ON COMPONENT 63 (80h-FFh)" : 0x4063,
  "DIAGNOSTIC FAILURE ON COMPONENT 64 (80h-FFh)" : 0x4064,
  "DIAGNOSTIC FAILURE ON COMPONENT 65 (80h-FFh)" : 0x4065,
  "DIAGNOSTIC FAILURE ON COMPONENT 66 (80h-FFh)" : 0x4066,
  "DIAGNOSTIC FAILURE ON COMPONENT 67 (80h-FFh)" : 0x4067,
  "DIAGNOSTIC FAILURE ON COMPONENT 68 (80h-FFh)" : 0x4068,
  "DIAGNOSTIC FAILURE ON COMPONENT 69 (80h-FFh)" : 0x4069,
  "DIAGNOSTIC FAILURE ON COMPONENT 6A (80h-FFh)" : 0x406A,
  "DIAGNOSTIC FAILURE ON COMPONENT 6B (80h-FFh)" : 0x406B,
  "DIAGNOSTIC FAILURE ON COMPONENT 6C (80h-FFh)" : 0x406C,
  "DIAGNOSTIC FAILURE ON COMPONENT 6D (80h-FFh)" : 0x406D,
  "DIAGNOSTIC FAILURE ON COMPONENT 6E (80h-FFh)" : 0x406E,
  "DIAGNOSTIC FAILURE ON COMPONENT 6F (80h-FFh)" : 0x406F,
  "DIAGNOSTIC FAILURE ON COMPONENT 70 (80h-FFh)" : 0x4070,
  "DIAGNOSTIC FAILURE ON COMPONENT 71 (80h-FFh)" : 0x4071,
  "DIAGNOSTIC FAILURE ON COMPONENT 72 (80h-FFh)" : 0x4072,
  "DIAGNOSTIC FAILURE ON COMPONENT 73 (80h-FFh)" : 0x4073,
  "DIAGNOSTIC FAILURE ON COMPONENT 74 (80h-FFh)" : 0x4074,
  "DIAGNOSTIC FAILURE ON COMPONENT 75 (80h-FFh)" : 0x4075,
  "DIAGNOSTIC FAILURE ON COMPONENT 76 (80h-FFh)" : 0x4076,
  "DIAGNOSTIC FAILURE ON COMPONENT 77 (80h-FFh)" : 0x4077,
  "DIAGNOSTIC FAILURE ON COMPONENT 78 (80h-FFh)" : 0x4078,
  "DIAGNOSTIC FAILURE ON COMPONENT 79 (80h-FFh)" : 0x4079,
  "DIAGNOSTIC FAILURE ON COMPONENT 7A (80h-FFh)" : 0x407A,
  "DIAGNOSTIC FAILURE ON COMPONENT 7B (80h-FFh)" : 0x407B,
  "DIAGNOSTIC FAILURE ON COMPONENT 7C (80h-FFh)" : 0x407C,
  "DIAGNOSTIC FAILURE ON COMPONENT 7D (80h-FFh)" : 0x407D,
  "DIAGNOSTIC FAILURE ON COMPONENT 7E (80h-FFh)" : 0x407E,
  "DIAGNOSTIC FAILURE ON COMPONENT 7F (80h-FFh)" : 0x407F,
  "DIAGNOSTIC FAILURE ON COMPONENT 80 (80h-FFh)" : 0x4080,
  "DIAGNOSTIC FAILURE ON COMPONENT 81 (80h-FFh)" : 0x4081,
  "DIAGNOSTIC FAILURE ON COMPONENT 82 (80h-FFh)" : 0x4082,
  "DIAGNOSTIC FAILURE ON COMPONENT 83 (80h-FFh)" : 0x4083,
  "DIAGNOSTIC FAILURE ON COMPONENT 84 (80h-FFh)" : 0x4084,
  "DIAGNOSTIC FAILURE ON COMPONENT 85 (80h-FFh)" : 0x4085,
  "DIAGNOSTIC FAILURE ON COMPONENT 86 (80h-FFh)" : 0x4086,
  "DIAGNOSTIC FAILURE ON COMPONENT 87 (80h-FFh)" : 0x4087,
  "DIAGNOSTIC FAILURE ON COMPONENT 88 (80h-FFh)" : 0x4088,
  "DIAGNOSTIC FAILURE ON COMPONENT 89 (80h-FFh)" : 0x4089,
  "DIAGNOSTIC FAILURE ON COMPONENT 8A (80h-FFh)" : 0x408A,
  "DIAGNOSTIC FAILURE ON COMPONENT 8B (80h-FFh)" : 0x408B,
  "DIAGNOSTIC FAILURE ON COMPONENT 8C (80h-FFh)" : 0x408C,
  "DIAGNOSTIC FAILURE ON COMPONENT 8D (80h-FFh)" : 0x408D,
  "DIAGNOSTIC FAILURE ON COMPONENT 8E (80h-FFh)" : 0x408E,
  "DIAGNOSTIC FAILURE ON COMPONENT 8F (80h-FFh)" : 0x408F,
  "DIAGNOSTIC FAILURE ON COMPONENT 90 (80h-FFh)" : 0x4090,
  "DIAGNOSTIC FAILURE ON COMPONENT 91 (80h-FFh)" : 0x4091,
  "DIAGNOSTIC FAILURE ON COMPONENT 92 (80h-FFh)" : 0x4092,
  "DIAGNOSTIC FAILURE ON COMPONENT 93 (80h-FFh)" : 0x4093,
  "DIAGNOSTIC FAILURE ON COMPONENT 94 (80h-FFh)" : 0x4094,
  "DIAGNOSTIC FAILURE ON COMPONENT 95 (80h-FFh)" : 0x4095,
  "DIAGNOSTIC FAILURE ON COMPONENT 96 (80h-FFh)" : 0x4096,
  "DIAGNOSTIC FAILURE ON COMPONENT 97 (80h-FFh)" : 0x4097,
  "DIAGNOSTIC FAILURE ON COMPONENT 98 (80h-FFh)" : 0x4098,
  "DIAGNOSTIC FAILURE ON COMPONENT 99 (80h-FFh)" : 0x4099,
  "DIAGNOSTIC FAILURE ON COMPONENT 9A (80h-FFh)" : 0x409A,
  "DIAGNOSTIC FAILURE ON COMPONENT 9B (80h-FFh)" : 0x409B,
  "DIAGNOSTIC FAILURE ON COMPONENT 9C (80h-FFh)" : 0x409C,
  "DIAGNOSTIC FAILURE ON COMPONENT 9D (80h-FFh)" : 0x409D,
  "DIAGNOSTIC FAILURE ON COMPONENT 9E (80h-FFh)" : 0x409E,
  "DIAGNOSTIC FAILURE ON COMPONENT 9F (80h-FFh)" : 0x409F,
  "DIAGNOSTIC FAILURE ON COMPONENT A0 (80h-FFh)" : 0x40A0,
  "DIAGNOSTIC FAILURE ON COMPONENT A1 (80h-FFh)" : 0x40A1,
  "DIAGNOSTIC FAILURE ON COMPONENT A2 (80h-FFh)" : 0x40A2,
  "DIAGNOSTIC FAILURE ON COMPONENT A3 (80h-FFh)" : 0x40A3,
  "DIAGNOSTIC FAILURE ON COMPONENT A4 (80h-FFh)" : 0x40A4,
  "DIAGNOSTIC FAILURE ON COMPONENT A5 (80h-FFh)" : 0x40A5,
  "DIAGNOSTIC FAILURE ON COMPONENT A6 (80h-FFh)" : 0x40A6,
  "DIAGNOSTIC FAILURE ON COMPONENT A7 (80h-FFh)" : 0x40A7,
  "DIAGNOSTIC FAILURE ON COMPONENT A8 (80h-FFh)" : 0x40A8,
  "DIAGNOSTIC FAILURE ON COMPONENT A9 (80h-FFh)" : 0x40A9,
  "DIAGNOSTIC FAILURE ON COMPONENT AA (80h-FFh)" : 0x40AA,
  "DIAGNOSTIC FAILURE ON COMPONENT AB (80h-FFh)" : 0x40AB,
  "DIAGNOSTIC FAILURE ON COMPONENT AC (80h-FFh)" : 0x40AC,
  "DIAGNOSTIC FAILURE ON COMPONENT AD (80h-FFh)" : 0x40AD,
  "DIAGNOSTIC FAILURE ON COMPONENT AE (80h-FFh)" : 0x40AE,
  "DIAGNOSTIC FAILURE ON COMPONENT AF (80h-FFh)" : 0x40AF,
  "DIAGNOSTIC FAILURE ON COMPONENT B0 (80h-FFh)" : 0x40B0,
  "DIAGNOSTIC FAILURE ON COMPONENT B1 (80h-FFh)" : 0x40B1,
  "DIAGNOSTIC FAILURE ON COMPONENT B2 (80h-FFh)" : 0x40B2,
  "DIAGNOSTIC FAILURE ON COMPONENT B3 (80h-FFh)" : 0x40B3,
  "DIAGNOSTIC FAILURE ON COMPONENT B4 (80h-FFh)" : 0x40B4,
  "DIAGNOSTIC FAILURE ON COMPONENT B5 (80h-FFh)" : 0x40B5,
  "DIAGNOSTIC FAILURE ON COMPONENT B6 (80h-FFh)" : 0x40B6,
  "DIAGNOSTIC FAILURE ON COMPONENT B7 (80h-FFh)" : 0x40B7,
  "DIAGNOSTIC FAILURE ON COMPONENT B8 (80h-FFh)" : 0x40B8,
  "DIAGNOSTIC FAILURE ON COMPONENT B9 (80h-FFh)" : 0x40B9,
  "DIAGNOSTIC FAILURE ON COMPONENT BA (80h-FFh)" : 0x40BA,
  "DIAGNOSTIC FAILURE ON COMPONENT BB (80h-FFh)" : 0x40BB,
  "DIAGNOSTIC FAILURE ON COMPONENT BC (80h-FFh)" : 0x40BC,
  "DIAGNOSTIC FAILURE ON COMPONENT BD (80h-FFh)" : 0x40BD,
  "DIAGNOSTIC FAILURE ON COMPONENT BE (80h-FFh)" : 0x40BE,
  "DIAGNOSTIC FAILURE ON COMPONENT BF (80h-FFh)" : 0x40BF,
  "DIAGNOSTIC FAILURE ON COMPONENT C0 (80h-FFh)" : 0x40C0,
  "DIAGNOSTIC FAILURE ON COMPONENT C1 (80h-FFh)" : 0x40C1,
  "DIAGNOSTIC FAILURE ON COMPONENT C2 (80h-FFh)" : 0x40C2,
  "DIAGNOSTIC FAILURE ON COMPONENT C3 (80h-FFh)" : 0x40C3,
  "DIAGNOSTIC FAILURE ON COMPONENT C4 (80h-FFh)" : 0x40C4,
  "DIAGNOSTIC FAILURE ON COMPONENT C5 (80h-FFh)" : 0x40C5,
  "DIAGNOSTIC FAILURE ON COMPONENT C6 (80h-FFh)" : 0x40C6,
  "DIAGNOSTIC FAILURE ON COMPONENT C7 (80h-FFh)" : 0x40C7,
  "DIAGNOSTIC FAILURE ON COMPONENT C8 (80h-FFh)" : 0x40C8,
  "DIAGNOSTIC FAILURE ON COMPONENT C9 (80h-FFh)" : 0x40C9,
  "DIAGNOSTIC FAILURE ON COMPONENT CA (80h-FFh)" : 0x40CA,
  "DIAGNOSTIC FAILURE ON COMPONENT CB (80h-FFh)" : 0x40CB,
  "DIAGNOSTIC FAILURE ON COMPONENT CC (80h-FFh)" : 0x40CC,
  "DIAGNOSTIC FAILURE ON COMPONENT CD (80h-FFh)" : 0x40CD,
  "DIAGNOSTIC FAILURE ON COMPONENT CE (80h-FFh)" : 0x40CE,
  "DIAGNOSTIC FAILURE ON COMPONENT CF (80h-FFh)" : 0x40CF,
  "DIAGNOSTIC FAILURE ON COMPONENT D0 (80h-FFh)" : 0x40D0,
  "DIAGNOSTIC FAILURE ON COMPONENT D1 (80h-FFh)" : 0x40D1,
  "DIAGNOSTIC FAILURE ON COMPONENT D2 (80h-FFh)" : 0x40D2,
  "DIAGNOSTIC FAILURE ON COMPONENT D3 (80h-FFh)" : 0x40D3,
  "DIAGNOSTIC FAILURE ON COMPONENT D4 (80h-FFh)" : 0x40D4,
  "DIAGNOSTIC FAILURE ON COMPONENT D5 (80h-FFh)" : 0x40D5,
  "DIAGNOSTIC FAILURE ON COMPONENT D6 (80h-FFh)" : 0x40D6,
  "DIAGNOSTIC FAILURE ON COMPONENT D7 (80h-FFh)" : 0x40D7,
  "DIAGNOSTIC FAILURE ON COMPONENT D8 (80h-FFh)" : 0x40D8,
  "DIAGNOSTIC FAILURE ON COMPONENT D9 (80h-FFh)" : 0x40D9,
  "DIAGNOSTIC FAILURE ON COMPONENT DA (80h-FFh)" : 0x40DA,
  "DIAGNOSTIC FAILURE ON COMPONENT DB (80h-FFh)" : 0x40DB,
  "DIAGNOSTIC FAILURE ON COMPONENT DC (80h-FFh)" : 0x40DC,
  "DIAGNOSTIC FAILURE ON COMPONENT DD (80h-FFh)" : 0x40DD,
  "DIAGNOSTIC FAILURE ON COMPONENT DE (80h-FFh)" : 0x40DE,
  "DIAGNOSTIC FAILURE ON COMPONENT DF (80h-FFh)" : 0x40DF,
  "DIAGNOSTIC FAILURE ON COMPONENT E0 (80h-FFh)" : 0x40E0,
  "DIAGNOSTIC FAILURE ON COMPONENT E1 (80h-FFh)" : 0x40E1,
  "DIAGNOSTIC FAILURE ON COMPONENT E2 (80h-FFh)" : 0x40E2,
  "DIAGNOSTIC FAILURE ON COMPONENT E3 (80h-FFh)" : 0x40E3,
  "DIAGNOSTIC FAILURE ON COMPONENT E4 (80h-FFh)" : 0x40E4,
  "DIAGNOSTIC FAILURE ON COMPONENT E5 (80h-FFh)" : 0x40E5,
  "DIAGNOSTIC FAILURE ON COMPONENT E6 (80h-FFh)" : 0x40E6,
  "DIAGNOSTIC FAILURE ON COMPONENT E7 (80h-FFh)" : 0x40E7,
  "DIAGNOSTIC FAILURE ON COMPONENT E8 (80h-FFh)" : 0x40E8,
  "DIAGNOSTIC FAILURE ON COMPONENT E9 (80h-FFh)" : 0x40E9,
  "DIAGNOSTIC FAILURE ON COMPONENT EA (80h-FFh)" : 0x40EA,
  "DIAGNOSTIC FAILURE ON COMPONENT EB (80h-FFh)" : 0x40EB,
  "DIAGNOSTIC FAILURE ON COMPONENT EC (80h-FFh)" : 0x40EC,
  "DIAGNOSTIC FAILURE ON COMPONENT ED (80h-FFh)" : 0x40ED,
  "DIAGNOSTIC FAILURE ON COMPONENT EE (80h-FFh)" : 0x40EE,
  "DIAGNOSTIC FAILURE ON COMPONENT EF (80h-FFh)" : 0x40EF,
  "DIAGNOSTIC FAILURE ON COMPONENT F0 (80h-FFh)" : 0x40F0,
  "DIAGNOSTIC FAILURE ON COMPONENT F1 (80h-FFh)" : 0x40F1,
  "DIAGNOSTIC FAILURE ON COMPONENT F2 (80h-FFh)" : 0x40F2,
  "DIAGNOSTIC FAILURE ON COMPONENT F3 (80h-FFh)" : 0x40F3,
  "DIAGNOSTIC FAILURE ON COMPONENT F4 (80h-FFh)" : 0x40F4,
  "DIAGNOSTIC FAILURE ON COMPONENT F5 (80h-FFh)" : 0x40F5,
  "DIAGNOSTIC FAILURE ON COMPONENT F6 (80h-FFh)" : 0x40F6,
  "DIAGNOSTIC FAILURE ON COMPONENT F7 (80h-FFh)" : 0x40F7,
  "DIAGNOSTIC FAILURE ON COMPONENT F8 (80h-FFh)" : 0x40F8,
  "DIAGNOSTIC FAILURE ON COMPONENT F9 (80h-FFh)" : 0x40F9,
  "DIAGNOSTIC FAILURE ON COMPONENT FA (80h-FFh)" : 0x40FA,
  "DIAGNOSTIC FAILURE ON COMPONENT FB (80h-FFh)" : 0x40FB,
  "DIAGNOSTIC FAILURE ON COMPONENT FC (80h-FFh)" : 0x40FC,
  "DIAGNOSTIC FAILURE ON COMPONENT FD (80h-FFh)" : 0x40FD,
  "DIAGNOSTIC FAILURE ON COMPONENT FE (80h-FFh)" : 0x40FE,
  "DIAGNOSTIC FAILURE ON COMPONENT FF (80h-FFh)" : 0x40FF,
  "DATA PATH FAILURE (SHOULD USE 40 NN)" : 0x4100,
  "POWER-ON OR SELF-TEST FAILURE (SHOULD USE 40 NN)" : 0x4200,
  "MESSAGE ERROR" : 0x4300,
  "INTERNAL TARGET FAILURE" : 0x4400,
  "ATA DEVICE FAILED SET FEATURES" : 0x4471,
  "SELECT OR RESELECT FAILURE" : 0x4500,
  "UNSUCCESSFUL SOFT RESET" : 0x4600,
  "SCSI PARITY ERROR" : 0x4700,
  "DATA PHASE CRC ERROR DETECTED" : 0x4701,
  "SCSI PARITY ERROR DETECTED DURING ST DATA PHASE" : 0x4702,
  "INFORMATION UNIT iuCRC ERROR DETECTED" : 0x4703,
  "ASYNCHRONOUS INFORMATION PROTECTION ERROR DETECTED" : 0x4704,
  "PROTOCOL SERVICE CRC ERROR" : 0x4705,
  "PHY TEST FUNCTION IN PROGRESS" : 0x4706,
  "SOME COMMANDS CLEARED BY ISCSI PROTOCOL EVENT" : 0x477F,
  "INITIATOR DETECTED ERROR MESSAGE RECEIVED" : 0x4800,
  "INVALID MESSAGE ERROR" : 0x4900,
  "COMMAND PHASE ERROR" : 0x4A00,
  "DATA PHASE ERROR" : 0x4B00,
  "INVALID TARGET PORT TRANSFER TAG RECEIVED" : 0x4B01,
  "TOO MUCH WRITE DATA" : 0x4B02,
  "ACK/NAK TIMEOUT" : 0x4B03,
  "NAK RECEIVED" : 0x4B04,
  "DATA OFFSET ERROR" : 0x4B05,
  "INITIATOR RESPONSE TIMEOUT" : 0x4B06,
  "LOGICAL UNIT FAILED SELF-CONFIGURATION" : 0x4C00,
  "TAGGED OVERLAPPED COMMANDS (00 = TASK TAG)" : 0x4D00,
  "TAGGED OVERLAPPED COMMANDS (01 = TASK TAG)" : 0x4D01,
  "TAGGED OVERLAPPED COMMANDS (02 = TASK TAG)" : 0x4D02,
  "TAGGED OVERLAPPED COMMANDS (03 = TASK TAG)" : 0x4D03,
  "TAGGED OVERLAPPED COMMANDS (04 = TASK TAG)" : 0x4D04,
  "TAGGED OVERLAPPED COMMANDS (05 = TASK TAG)" : 0x4D05,
  "TAGGED OVERLAPPED COMMANDS (06 = TASK TAG)" : 0x4D06,
  "TAGGED OVERLAPPED COMMANDS (07 = TASK TAG)" : 0x4D07,
  "TAGGED OVERLAPPED COMMANDS (08 = TASK TAG)" : 0x4D08,
  "TAGGED OVERLAPPED COMMANDS (09 = TASK TAG)" : 0x4D09,
  "TAGGED OVERLAPPED COMMANDS (0A = TASK TAG)" : 0x4D0A,
  "TAGGED OVERLAPPED COMMANDS (0B = TASK TAG)" : 0x4D0B,
  "TAGGED OVERLAPPED COMMANDS (0C = TASK TAG)" : 0x4D0C,
  "TAGGED OVERLAPPED COMMANDS (0D = TASK TAG)" : 0x4D0D,
  "TAGGED OVERLAPPED COMMANDS (0E = TASK TAG)" : 0x4D0E,
  "TAGGED OVERLAPPED COMMANDS (0F = TASK TAG)" : 0x4D0F,
  "TAGGED OVERLAPPED COMMANDS (10 = TASK TAG)" : 0x4D10,
  "TAGGED OVERLAPPED COMMANDS (11 = TASK TAG)" : 0x4D11,
  "TAGGED OVERLAPPED COMMANDS (12 = TASK TAG)" : 0x4D12,
  "TAGGED OVERLAPPED COMMANDS (13 = TASK TAG)" : 0x4D13,
  "TAGGED OVERLAPPED COMMANDS (14 = TASK TAG)" : 0x4D14,
  "TAGGED OVERLAPPED COMMANDS (15 = TASK TAG)" : 0x4D15,
  "TAGGED OVERLAPPED COMMANDS (16 = TASK TAG)" : 0x4D16,
  "TAGGED OVERLAPPED COMMANDS (17 = TASK TAG)" : 0x4D17,
  "TAGGED OVERLAPPED COMMANDS (18 = TASK TAG)" : 0x4D18,
  "TAGGED OVERLAPPED COMMANDS (19 = TASK TAG)" : 0x4D19,
  "TAGGED OVERLAPPED COMMANDS (1A = TASK TAG)" : 0x4D1A,
  "TAGGED OVERLAPPED COMMANDS (1B = TASK TAG)" : 0x4D1B,
  "TAGGED OVERLAPPED COMMANDS (1C = TASK TAG)" : 0x4D1C,
  "TAGGED OVERLAPPED COMMANDS (1D = TASK TAG)" : 0x4D1D,
  "TAGGED OVERLAPPED COMMANDS (1E = TASK TAG)" : 0x4D1E,
  "TAGGED OVERLAPPED COMMANDS (1F = TASK TAG)" : 0x4D1F,
  "TAGGED OVERLAPPED COMMANDS (20 = TASK TAG)" : 0x4D20,
  "TAGGED OVERLAPPED COMMANDS (21 = TASK TAG)" : 0x4D21,
  "TAGGED OVERLAPPED COMMANDS (22 = TASK TAG)" : 0x4D22,
  "TAGGED OVERLAPPED COMMANDS (23 = TASK TAG)" : 0x4D23,
  "TAGGED OVERLAPPED COMMANDS (24 = TASK TAG)" : 0x4D24,
  "TAGGED OVERLAPPED COMMANDS (25 = TASK TAG)" : 0x4D25,
  "TAGGED OVERLAPPED COMMANDS (26 = TASK TAG)" : 0x4D26,
  "TAGGED OVERLAPPED COMMANDS (27 = TASK TAG)" : 0x4D27,
  "TAGGED OVERLAPPED COMMANDS (28 = TASK TAG)" : 0x4D28,
  "TAGGED OVERLAPPED COMMANDS (29 = TASK TAG)" : 0x4D29,
  "TAGGED OVERLAPPED COMMANDS (2A = TASK TAG)" : 0x4D2A,
  "TAGGED OVERLAPPED COMMANDS (2B = TASK TAG)" : 0x4D2B,
  "TAGGED OVERLAPPED COMMANDS (2C = TASK TAG)" : 0x4D2C,
  "TAGGED OVERLAPPED COMMANDS (2D = TASK TAG)" : 0x4D2D,
  "TAGGED OVERLAPPED COMMANDS (2E = TASK TAG)" : 0x4D2E,
  "TAGGED OVERLAPPED COMMANDS (2F = TASK TAG)" : 0x4D2F,
  "TAGGED OVERLAPPED COMMANDS (30 = TASK TAG)" : 0x4D30,
  "TAGGED OVERLAPPED COMMANDS (31 = TASK TAG)" : 0x4D31,
  "TAGGED OVERLAPPED COMMANDS (32 = TASK TAG)" : 0x4D32,
  "TAGGED OVERLAPPED COMMANDS (33 = TASK TAG)" : 0x4D33,
  "TAGGED OVERLAPPED COMMANDS (34 = TASK TAG)" : 0x4D34,
  "TAGGED OVERLAPPED COMMANDS (35 = TASK TAG)" : 0x4D35,
  "TAGGED OVERLAPPED COMMANDS (36 = TASK TAG)" : 0x4D36,
  "TAGGED OVERLAPPED COMMANDS (37 = TASK TAG)" : 0x4D37,
  "TAGGED OVERLAPPED COMMANDS (38 = TASK TAG)" : 0x4D38,
  "TAGGED OVERLAPPED COMMANDS (39 = TASK TAG)" : 0x4D39,
  "TAGGED OVERLAPPED COMMANDS (3A = TASK TAG)" : 0x4D3A,
  "TAGGED OVERLAPPED COMMANDS (3B = TASK TAG)" : 0x4D3B,
  "TAGGED OVERLAPPED COMMANDS (3C = TASK TAG)" : 0x4D3C,
  "TAGGED OVERLAPPED COMMANDS (3D = TASK TAG)" : 0x4D3D,
  "TAGGED OVERLAPPED COMMANDS (3E = TASK TAG)" : 0x4D3E,
  "TAGGED OVERLAPPED COMMANDS (3F = TASK TAG)" : 0x4D3F,
  "TAGGED OVERLAPPED COMMANDS (40 = TASK TAG)" : 0x4D40,
  "TAGGED OVERLAPPED COMMANDS (41 = TASK TAG)" : 0x4D41,
  "TAGGED OVERLAPPED COMMANDS (42 = TASK TAG)" : 0x4D42,
  "TAGGED OVERLAPPED COMMANDS (43 = TASK TAG)" : 0x4D43,
  "TAGGED OVERLAPPED COMMANDS (44 = TASK TAG)" : 0x4D44,
  "TAGGED OVERLAPPED COMMANDS (45 = TASK TAG)" : 0x4D45,
  "TAGGED OVERLAPPED COMMANDS (46 = TASK TAG)" : 0x4D46,
  "TAGGED OVERLAPPED COMMANDS (47 = TASK TAG)" : 0x4D47,
  "TAGGED OVERLAPPED COMMANDS (48 = TASK TAG)" : 0x4D48,
  "TAGGED OVERLAPPED COMMANDS (49 = TASK TAG)" : 0x4D49,
  "TAGGED OVERLAPPED COMMANDS (4A = TASK TAG)" : 0x4D4A,
  "TAGGED OVERLAPPED COMMANDS (4B = TASK TAG)" : 0x4D4B,
  "TAGGED OVERLAPPED COMMANDS (4C = TASK TAG)" : 0x4D4C,
  "TAGGED OVERLAPPED COMMANDS (4D = TASK TAG)" : 0x4D4D,
  "TAGGED OVERLAPPED COMMANDS (4E = TASK TAG)" : 0x4D4E,
  "TAGGED OVERLAPPED COMMANDS (4F = TASK TAG)" : 0x4D4F,
  "TAGGED OVERLAPPED COMMANDS (50 = TASK TAG)" : 0x4D50,
  "TAGGED OVERLAPPED COMMANDS (51 = TASK TAG)" : 0x4D51,
  "TAGGED OVERLAPPED COMMANDS (52 = TASK TAG)" : 0x4D52,
  "TAGGED OVERLAPPED COMMANDS (53 = TASK TAG)" : 0x4D53,
  "TAGGED OVERLAPPED COMMANDS (54 = TASK TAG)" : 0x4D54,
  "TAGGED OVERLAPPED COMMANDS (55 = TASK TAG)" : 0x4D55,
  "TAGGED OVERLAPPED COMMANDS (56 = TASK TAG)" : 0x4D56,
  "TAGGED OVERLAPPED COMMANDS (57 = TASK TAG)" : 0x4D57,
  "TAGGED OVERLAPPED COMMANDS (58 = TASK TAG)" : 0x4D58,
  "TAGGED OVERLAPPED COMMANDS (59 = TASK TAG)" : 0x4D59,
  "TAGGED OVERLAPPED COMMANDS (5A = TASK TAG)" : 0x4D5A,
  "TAGGED OVERLAPPED COMMANDS (5B = TASK TAG)" : 0x4D5B,
  "TAGGED OVERLAPPED COMMANDS (5C = TASK TAG)" : 0x4D5C,
  "TAGGED OVERLAPPED COMMANDS (5D = TASK TAG)" : 0x4D5D,
  "TAGGED OVERLAPPED COMMANDS (5E = TASK TAG)" : 0x4D5E,
  "TAGGED OVERLAPPED COMMANDS (5F = TASK TAG)" : 0x4D5F,
  "TAGGED OVERLAPPED COMMANDS (60 = TASK TAG)" : 0x4D60,
  "TAGGED OVERLAPPED COMMANDS (61 = TASK TAG)" : 0x4D61,
  "TAGGED OVERLAPPED COMMANDS (62 = TASK TAG)" : 0x4D62,
  "TAGGED OVERLAPPED COMMANDS (63 = TASK TAG)" : 0x4D63,
  "TAGGED OVERLAPPED COMMANDS (64 = TASK TAG)" : 0x4D64,
  "TAGGED OVERLAPPED COMMANDS (65 = TASK TAG)" : 0x4D65,
  "TAGGED OVERLAPPED COMMANDS (66 = TASK TAG)" : 0x4D66,
  "TAGGED OVERLAPPED COMMANDS (67 = TASK TAG)" : 0x4D67,
  "TAGGED OVERLAPPED COMMANDS (68 = TASK TAG)" : 0x4D68,
  "TAGGED OVERLAPPED COMMANDS (69 = TASK TAG)" : 0x4D69,
  "TAGGED OVERLAPPED COMMANDS (6A = TASK TAG)" : 0x4D6A,
  "TAGGED OVERLAPPED COMMANDS (6B = TASK TAG)" : 0x4D6B,
  "TAGGED OVERLAPPED COMMANDS (6C = TASK TAG)" : 0x4D6C,
  "TAGGED OVERLAPPED COMMANDS (6D = TASK TAG)" : 0x4D6D,
  "TAGGED OVERLAPPED COMMANDS (6E = TASK TAG)" : 0x4D6E,
  "TAGGED OVERLAPPED COMMANDS (6F = TASK TAG)" : 0x4D6F,
  "TAGGED OVERLAPPED COMMANDS (70 = TASK TAG)" : 0x4D70,
  "TAGGED OVERLAPPED COMMANDS (71 = TASK TAG)" : 0x4D71,
  "TAGGED OVERLAPPED COMMANDS (72 = TASK TAG)" : 0x4D72,
  "TAGGED OVERLAPPED COMMANDS (73 = TASK TAG)" : 0x4D73,
  "TAGGED OVERLAPPED COMMANDS (74 = TASK TAG)" : 0x4D74,
  "TAGGED OVERLAPPED COMMANDS (75 = TASK TAG)" : 0x4D75,
  "TAGGED OVERLAPPED COMMANDS (76 = TASK TAG)" : 0x4D76,
  "TAGGED OVERLAPPED COMMANDS (77 = TASK TAG)" : 0x4D77,
  "TAGGED OVERLAPPED COMMANDS (78 = TASK TAG)" : 0x4D78,
  "TAGGED OVERLAPPED COMMANDS (79 = TASK TAG)" : 0x4D79,
  "TAGGED OVERLAPPED COMMANDS (7A = TASK TAG)" : 0x4D7A,
  "TAGGED OVERLAPPED COMMANDS (7B = TASK TAG)" : 0x4D7B,
  "TAGGED OVERLAPPED COMMANDS (7C = TASK TAG)" : 0x4D7C,
  "TAGGED OVERLAPPED COMMANDS (7D = TASK TAG)" : 0x4D7D,
  "TAGGED OVERLAPPED COMMANDS (7E = TASK TAG)" : 0x4D7E,
  "TAGGED OVERLAPPED COMMANDS (7F = TASK TAG)" : 0x4D7F,
  "TAGGED OVERLAPPED COMMANDS (80 = TASK TAG)" : 0x4D80,
  "TAGGED OVERLAPPED COMMANDS (81 = TASK TAG)" : 0x4D81,
  "TAGGED OVERLAPPED COMMANDS (82 = TASK TAG)" : 0x4D82,
  "TAGGED OVERLAPPED COMMANDS (83 = TASK TAG)" : 0x4D83,
  "TAGGED OVERLAPPED COMMANDS (84 = TASK TAG)" : 0x4D84,
  "TAGGED OVERLAPPED COMMANDS (85 = TASK TAG)" : 0x4D85,
  "TAGGED OVERLAPPED COMMANDS (86 = TASK TAG)" : 0x4D86,
  "TAGGED OVERLAPPED COMMANDS (87 = TASK TAG)" : 0x4D87,
  "TAGGED OVERLAPPED COMMANDS (88 = TASK TAG)" : 0x4D88,
  "TAGGED OVERLAPPED COMMANDS (89 = TASK TAG)" : 0x4D89,
  "TAGGED OVERLAPPED COMMANDS (8A = TASK TAG)" : 0x4D8A,
  "TAGGED OVERLAPPED COMMANDS (8B = TASK TAG)" : 0x4D8B,
  "TAGGED OVERLAPPED COMMANDS (8C = TASK TAG)" : 0x4D8C,
  "TAGGED OVERLAPPED COMMANDS (8D = TASK TAG)" : 0x4D8D,
  "TAGGED OVERLAPPED COMMANDS (8E = TASK TAG)" : 0x4D8E,
  "TAGGED OVERLAPPED COMMANDS (8F = TASK TAG)" : 0x4D8F,
  "TAGGED OVERLAPPED COMMANDS (90 = TASK TAG)" : 0x4D90,
  "TAGGED OVERLAPPED COMMANDS (91 = TASK TAG)" : 0x4D91,
  "TAGGED OVERLAPPED COMMANDS (92 = TASK TAG)" : 0x4D92,
  "TAGGED OVERLAPPED COMMANDS (93 = TASK TAG)" : 0x4D93,
  "TAGGED OVERLAPPED COMMANDS (94 = TASK TAG)" : 0x4D94,
  "TAGGED OVERLAPPED COMMANDS (95 = TASK TAG)" : 0x4D95,
  "TAGGED OVERLAPPED COMMANDS (96 = TASK TAG)" : 0x4D96,
  "TAGGED OVERLAPPED COMMANDS (97 = TASK TAG)" : 0x4D97,
  "TAGGED OVERLAPPED COMMANDS (98 = TASK TAG)" : 0x4D98,
  "TAGGED OVERLAPPED COMMANDS (99 = TASK TAG)" : 0x4D99,
  "TAGGED OVERLAPPED COMMANDS (9A = TASK TAG)" : 0x4D9A,
  "TAGGED OVERLAPPED COMMANDS (9B = TASK TAG)" : 0x4D9B,
  "TAGGED OVERLAPPED COMMANDS (9C = TASK TAG)" : 0x4D9C,
  "TAGGED OVERLAPPED COMMANDS (9D = TASK TAG)" : 0x4D9D,
  "TAGGED OVERLAPPED COMMANDS (9E = TASK TAG)" : 0x4D9E,
  "TAGGED OVERLAPPED COMMANDS (9F = TASK TAG)" : 0x4D9F,
  "TAGGED OVERLAPPED COMMANDS (A0 = TASK TAG)" : 0x4DA0,
  "TAGGED OVERLAPPED COMMANDS (A1 = TASK TAG)" : 0x4DA1,
  "TAGGED OVERLAPPED COMMANDS (A2 = TASK TAG)" : 0x4DA2,
  "TAGGED OVERLAPPED COMMANDS (A3 = TASK TAG)" : 0x4DA3,
  "TAGGED OVERLAPPED COMMANDS (A4 = TASK TAG)" : 0x4DA4,
  "TAGGED OVERLAPPED COMMANDS (A5 = TASK TAG)" : 0x4DA5,
  "TAGGED OVERLAPPED COMMANDS (A6 = TASK TAG)" : 0x4DA6,
  "TAGGED OVERLAPPED COMMANDS (A7 = TASK TAG)" : 0x4DA7,
  "TAGGED OVERLAPPED COMMANDS (A8 = TASK TAG)" : 0x4DA8,
  "TAGGED OVERLAPPED COMMANDS (A9 = TASK TAG)" : 0x4DA9,
  "TAGGED OVERLAPPED COMMANDS (AA = TASK TAG)" : 0x4DAA,
  "TAGGED OVERLAPPED COMMANDS (AB = TASK TAG)" : 0x4DAB,
  "TAGGED OVERLAPPED COMMANDS (AC = TASK TAG)" : 0x4DAC,
  "TAGGED OVERLAPPED COMMANDS (AD = TASK TAG)" : 0x4DAD,
  "TAGGED OVERLAPPED COMMANDS (AE = TASK TAG)" : 0x4DAE,
  "TAGGED OVERLAPPED COMMANDS (AF = TASK TAG)" : 0x4DAF,
  "TAGGED OVERLAPPED COMMANDS (B0 = TASK TAG)" : 0x4DB0,
  "TAGGED OVERLAPPED COMMANDS (B1 = TASK TAG)" : 0x4DB1,
  "TAGGED OVERLAPPED COMMANDS (B2 = TASK TAG)" : 0x4DB2,
  "TAGGED OVERLAPPED COMMANDS (B3 = TASK TAG)" : 0x4DB3,
  "TAGGED OVERLAPPED COMMANDS (B4 = TASK TAG)" : 0x4DB4,
  "TAGGED OVERLAPPED COMMANDS (B5 = TASK TAG)" : 0x4DB5,
  "TAGGED OVERLAPPED COMMANDS (B6 = TASK TAG)" : 0x4DB6,
  "TAGGED OVERLAPPED COMMANDS (B7 = TASK TAG)" : 0x4DB7,
  "TAGGED OVERLAPPED COMMANDS (B8 = TASK TAG)" : 0x4DB8,
  "TAGGED OVERLAPPED COMMANDS (B9 = TASK TAG)" : 0x4DB9,
  "TAGGED OVERLAPPED COMMANDS (BA = TASK TAG)" : 0x4DBA,
  "TAGGED OVERLAPPED COMMANDS (BB = TASK TAG)" : 0x4DBB,
  "TAGGED OVERLAPPED COMMANDS (BC = TASK TAG)" : 0x4DBC,
  "TAGGED OVERLAPPED COMMANDS (BD = TASK TAG)" : 0x4DBD,
  "TAGGED OVERLAPPED COMMANDS (BE = TASK TAG)" : 0x4DBE,
  "TAGGED OVERLAPPED COMMANDS (BF = TASK TAG)" : 0x4DBF,
  "TAGGED OVERLAPPED COMMANDS (C0 = TASK TAG)" : 0x4DC0,
  "TAGGED OVERLAPPED COMMANDS (C1 = TASK TAG)" : 0x4DC1,
  "TAGGED OVERLAPPED COMMANDS (C2 = TASK TAG)" : 0x4DC2,
  "TAGGED OVERLAPPED COMMANDS (C3 = TASK TAG)" : 0x4DC3,
  "TAGGED OVERLAPPED COMMANDS (C4 = TASK TAG)" : 0x4DC4,
  "TAGGED OVERLAPPED COMMANDS (C5 = TASK TAG)" : 0x4DC5,
  "TAGGED OVERLAPPED COMMANDS (C6 = TASK TAG)" : 0x4DC6,
  "TAGGED OVERLAPPED COMMANDS (C7 = TASK TAG)" : 0x4DC7,
  "TAGGED OVERLAPPED COMMANDS (C8 = TASK TAG)" : 0x4DC8,
  "TAGGED OVERLAPPED COMMANDS (C9 = TASK TAG)" : 0x4DC9,
  "TAGGED OVERLAPPED COMMANDS (CA = TASK TAG)" : 0x4DCA,
  "TAGGED OVERLAPPED COMMANDS (CB = TASK TAG)" : 0x4DCB,
  "TAGGED OVERLAPPED COMMANDS (CC = TASK TAG)" : 0x4DCC,
  "TAGGED OVERLAPPED COMMANDS (CD = TASK TAG)" : 0x4DCD,
  "TAGGED OVERLAPPED COMMANDS (CE = TASK TAG)" : 0x4DCE,
  "TAGGED OVERLAPPED COMMANDS (CF = TASK TAG)" : 0x4DCF,
  "TAGGED OVERLAPPED COMMANDS (D0 = TASK TAG)" : 0x4DD0,
  "TAGGED OVERLAPPED COMMANDS (D1 = TASK TAG)" : 0x4DD1,
  "TAGGED OVERLAPPED COMMANDS (D2 = TASK TAG)" : 0x4DD2,
  "TAGGED OVERLAPPED COMMANDS (D3 = TASK TAG)" : 0x4DD3,
  "TAGGED OVERLAPPED COMMANDS (D4 = TASK TAG)" : 0x4DD4,
  "TAGGED OVERLAPPED COMMANDS (D5 = TASK TAG)" : 0x4DD5,
  "TAGGED OVERLAPPED COMMANDS (D6 = TASK TAG)" : 0x4DD6,
  "TAGGED OVERLAPPED COMMANDS (D7 = TASK TAG)" : 0x4DD7,
  "TAGGED OVERLAPPED COMMANDS (D8 = TASK TAG)" : 0x4DD8,
  "TAGGED OVERLAPPED COMMANDS (D9 = TASK TAG)" : 0x4DD9,
  "TAGGED OVERLAPPED COMMANDS (DA = TASK TAG)" : 0x4DDA,
  "TAGGED OVERLAPPED COMMANDS (DB = TASK TAG)" : 0x4DDB,
  "TAGGED OVERLAPPED COMMANDS (DC = TASK TAG)" : 0x4DDC,
  "TAGGED OVERLAPPED COMMANDS (DD = TASK TAG)" : 0x4DDD,
  "TAGGED OVERLAPPED COMMANDS (DE = TASK TAG)" : 0x4DDE,
  "TAGGED OVERLAPPED COMMANDS (DF = TASK TAG)" : 0x4DDF,
  "TAGGED OVERLAPPED COMMANDS (E0 = TASK TAG)" : 0x4DE0,
  "TAGGED OVERLAPPED COMMANDS (E1 = TASK TAG)" : 0x4DE1,
  "TAGGED OVERLAPPED COMMANDS (E2 = TASK TAG)" : 0x4DE2,
  "TAGGED OVERLAPPED COMMANDS (E3 = TASK TAG)" : 0x4DE3,
  "TAGGED OVERLAPPED COMMANDS (E4 = TASK TAG)" : 0x4DE4,
  "TAGGED OVERLAPPED COMMANDS (E5 = TASK TAG)" : 0x4DE5,
  "TAGGED OVERLAPPED COMMANDS (E6 = TASK TAG)" : 0x4DE6,
  "TAGGED OVERLAPPED COMMANDS (E7 = TASK TAG)" : 0x4DE7,
  "TAGGED OVERLAPPED COMMANDS (E8 = TASK TAG)" : 0x4DE8,
  "TAGGED OVERLAPPED COMMANDS (E9 = TASK TAG)" : 0x4DE9,
  "TAGGED OVERLAPPED COMMANDS (EA = TASK TAG)" : 0x4DEA,
  "TAGGED OVERLAPPED COMMANDS (EB = TASK TAG)" : 0x4DEB,
  "TAGGED OVERLAPPED COMMANDS (EC = TASK TAG)" : 0x4DEC,
  "TAGGED OVERLAPPED COMMANDS (ED = TASK TAG)" : 0x4DED,
  "TAGGED OVERLAPPED COMMANDS (EE = TASK TAG)" : 0x4DEE,
  "TAGGED OVERLAPPED COMMANDS (EF = TASK TAG)" : 0x4DEF,
  "TAGGED OVERLAPPED COMMANDS (F0 = TASK TAG)" : 0x4DF0,
  "TAGGED OVERLAPPED COMMANDS (F1 = TASK TAG)" : 0x4DF1,
  "TAGGED OVERLAPPED COMMANDS (F2 = TASK TAG)" : 0x4DF2,
  "TAGGED OVERLAPPED COMMANDS (F3 = TASK TAG)" : 0x4DF3,
  "TAGGED OVERLAPPED COMMANDS (F4 = TASK TAG)" : 0x4DF4,
  "TAGGED OVERLAPPED COMMANDS (F5 = TASK TAG)" : 0x4DF5,
  "TAGGED OVERLAPPED COMMANDS (F6 = TASK TAG)" : 0x4DF6,
  "TAGGED OVERLAPPED COMMANDS (F7 = TASK TAG)" : 0x4DF7,
  "TAGGED OVERLAPPED COMMANDS (F8 = TASK TAG)" : 0x4DF8,
  "TAGGED OVERLAPPED COMMANDS (F9 = TASK TAG)" : 0x4DF9,
  "TAGGED OVERLAPPED COMMANDS (FA = TASK TAG)" : 0x4DFA,
  "TAGGED OVERLAPPED COMMANDS (FB = TASK TAG)" : 0x4DFB,
  "TAGGED OVERLAPPED COMMANDS (FC = TASK TAG)" : 0x4DFC,
  "TAGGED OVERLAPPED COMMANDS (FD = TASK TAG)" : 0x4DFD,
  "TAGGED OVERLAPPED COMMANDS (FE = TASK TAG)" : 0x4DFE,
  "TAGGED OVERLAPPED COMMANDS (FF = TASK TAG)" : 0x4DFF,
  "OVERLAPPED COMMANDS ATTEMPTED" : 0x4E00,
  "reserved_4F00" : 0x4F00,
  "WRITE APPEND ERROR" : 0x5000,
  "WRITE APPEND POSITION ERROR" : 0x5001,
  "POSITION ERROR RELATED TO TIMING" : 0x5002,
  "ERASE FAILURE" : 0x5100,
  "ERASE FAILURE - INCOMPLETE ERASE OPERATION DETECTED" : 0x5101,
  "CARTRIDGE FAULT" : 0x5200,
  "MEDIA LOAD OR EJECT FAILED" : 0x5300,
  "UNLOAD TAPE FAILURE" : 0x5301,
  "MEDIUM REMOVAL PREVENTED" : 0x5302,
  "MEDIUM REMOVAL PREVENTED BY DATA TRANSFER ELEMENT" : 0x5303,
  "MEDIUM THREAD OR UNTHREAD FAILURE" : 0x5304,
  "SCSI TO HOST SYSTEM INTERFACE FAILURE" : 0x5400,
  "SYSTEM RESOURCE FAILURE" : 0x5500,
  "SYSTEM BUFFER FULL" : 0x5501,
  "INSUFFICIENT RESERVATION RESOURCES" : 0x5502,
  "INSUFFICIENT RESOURCES" : 0x5503,
  "INSUFFICIENT REGISTRATION RESOURCES" : 0x5504,
  "INSUFFICIENT ACCESS CONTROL RESOURCES" : 0x5505,
  "AUXILIARY MEMORY OUT OF SPACE" : 0x5506,
  "QUOTA ERROR" : 0x5507,
  "MAXIMUM NUMBER OF SUPPLEMENTAL DECRYPTION KEYS EXCEEDED" : 0x5508,
  "MEDIUM AUXILIARY MEMORY NOT ACCESSIBLE" : 0x5509,
  "DATA CURRENTLY UNAVAILABLE" : 0x550A,
  "reserved_5600" : 0x5600,
  "UNABLE TO RECOVER TABLE-OF-CONTENTS" : 0x5700,
  "GENERATION DOES NOT EXIST" : 0x5800,
  "UPDATED BLOCK READ" : 0x5900,
  "OPERATOR REQUEST OR STATE CHANGE INPUT" : 0x5A00,
  "OPERATOR MEDIUM REMOVAL REQUEST" : 0x5A01,
  "OPERATOR SELECTED WRITE PROTECT" : 0x5A02,
  "OPERATOR SELECTED WRITE PERMIT" : 0x5A03,
  "LOG EXCEPTION" : 0x5B00,
  "THRESHOLD CONDITION MET" : 0x5B01,
  "LOG COUNTER AT MAXIMUM" : 0x5B02,
  "LOG LIST CODES EXHAUSTED" : 0x5B03,
  "RPL STATUS CHANGE" : 0x5C00,
  "SPINDLES SYNCHRONIZED" : 0x5C01,
  "SPINDLES NOT SYNCHRONIZED" : 0x5C02,
  "FAILURE PREDICTION THRESHOLD EXCEEDED" : 0x5D00,
  "MEDIA FAILURE PREDICTION THRESHOLD EXCEEDED" : 0x5D01,
  "LOGICAL UNIT FAILURE PREDICTION THRESHOLD EXCEEDED" : 0x5D02,
  "SPARE AREA EXHAUSTION PREDICTION THRESHOLD EXCEEDED" : 0x5D03,
  "HARDWARE IMPENDING FAILURE GENERAL HARD DRIVE FAILURE" : 0x5D10,
  "HARDWARE IMPENDING FAILURE DRIVE ERROR RATE TOO HIGH" : 0x5D11,
  "HARDWARE IMPENDING FAILURE DATA ERROR RATE TOO HIGH" : 0x5D12,
  "HARDWARE IMPENDING FAILURE SEEK ERROR RATE TOO HIGH" : 0x5D13,
  "HARDWARE IMPENDING FAILURE TOO MANY BLOCK REASSIGNS" : 0x5D14,
  "HARDWARE IMPENDING FAILURE ACCESS TIMES TOO HIGH" : 0x5D15,
  "HARDWARE IMPENDING FAILURE START UNIT TIMES TOO HIGH" : 0x5D16,
  "HARDWARE IMPENDING FAILURE CHANNEL PARAMETRICS" : 0x5D17,
  "HARDWARE IMPENDING FAILURE CONTROLLER DETECTED" : 0x5D18,
  "HARDWARE IMPENDING FAILURE THROUGHPUT PERFORMANCE" : 0x5D19,
  "HARDWARE IMPENDING FAILURE SEEK TIME PERFORMANCE" : 0x5D1A,
  "HARDWARE IMPENDING FAILURE SPIN-UP RETRY COUNT" : 0x5D1B,
  "HARDWARE IMPENDING FAILURE DRIVE CALIBRATION RETRY COUNT" : 0x5D1C,
  "CONTROLLER IMPENDING FAILURE GENERAL HARD DRIVE FAILURE" : 0x5D20,
  "CONTROLLER IMPENDING FAILURE DRIVE ERROR RATE TOO HIGH" : 0x5D21,
  "CONTROLLER IMPENDING FAILURE DATA ERROR RATE TOO HIGH" : 0x5D22,
  "CONTROLLER IMPENDING FAILURE SEEK ERROR RATE TOO HIGH" : 0x5D23,
  "CONTROLLER IMPENDING FAILURE TOO MANY BLOCK REASSIGNS" : 0x5D24,
  "CONTROLLER IMPENDING FAILURE ACCESS TIMES TOO HIGH" : 0x5D25,
  "CONTROLLER IMPENDING FAILURE START UNIT TIMES TOO HIGH" : 0x5D26,
  "CONTROLLER IMPENDING FAILURE CHANNEL PARAMETRICS" : 0x5D27,
  "CONTROLLER IMPENDING FAILURE CONTROLLER DETECTED" : 0x5D28,
  "CONTROLLER IMPENDING FAILURE THROUGHPUT PERFORMANCE" : 0x5D29,
  "CONTROLLER IMPENDING FAILURE SEEK TIME PERFORMANCE" : 0x5D2A,
  "CONTROLLER IMPENDING FAILURE SPIN-UP RETRY COUNT" : 0x5D2B,
  "CONTROLLER IMPENDING FAILURE DRIVE CALIBRATION RETRY COUNT" : 0x5D2C,
  "DATA CHANNEL IMPENDING FAILURE GENERAL HARD DRIVE FAILURE" : 0x5D30,
  "DATA CHANNEL IMPENDING FAILURE DRIVE ERROR RATE TOO HIGH" : 0x5D31,
  "DATA CHANNEL IMPENDING FAILURE DATA ERROR RATE TOO HIGH" : 0x5D32,
  "DATA CHANNEL IMPENDING FAILURE SEEK ERROR RATE TOO HIGH" : 0x5D33,
  "DATA CHANNEL IMPENDING FAILURE TOO MANY BLOCK REASSIGNS" : 0x5D34,
  "DATA CHANNEL IMPENDING FAILURE ACCESS TIMES TOO HIGH" : 0x5D35,
  "DATA CHANNEL IMPENDING FAILURE START UNIT TIMES TOO HIGH" : 0x5D36,
  "DATA CHANNEL IMPENDING FAILURE CHANNEL PARAMETRICS" : 0x5D37,
  "DATA CHANNEL IMPENDING FAILURE CONTROLLER DETECTED" : 0x5D38,
  "DATA CHANNEL IMPENDING FAILURE THROUGHPUT PERFORMANCE" : 0x5D39,
  "DATA CHANNEL IMPENDING FAILURE SEEK TIME PERFORMANCE" : 0x5D3A,
  "DATA CHANNEL IMPENDING FAILURE SPIN-UP RETRY COUNT" : 0x5D3B,
  "DATA CHANNEL IMPENDING FAILURE DRIVE CALIBRATION RETRY COUNT" : 0x5D3C,
  "SERVO IMPENDING FAILURE GENERAL HARD DRIVE FAILURE" : 0x5D40,
  "SERVO IMPENDING FAILURE DRIVE ERROR RATE TOO HIGH" : 0x5D41,
  "SERVO IMPENDING FAILURE DATA ERROR RATE TOO HIGH" : 0x5D42,
  "SERVO IMPENDING FAILURE SEEK ERROR RATE TOO HIGH" : 0x5D43,
  "SERVO IMPENDING FAILURE TOO MANY BLOCK REASSIGNS" : 0x5D44,
  "SERVO IMPENDING FAILURE ACCESS TIMES TOO HIGH" : 0x5D45,
  "SERVO IMPENDING FAILURE START UNIT TIMES TOO HIGH" : 0x5D46,
  "SERVO IMPENDING FAILURE CHANNEL PARAMETRICS" : 0x5D47,
  "SERVO IMPENDING FAILURE CONTROLLER DETECTED" : 0x5D48,
  "SERVO IMPENDING FAILURE THROUGHPUT PERFORMANCE" : 0x5D49,
  "SERVO IMPENDING FAILURE SEEK TIME PERFORMANCE" : 0x5D4A,
  "SERVO IMPENDING FAILURE SPIN-UP RETRY COUNT" : 0x5D4B,
  "SERVO IMPENDING FAILURE DRIVE CALIBRATION RETRY COUNT" : 0x5D4C,
  "SPINDLE IMPENDING FAILURE GENERAL HARD DRIVE FAILURE" : 0x5D50,
  "SPINDLE IMPENDING FAILURE DRIVE ERROR RATE TOO HIGH" : 0x5D51,
  "SPINDLE IMPENDING FAILURE DATA ERROR RATE TOO HIGH" : 0x5D52,
  "SPINDLE IMPENDING FAILURE SEEK ERROR RATE TOO HIGH" : 0x5D53,
  "SPINDLE IMPENDING FAILURE TOO MANY BLOCK REASSIGNS" : 0x5D54,
  "SPINDLE IMPENDING FAILURE ACCESS TIMES TOO HIGH" : 0x5D55,
  "SPINDLE IMPENDING FAILURE START UNIT TIMES TOO HIGH" : 0x5D56,
  "SPINDLE IMPENDING FAILURE CHANNEL PARAMETRICS" : 0x5D57,
  "SPINDLE IMPENDING FAILURE CONTROLLER DETECTED" : 0x5D58,
  "SPINDLE IMPENDING FAILURE THROUGHPUT PERFORMANCE" : 0x5D59,
  "SPINDLE IMPENDING FAILURE SEEK TIME PERFORMANCE" : 0x5D5A,
  "SPINDLE IMPENDING FAILURE SPIN-UP RETRY COUNT" : 0x5D5B,
  "SPINDLE IMPENDING FAILURE DRIVE CALIBRATION RETRY COUNT" : 0x5D5C,
  "FIRMWARE IMPENDING FAILURE GENERAL HARD DRIVE FAILURE" : 0x5D60,
  "FIRMWARE IMPENDING FAILURE DRIVE ERROR RATE TOO HIGH" : 0x5D61,
  "FIRMWARE IMPENDING FAILURE DATA ERROR RATE TOO HIGH" : 0x5D62,
  "FIRMWARE IMPENDING FAILURE SEEK ERROR RATE TOO HIGH" : 0x5D63,
  "FIRMWARE IMPENDING FAILURE TOO MANY BLOCK REASSIGNS" : 0x5D64,
  "FIRMWARE IMPENDING FAILURE ACCESS TIMES TOO HIGH" : 0x5D65,
  "FIRMWARE IMPENDING FAILURE START UNIT TIMES TOO HIGH" : 0x5D66,
  "FIRMWARE IMPENDING FAILURE CHANNEL PARAMETRICS" : 0x5D67,
  "FIRMWARE IMPENDING FAILURE CONTROLLER DETECTED" : 0x5D68,
  "FIRMWARE IMPENDING FAILURE THROUGHPUT PERFORMANCE" : 0x5D69,
  "FIRMWARE IMPENDING FAILURE SEEK TIME PERFORMANCE" : 0x5D6A,
  "FIRMWARE IMPENDING FAILURE SPIN-UP RETRY COUNT" : 0x5D6B,
  "FIRMWARE IMPENDING FAILURE DRIVE CALIBRATION RETRY COUNT" : 0x5D6C,
  "FAILURE PREDICTION THRESHOLD EXCEEDED (FALSE)" : 0x5DFF,
  "LOW POWER CONDITION ON" : 0x5E00,
  "IDLE CONDITION ACTIVATED BY TIMER" : 0x5E01,
  "STANDBY CONDITION ACTIVATED BY TIMER" : 0x5E02,
  "IDLE CONDITION ACTIVATED BY COMMAND" : 0x5E03,
  "STANDBY CONDITION ACTIVATED BY COMMAND" : 0x5E04,
  "POWER STATE CHANGE TO ACTIVE" : 0x5E41,
  "POWER STATE CHANGE TO IDLE" : 0x5E42,
  "POWER STATE CHANGE TO STANDBY" : 0x5E43,
  "POWER STATE CHANGE TO SLEEP" : 0x5E45,
  "POWER STATE CHANGE TO DEVICE CONTROL" : 0x5E47,
  "reserved_5F00" : 0x5F00,
  "LAMP FAILURE" : 0x6000,
  "VIDEO ACQUISITION ERROR" : 0x6100,
  "UNABLE TO ACQUIRE VIDEO" : 0x6101,
  "OUT OF FOCUS" : 0x6102,
  "SCAN HEAD POSITIONING ERROR" : 0x6200,
  "END OF USER AREA ENCOUNTERED ON THIS TRACK" : 0x6300,
  "PACKET DOES NOT FIT IN AVAILABLE SPACE" : 0x6301,
  "ILLEGAL MODE FOR THIS TRACK" : 0x6400,
  "INVALID PACKET SIZE" : 0x6401,
  "VOLTAGE FAULT" : 0x6500,
  "AUTOMATIC DOCUMENT FEEDER COVER UP" : 0x6600,
  "AUTOMATIC DOCUMENT FEEDER LIFT UP" : 0x6601,
  "DOCUMENT JAM IN AUTOMATIC DOCUMENT FEEDER" : 0x6602,
  "DOCUMENT MISS FEED AUTOMATIC IN DOCUMENT FEEDER" : 0x6603,
  "CONFIGURATION FAILURE" : 0x6700,
  "CONFIGURATION OF INCAPABLE LOGICAL UNITS FAILED" : 0x6701,
  "ADD LOGICAL UNIT FAILED" : 0x6702,
  "MODIFICATION OF LOGICAL UNIT FAILED" : 0x6703,
  "EXCHANGE OF LOGICAL UNIT FAILED" : 0x6704,
  "REMOVE OF LOGICAL UNIT FAILED" : 0x6705,
  "ATTACHMENT OF LOGICAL UNIT FAILED" : 0x6706,
  "CREATION OF LOGICAL UNIT FAILED" : 0x6707,
  "ASSIGN FAILURE OCCURRED" : 0x6708,
  "MULTIPLY ASSIGNED LOGICAL UNIT" : 0x6709,
  "SET TARGET PORT GROUPS COMMAND FAILED" : 0x670A,
  "ATA DEVICE FEATURE NOT ENABLED" : 0x670B,
  "LOGICAL UNIT NOT CONFIGURED" : 0x6800,
  "DATA LOSS ON LOGICAL UNIT" : 0x6900,
  "MULTIPLE LOGICAL UNIT FAILURES" : 0x6901,
  "PARITY/DATA MISMATCH" : 0x6902,
  "INFORMATIONAL, REFER TO LOG" : 0x6A00,
  "STATE CHANGE HAS OCCURRED" : 0x6B00,
  "REDUNDANCY LEVEL GOT BETTER" : 0x6B01,
  "REDUNDANCY LEVEL GOT WORSE" : 0x6B02,
  "REBUILD FAILURE OCCURRED" : 0x6C00,
  "RECALCULATE FAILURE OCCURRED" : 0x6D00,
  "COMMAND TO LOGICAL UNIT FAILED" : 0x6E00,
  "COPY PROTECTION KEY EXCHANGE FAILURE - AUTHENTICATION FAILURE" : 0x6F00,
  "COPY PROTECTION KEY EXCHANGE FAILURE - KEY NOT PRESENT" : 0x6F01,
  "COPY PROTECTION KEY EXCHANGE FAILURE - KEY NOT ESTABLISHED" : 0x6F02,
  "READ OF SCRAMBLED SECTOR WITHOUT AUTHENTICATION" : 0x6F03,
  "MEDIA REGION CODE IS MISMATCHED TO LOGICAL UNIT REGION" : 0x6F04,
  "DRIVE REGION MUST BE PERMANENT/REGION RESET COUNT ERROR" : 0x6F05,
  "INSUFFICIENT BLOCK COUNT FOR BINDING NONCE RECORDING" : 0x6F06,
  "CONFLICT IN BINDING NONCE RECORDING" : 0x6F07,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 00" : 0x7000,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 01" : 0x7001,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 02" : 0x7002,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 03" : 0x7003,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 04" : 0x7004,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 05" : 0x7005,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 06" : 0x7006,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 07" : 0x7007,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 08" : 0x7008,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 09" : 0x7009,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 0A" : 0x700A,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 0B" : 0x700B,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 0C" : 0x700C,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 0D" : 0x700D,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 0E" : 0x700E,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 0F" : 0x700F,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 10" : 0x7010,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 11" : 0x7011,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 12" : 0x7012,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 13" : 0x7013,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 14" : 0x7014,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 15" : 0x7015,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 16" : 0x7016,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 17" : 0x7017,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 18" : 0x7018,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 19" : 0x7019,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 1A" : 0x701A,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 1B" : 0x701B,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 1C" : 0x701C,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 1D" : 0x701D,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 1E" : 0x701E,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 1F" : 0x701F,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 20" : 0x7020,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 21" : 0x7021,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 22" : 0x7022,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 23" : 0x7023,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 24" : 0x7024,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 25" : 0x7025,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 26" : 0x7026,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 27" : 0x7027,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 28" : 0x7028,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 29" : 0x7029,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 2A" : 0x702A,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 2B" : 0x702B,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 2C" : 0x702C,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 2D" : 0x702D,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 2E" : 0x702E,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 2F" : 0x702F,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 30" : 0x7030,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 31" : 0x7031,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 32" : 0x7032,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 33" : 0x7033,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 34" : 0x7034,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 35" : 0x7035,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 36" : 0x7036,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 37" : 0x7037,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 38" : 0x7038,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 39" : 0x7039,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 3A" : 0x703A,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 3B" : 0x703B,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 3C" : 0x703C,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 3D" : 0x703D,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 3E" : 0x703E,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 3F" : 0x703F,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 40" : 0x7040,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 41" : 0x7041,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 42" : 0x7042,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 43" : 0x7043,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 44" : 0x7044,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 45" : 0x7045,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 46" : 0x7046,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 47" : 0x7047,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 48" : 0x7048,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 49" : 0x7049,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 4A" : 0x704A,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 4B" : 0x704B,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 4C" : 0x704C,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 4D" : 0x704D,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 4E" : 0x704E,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 4F" : 0x704F,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 50" : 0x7050,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 51" : 0x7051,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 52" : 0x7052,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 53" : 0x7053,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 54" : 0x7054,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 55" : 0x7055,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 56" : 0x7056,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 57" : 0x7057,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 58" : 0x7058,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 59" : 0x7059,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 5A" : 0x705A,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 5B" : 0x705B,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 5C" : 0x705C,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 5D" : 0x705D,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 5E" : 0x705E,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 5F" : 0x705F,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 60" : 0x7060,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 61" : 0x7061,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 62" : 0x7062,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 63" : 0x7063,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 64" : 0x7064,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 65" : 0x7065,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 66" : 0x7066,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 67" : 0x7067,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 68" : 0x7068,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 69" : 0x7069,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 6A" : 0x706A,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 6B" : 0x706B,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 6C" : 0x706C,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 6D" : 0x706D,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 6E" : 0x706E,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 6F" : 0x706F,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 70" : 0x7070,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 71" : 0x7071,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 72" : 0x7072,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 73" : 0x7073,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 74" : 0x7074,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 75" : 0x7075,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 76" : 0x7076,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 77" : 0x7077,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 78" : 0x7078,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 79" : 0x7079,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 7A" : 0x707A,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 7B" : 0x707B,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 7C" : 0x707C,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 7D" : 0x707D,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 7E" : 0x707E,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 7F" : 0x707F,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 80" : 0x7080,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 81" : 0x7081,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 82" : 0x7082,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 83" : 0x7083,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 84" : 0x7084,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 85" : 0x7085,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 86" : 0x7086,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 87" : 0x7087,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 88" : 0x7088,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 89" : 0x7089,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 8A" : 0x708A,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 8B" : 0x708B,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 8C" : 0x708C,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 8D" : 0x708D,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 8E" : 0x708E,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 8F" : 0x708F,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 90" : 0x7090,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 91" : 0x7091,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 92" : 0x7092,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 93" : 0x7093,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 94" : 0x7094,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 95" : 0x7095,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 96" : 0x7096,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 97" : 0x7097,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 98" : 0x7098,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 99" : 0x7099,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 9A" : 0x709A,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 9B" : 0x709B,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 9C" : 0x709C,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 9D" : 0x709D,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 9E" : 0x709E,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF 9F" : 0x709F,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF A0" : 0x70A0,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF A1" : 0x70A1,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF A2" : 0x70A2,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF A3" : 0x70A3,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF A4" : 0x70A4,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF A5" : 0x70A5,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF A6" : 0x70A6,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF A7" : 0x70A7,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF A8" : 0x70A8,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF A9" : 0x70A9,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF AA" : 0x70AA,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF AB" : 0x70AB,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF AC" : 0x70AC,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF AD" : 0x70AD,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF AE" : 0x70AE,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF AF" : 0x70AF,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF B0" : 0x70B0,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF B1" : 0x70B1,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF B2" : 0x70B2,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF B3" : 0x70B3,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF B4" : 0x70B4,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF B5" : 0x70B5,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF B6" : 0x70B6,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF B7" : 0x70B7,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF B8" : 0x70B8,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF B9" : 0x70B9,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF BA" : 0x70BA,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF BB" : 0x70BB,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF BC" : 0x70BC,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF BD" : 0x70BD,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF BE" : 0x70BE,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF BF" : 0x70BF,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF C0" : 0x70C0,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF C1" : 0x70C1,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF C2" : 0x70C2,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF C3" : 0x70C3,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF C4" : 0x70C4,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF C5" : 0x70C5,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF C6" : 0x70C6,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF C7" : 0x70C7,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF C8" : 0x70C8,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF C9" : 0x70C9,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF CA" : 0x70CA,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF CB" : 0x70CB,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF CC" : 0x70CC,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF CD" : 0x70CD,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF CE" : 0x70CE,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF CF" : 0x70CF,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF D0" : 0x70D0,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF D1" : 0x70D1,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF D2" : 0x70D2,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF D3" : 0x70D3,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF D4" : 0x70D4,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF D5" : 0x70D5,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF D6" : 0x70D6,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF D7" : 0x70D7,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF D8" : 0x70D8,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF D9" : 0x70D9,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF DA" : 0x70DA,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF DB" : 0x70DB,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF DC" : 0x70DC,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF DD" : 0x70DD,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF DE" : 0x70DE,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF DF" : 0x70DF,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF E0" : 0x70E0,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF E1" : 0x70E1,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF E2" : 0x70E2,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF E3" : 0x70E3,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF E4" : 0x70E4,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF E5" : 0x70E5,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF E6" : 0x70E6,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF E7" : 0x70E7,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF E8" : 0x70E8,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF E9" : 0x70E9,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF EA" : 0x70EA,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF EB" : 0x70EB,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF EC" : 0x70EC,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF ED" : 0x70ED,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF EE" : 0x70EE,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF EF" : 0x70EF,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF F0" : 0x70F0,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF F1" : 0x70F1,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF F2" : 0x70F2,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF F3" : 0x70F3,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF F4" : 0x70F4,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF F5" : 0x70F5,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF F6" : 0x70F6,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF F7" : 0x70F7,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF F8" : 0x70F8,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF F9" : 0x70F9,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF FA" : 0x70FA,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF FB" : 0x70FB,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF FC" : 0x70FC,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF FD" : 0x70FD,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF FE" : 0x70FE,
  "DECOMPRESSION EXCEPTION SHORT ALGORITHM ID OF FF" : 0x70FF,
  "DECOMPRESSION EXCEPTION LONG ALGORITHM ID" : 0x7100,
  "SESSION FIXATION ERROR" : 0x7200,
  "SESSION FIXATION ERROR WRITING LEAD-IN" : 0x7201,
  "SESSION FIXATION ERROR WRITING LEAD-OUT" : 0x7202,
  "SESSION FIXATION ERROR - INCOMPLETE TRACK IN SESSION" : 0x7203,
  "EMPTY OR PARTIALLY WRITTEN RESERVED TRACK" : 0x7204,
  "NO MORE TRACK RESERVATIONS ALLOWED" : 0x7205,
  "RMZ EXTENSION IS NOT ALLOWED" : 0x7206,
  "NO MORE TEST ZONE EXTENSIONS ARE ALLOWED" : 0x7207,
  "CD CONTROL ERROR" : 0x7300,
  "POWER CALIBRATION AREA ALMOST FULL" : 0x7301,
  "POWER CALIBRATION AREA IS FULL" : 0x7302,
  "POWER CALIBRATION AREA ERROR" : 0x7303,
  "PROGRAM MEMORY AREA UPDATE FAILURE" : 0x7304,
  "PROGRAM MEMORY AREA IS FULL" : 0x7305,
  "RMA/PMA IS ALMOST FULL" : 0x7306,
  "CURRENT POWER CALIBRATION AREA ALMOST FULL" : 0x7310,
  "CURRENT POWER CALIBRATION AREA IS FULL" : 0x7311,
  "RDZ IS FULL" : 0x7317,
  "SECURITY ERROR" : 0x7400,
  "UNABLE TO DECRYPT DATA" : 0x7401,
  "UNENCRYPTED DATA ENCOUNTERED WHILE DECRYPTING" : 0x7402,
  "INCORRECT DATA ENCRYPTION KEY" : 0x7403,
  "CRYPTOGRAPHIC INTEGRITY VALIDATION FAILED" : 0x7404,
  "ERROR DECRYPTING DATA" : 0x7405,
  "UNKNOWN SIGNATURE VERIFICATION KEY" : 0x7406,
  "ENCRYPTION PARAMETERS NOT USEABLE" : 0x7407,
  "DIGITAL SIGNATURE VALIDATION FAILURE" : 0x7408,
  "ENCRYPTION MODE MISMATCH ON READ" : 0x7409,
  "ENCRYPTED BLOCK NOT RAW READ ENABLED" : 0x740A,
  "INCORRECT ENCRYPTION PARAMETERS" : 0x740B,
  "UNABLE TO DECRYPT PARAMETER LIST" : 0x740C,
  "ENCRYPTION ALGORITHM DISABLED" : 0x740D,
  "SA CREATION PARAMETER VALUE INVALID" : 0x7410,
  "SA CREATION PARAMETER VALUE REJECTED" : 0x7411,
  "INVALID SA USAGE" : 0x7412,
  "DATA ENCRYPTION CONFIGURATION PREVENTED" : 0x7421,
  "SA CREATION PARAMETER NOT SUPPORTED" : 0x7430,
  "AUTHENTICATION FAILED" : 0x7440,
  "EXTERNAL DATA ENCRYPTION KEY MANAGER ACCESS ERROR" : 0x7461,
  "EXTERNAL DATA ENCRYPTION KEY MANAGER ERROR" : 0x7462,
  "EXTERNAL DATA ENCRYPTION KEY NOT FOUND" : 0x7463,
  "EXTERNAL DATA ENCRYPTION REQUEST NOT AUTHORIZED" : 0x7464,
  "EXTERNAL DATA ENCRYPTION CONTROL TIMEOUT" : 0x746E,
  "EXTERNAL DATA ENCRYPTION CONTROL ERROR" : 0x746F,
  "LOGICAL UNIT ACCESS NOT AUTHORIZED" : 0x7471,
  "SECURITY CONFLICT IN TRANSLATED DEVICE" : 0x7479,
  "reserved_7500" : 0x7500,
  "reserved_7600" : 0x7600,
  "reserved_7700" : 0x7700,
  "reserved_7800" : 0x7800,
  "reserved_7900" : 0x7900,
  "reserved_7A00" : 0x7A00,
  "reserved_7B00" : 0x7B00,
  "reserved_7C00" : 0x7C00,
  "reserved_7D00" : 0x7D00,
  "reserved_7E00" : 0x7E00,
  "reserved_7F00" : 0x7F00,

    },
    default = Pass,
)
