#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 
# This small app takes the list of T10 Additional Sense Code (ASC)
# data and generates a Struct
"""
Generates the ASC construct from values in the asc-num.txt

This program generates the asc_codes.py modules using data
from the asc-num.txt file in the current directory. The
Additioanal Sense Code (ASC) Struct us used by sense for
displaying the matching ASC text string

Right now this file must be manually downloaded from the 
following location - http://www.t10.org/lists/asc-num.txt

Sample - 
ASC/ASCQ DTLPWROMAEBKVF  Description
-------  --------------  ----------------------------------------------------
00h/00h  DTLPWROMAEBKVF  NO ADDITIONAL SENSE INFORMATION
00h/01h   T              FILEMARK DETECTED

Logic
1. look for the line starting with -----
2. for ever success line, 
  a. if line length > 9 i.e. we have a hex value
  b. combine the two hex values into a 16 but hex value
  c. copy the description (i.e. char 25+)
  d. if there is no description then replace with a 
     'reserved_XXXX' where XXXX is the hex value.

NOTE: 2.d. This is not entirely correct, but I did this so that
      it can be symmetric and can be used to generate the ID from
      the text (sue me!)
       
There is additional logic so that for lines lines such as 
4Dh/NNh  DTLPWROMAEBKVF  TAGGED OVERLAPPED COMMANDS (NN = TASK TAG)
the NN value is exploded into all valus of 00h-FFh and the text
is replaced e.g.
  "TAGGED OVERLAPPED COMMANDS (00 = TASK TAG)" : 0x4D00,
  "TAGGED OVERLAPPED COMMANDS (01 = TASK TAG)" : 0x4D01,
  "TAGGED OVERLAPPED COMMANDS (02 = TASK TAG)" : 0x4D02,
  ...
  "TAGGED OVERLAPPED COMMANDS (FE = TASK TAG)" : 0x4DFE,
  "TAGGED OVERLAPPED COMMANDS (FF = TASK TAG)" : 0x4DFF,
  
NOTE: some NN cases are actually 80h-FFh such as the case of
      40h/NNh  DTLPWROMAEBKVF  DIAGNOSTIC FAILURE ON COMPONENT NN (80h-FFh)
      I don't handle if. It is a problem, add a specific check for 40NN or 
      (80h-FFh)
"""

input_file = "asc-num.txt"
output_file = "asc_codes.py"

# ================= header text for file ======================== 
header = """from construct import *

# set of Additional Sense Code data generated from the asc-num.txt file.
# use generate_asc.py to update these values

additional_sense_code = SymmetricMapping(UBInt16("additional_sense_code"),
       mapping = {
"""

# ================= footer text for file ======================== 
footer = """
    },
    default = Pass,
)
"""

def generateFile():
    # TODO: a proper try and catch around here to catch any exceptions
    
   ifile = open(input_file,"r")
   ofile = open(output_file, "w")

   ofile.write(header)

   valid_data = False
   for line in ifile:
     if valid_data and (len(line) >= 9):
       code = "0x" + line[0:2] + line[4:6]
       if 9 == len(line):
         description = "reserved_%s" % code[2:]
       else:
         description = line.strip()[25:]

         # sometimes there are situations where they
         # use NN to refer to a 0x00-0xFF range
         # we will expand this
       if 0 == code.count('NN'):
           ofile.write("  \"%s\" : %s,\n" % (description, code))
       else:
         for counter in range(0x00,0xFF + 1):
           ofile.write("  \"%s\" : %s,\n" % (
               description.replace('NN', "%02X" % counter), 
               code.replace('NN', "%02X" % counter)))

       # only start reading data once the ----- lineis reached
     if line.startswith("-----"):
        valid_data = True

   ofile.write(footer)
  
   ifile.close()
   ofile.close()

if __name__ == '__main__':
  generateFile() 
