#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 
from construct import *

# set of Additional Sense Code data generated from the stds.txt file.
# use generate_stds.py to update these values

version_descriptor=SymmetricMapping(UBInt16("version_descriptor"),
    mapping = {
  "ADC (no version claimed)" : 0x03C0,
  "ADC ANSI INCITS 403-2005" : 0x03D7,
  "ADC T10/1558-D revision 7" : 0x03D6,
  "ADC T10/1558-D revision 6" : 0x03D5,
  "ADC-2 (no version claimed)" : 0x04A0,
  "ADC-2 ANSI INCITS 441-2008" : 0x04AC,
  "ADC-2 T10/1741-D revision 7" : 0x04A7,
  "ADC-2 T10/1741-D revision 8" : 0x04AA,
  "ADC-3 (no version claimed)" : 0x0500,
  "ADP (no version claimed)" : 0x09C0,
  "ADT (no version claimed)" : 0x09E0,
  "ADT ANSI INCITS 406-2005" : 0x09FD,
  "ADT T10/1557-D revision 14" : 0x09FA,
  "ADT T10/1557-D revision 11" : 0x09F9,
  "ADT-2 (no version claimed)" : 0x0A20,
  "ATA/ATAPI-6 (no version claimed)" : 0x15E0,
  "ATA/ATAPI-6 ANSI INCITS 361-2002" : 0x15FD,
  "ATA/ATAPI-7 (no version claimed)" : 0x1600,
  "ATA/ATAPI-7 ANSI INCITS 397-2005" : 0x161C,
  "ATA/ATAPI-7 T13/1532-D revision 3" : 0x1602,
  "ATA/ATAPI-8 ATA8-AAM Architecture Model (no version claimed)" : 0x1620,
  "ATA/ATAPI-8 ATA8-APT Parallel Transport (no version claimed)" : 0x1621,
  "ATA/ATAPI-8 ATA8-AST Serial Transport (no version claimed)" : 0x1622,
  "ATA/ATAPI-8 ATA8-ACS ATA/ATAPI Command Set (no version claimed)" : 0x1623,
  "BCC (no version claimed)" : 0x0380,
  "EPI (no version claimed)" : 0x0B20,
  "EPI ANSI INCITS TR-23 1999" : 0x0B3C,
  "EPI T10/1134 revision 16" : 0x0B3B,
  "Fast-20 (no version claimed)" : 0x0AC0,
  "Fast-20 ANSI INCITS 277-1996" : 0x0ADC,
  "Fast-20 T10/1071 revision 06" : 0x0ADB,
  "FC 10GFC (no version claimed)" : 0x0EA0,
  "FC 10GFC ISO/IEC 14165-116" : 0x0EA3,
  "FC 10GFC ANSI INCITS 364-2003" : 0x0EA2,
  "FC 10GFC ANSI INCITS 364-2003 with AM1 ANSI INCITS 364/AM1-2007" : 0x0EA6,
  "FC-AL (no version claimed)" : 0x0D40,
  "FC-AL ANSI INCITS 272-1996" : 0x0D5C,
  "FC-AL-2 (no version claimed)" : 0x0D60,
  "FC-AL-2 ANSI INCITS 332-1999 with AM1-2003 & AM2-2006" : 0x0D63,
  "FC-AL-2 ANSI INCITS 332-1999 with Amnd 2 AM2-2006" : 0x0D64,
  "FC-AL-2 ANSI INCITS 332-1999 with Amnd 1 AM1-2003" : 0x0D7D,
  "FC-AL-2 ANSI INCITS 332-1999" : 0x0D7C,
  "FC-AL-2 T11/1133-D revision 7.0" : 0x0D61,
  "FC-DA (no version claimed)" : 0x12E0,
  "FC-DA ANSI INCITS TR-36 2004" : 0x12E8,
  "FC-DA T11/1513-DT revision 3.1" : 0x12E2,
  "FC-DA-2 (no version claimed)" : 0x12C0,
  "FC-FLA (no version claimed)" : 0x1320,
  "FC-FLA ANSI INCITS TR-20 1998" : 0x133C,
  "FC-FLA T11/1235 revision 7" : 0x133B,
  "FC-FS (no version claimed)" : 0x0DA0,
  "FC-FS ANSI INCITS 373-2003" : 0x0DBC,
  "FC-FS T11/1331-D revision 1.2" : 0x0DB7,
  "FC-FS T11/1331-D revision 1.7" : 0x0DB8,
  "FC-FS-2 (no version claimed)" : 0x0E00,
  "FC-FS-2 ANSI INCITS 242-2007 with AM1 ANSI INCITS 242/AM1-2007" : 0x0E03,
  "FC-FS-2 ANSI INCITS 242-2007" : 0x0E02,
  "FC-FS-3 (no version claimed)" : 0x0EE0,
  "FC-LS (no version claimed)" : 0x0E20,
  "FC-LS ANSI INCITS 433-2007" : 0x0E29,
  "FC-LS T11/1620-D revision 1.62" : 0x0E21,
  "FC-LS-2 (no version claimed)" : 0x0F00,
  "FCP (no version claimed)" : 0x08C0,
  "FCP ANSI INCITS 269-1996" : 0x08DC,
  "FCP T10/0993-D revision 12" : 0x08DB,
  "FC-PH (no version claimed)" : 0x0D20,
  "FC-PH ANSI INCITS 230-1994" : 0x0D3B,
  "FC-PH ANSI INCITS 230-1994 with Amnd 1 ANSI INCITS 230/AM1-1996" : 0x0D3C,
  "FC-PH-3 (no version claimed)" : 0x0D80,
  "FC-PH-3 ANSI INCITS 303-1998" : 0x0D9C,
  "FC-PI (no version claimed)" : 0x0DC0,
  "FC-PI ANSI INCITS 352-2002" : 0x0DDC,
  "FC-PI-2 (no version claimed)" : 0x0DE0,
  "FC-PI-2 ANSI INCITS 404-2006" : 0x0DE4,
  "FC-PI-2 T11/1506-D revision 5.0" : 0x0DE2,
  "FC-PI-3 (no version claimed)" : 0x0E60,
  "FC-PI-3 T11/1625-D revision 2.0" : 0x0E62,
  "FC-PI-4 (no version claimed)" : 0x0E80,
  "FC-PI-4 T11/1647-D revision 8.0" : 0x0E82,
  "FC-PI-5 (no version claimed)" : 0x0F20,
  "FC-PLDA (no version claimed)" : 0x1340,
  "FC-PLDA ANSI INCITS TR-19 1998" : 0x135C,
  "FC-PLDA T11/1162 revision 2.1" : 0x135B,
  "FCP-2 (no version claimed)" : 0x0900,
  "FCP-2 ANSI INCITS 350-2003" : 0x0917,
  "FCP-2 T10/1144-D revision 8" : 0x0918,
  "FCP-2 T10/1144-D revision 4" : 0x0901,
  "FCP-2 T10/1144-D revision 7" : 0x0915,
  "FCP-2 T10/1144-D revision 7a" : 0x0916,
  "FCP-3 (no version claimed)" : 0x0A00,
  "FCP-3 ISO/IEC 14776-223" : 0x0A1C,
  "FCP-3 ANSI INCITS 416-2006" : 0x0A11,
  "FCP-3 T10/1560-D revision 4" : 0x0A0F,
  "FCP-3 T10/1560-D revision 3f" : 0x0A07,
  "FCP-4 (no version claimed)" : 0x0A40,
  "FCP-4 T10/1828-D revision 01" : 0x0A42,
  "FC-SP (no version claimed)" : 0x0E40,
  "FC-SP ANSI INCITS 426-2007" : 0x0E45,
  "FC-SP T11/1570-D revision 1.6" : 0x0E42,
  "FC-SP-2 (no version claimed)" : 0x0EC0,
  "FC-Tape (no version claimed)" : 0x1300,
  "FC-Tape ANSI INCITS TR-24 1999" : 0x131C,
  "FC-Tape T11/1315 revision 1.17" : 0x131B,
  "FC-Tape T11/1315 revision 1.16" : 0x1301,
  "IEEE 1394 (no version claimed)" : 0x14A0,
  "ANSI IEEE 1394-1995" : 0x14BD,
  "IEEE 1394a (no version claimed)" : 0x14C0,
  "IEEE 1394b (no version claimed)" : 0x14E0,
  "iSCSI (no version claimed)" : 0x0960,
  "MMC (no version claimed)" : 0x0140,
  "MMC ANSI INCITS 304-1997" : 0x015C,
  "MMC T10/1048-D revision 10a" : 0x015B,
  "MMC-2 (no version claimed)" : 0x0240,
  "MMC-2 ANSI INCITS 333-2000" : 0x025C,
  "MMC-2 T10/1228-D revision 11a" : 0x025B,
  "MMC-2 T10/1228-D revision 11" : 0x0255,
  "MMC-3 (no version claimed)" : 0x02A0,
  "MMC-3 ANSI INCITS 360-2002" : 0x02B8,
  "MMC-3 T10/1363-D revision 10g" : 0x02B6,
  "MMC-3 T10/1363-D revision 9" : 0x02B5,
  "MMC-4 (no version claimed)" : 0x03A0,
  "MMC-4 ANSI INCITS 401-2005" : 0x03BF,
  "MMC-4 T10/1545-D revision 5a" : 0x03B1,
  "MMC-4 T10/1545-D revision 3" : 0x03BD,
  "MMC-4 T10/1545-D revision 3d" : 0x03BE,
  "MMC-5 (no version claimed)" : 0x0420,
  "MMC-5 T10/1675-D revision 04" : 0x0432,
  "MMC-5 ANSI INCITS 430-2007" : 0x0434,
  "MMC-5 T10/1675-D revision 03" : 0x042F,
  "MMC-5 T10/1675-D revision 03b" : 0x0431,
  "MMC-6 (no version claimed)" : 0x04E0,
  "OCRW (no version claimed)" : 0x0280,
  "OCRW ISO/IEC 14776-381" : 0x029E,
  "OSD (no version claimed)" : 0x0340,
  "OSD ANSI INCITS 400-2004" : 0x0356,
  "OSD T10/1355-D revision 10" : 0x0355,
  "OSD T10/1355-D revision 0" : 0x0341,
  "OSD T10/1355-D revision 7a" : 0x0342,
  "OSD T10/1355-D revision 8" : 0x0343,
  "OSD T10/1355-D revision 9" : 0x0344,
  "OSD-2 (no version claimed)" : 0x0440,
  "OSD-2 T10/1729-D revision 4" : 0x0444,
  "OSD-3 (no version claimed)" : 0x0560,
  "RBC (no version claimed)" : 0x0220,
  "RBC ANSI INCITS 330-2000" : 0x023C,
  "RBC T10/1240-D revision 10a" : 0x0238,
  "SAM (no version claimed)" : 0x0020,
  "SAM ANSI INCITS 270-1996" : 0x003C,
  "SAM T10/0994-D revision 18" : 0x003B,
  "SAM-2 (no version claimed)" : 0x0040,
  "SAM-2 ISO/IEC 14776-412" : 0x005E,
  "SAM-2 ANSI INCITS 366-2003" : 0x005C,
  "SAM-2 T10/1157-D revision 24" : 0x0055,
  "SAM-2 T10/1157-D revision 23" : 0x0054,
  "SAM-3 (no version claimed)" : 0x0060,
  "SAM-3 ANSI INCITS 402-2005" : 0x0077,
  "SAM-3 T10/1561-D revision 14" : 0x0076,
  "SAM-3 T10/1561-D revision 7" : 0x0062,
  "SAM-3 T10/1561-D revision 13" : 0x0075,
  "SAM-4 (no version claimed)" : 0x0080,
  "SAM-4 T10/1683-D revision 14" : 0x008B,
  "SAM-4 T10/1683-D revision 13" : 0x0087,
  "SAM-5 (no version claimed)" : 0x00A0,
  "SAS (no version claimed)" : 0x0BE0,
  "SAS ANSI INCITS 376-2003" : 0x0BFD,
  "SAS T10/1562-D revision 05" : 0x0BFC,
  "SAS T10/1562-D revision 01" : 0x0BE1,
  "SAS T10/1562-D revision 03" : 0x0BF5,
  "SAS T10/1562-D revision 04" : 0x0BFA,
  "SAS T10/1562-D revision 04" : 0x0BFB,
  "SAS-1.1 (no version claimed)" : 0x0C00,
  "SAS-1.1 ANSI INCITS 417-2006" : 0x0C11,
  "SAS-1.1 T10/1601-D revision 10" : 0x0C0F,
  "SAS-1.1 T10/1601-D revision 9" : 0x0C07,
  "SAS-2 (no version claimed)" : 0x0C20,
  "SAS-2 T10/1760-D revision 14" : 0x0C23,
  "SAS-2 T10/1760-D revision 15" : 0x0C27,
  "SAS-2.1 (no version claimed)" : 0x0C40,
  "SAT (no version claimed)" : 0x1EA0,
  "SAT ANSI INCITS 431-2007" : 0x1EAD,
  "SAT T10/1711-D revision 9" : 0x1EAB,
  "SAT T10/1711-D revision 8" : 0x1EA7,
  "SAT-2 (no version claimed)" : 0x1EC0,
  "SAT-2 T10/1826-D revision 6" : 0x1EC4,
  "SAT-3 (no version claimed)" : 0x1EE0,
  "SBC (no version claimed)" : 0x0180,
  "SBC ANSI INCITS 306-1998" : 0x019C,
  "SBC T10/0996-D revision 08c" : 0x019B,
  "SBC-2 (no version claimed)" : 0x0320,
  "SBC-2 ISO/IEC 14776-322" : 0x033E,
  "SBC-2 ANSI INCITS 405-2005" : 0x033D,
  "SBC-2 T10/1417-D revision 16" : 0x033B,
  "SBC-2 T10/1417-D revision 5a" : 0x0322,
  "SBC-2 T10/1417-D revision 15" : 0x0324,
  "SBC-3 (no version claimed)" : 0x04C0,
  "SBP-2 (no version claimed)" : 0x08E0,
  "SBP-2 ANSI INCITS 325-1998" : 0x08FC,
  "SBP-2 T10/1155-D revision 04" : 0x08FB,
  "SBP-3 (no version claimed)" : 0x0980,
  "SBP-3 ANSI INCITS 375-2004" : 0x099C,
  "SBP-3 T10/1467-D revision 5" : 0x099B,
  "SBP-3 T10/1467-D revision 1f" : 0x0982,
  "SBP-3 T10/1467-D revision 3" : 0x0994,
  "SBP-3 T10/1467-D revision 4" : 0x099A,
  "SCC (no version claimed)" : 0x0160,
  "SCC ANSI INCITS 276-1997" : 0x017C,
  "SCC T10/1047-D revision 06c" : 0x017B,
  "SCC-2 (no version claimed)" : 0x01E0,
  "SCC-2 ANSI INCITS 318-1998" : 0x01FC,
  "SCC-2 T10/1125-D revision 04" : 0x01FB,
  "SES (no version claimed)" : 0x01C0,
  "SES ANSI INCITS 305-1998" : 0x01DC,
  "SES T10/1212-D revision 08b" : 0x01DB,
  "SES ANSI INCITS 305-1998 w/ Amendment ANSI INCITS.305/AM1-2000" : 0x01DE,
  "SES T10/1212 revision 08b w/ Amendment ANSI INCITS.305/AM1-2000" : 0x01DD,
  "SES-2 (no version claimed)" : 0x03E0,
  "SES-2 T10/1559-D revision 20" : 0x03EB,
  "SES-2 T10/1559-D revision 16" : 0x03E1,
  "SES-2 T10/1559-D revision 19" : 0x03E7,
  "SIP (no version claimed)" : 0x08A0,
  "SIP ANSI INCITS 292-1997" : 0x08BC,
  "SIP T10/0856-D revision 10" : 0x08BB,
  "SMC (no version claimed)" : 0x01A0,
  "SMC ISO/IEC 14776-351" : 0x01BE,
  "SMC ANSI INCITS 314-1998" : 0x01BC,
  "SMC T10/0999-D revision 10a" : 0x01BB,
  "SMC-2 (no version claimed)" : 0x02E0,
  "SMC-2 ANSI INCITS 382-2004" : 0x02FE,
  "SMC-2 T10/1383-D revision 7" : 0x02FD,
  "SMC-2 T10/1383-D revision 5" : 0x02F5,
  "SMC-2 T10/1383-D revision 6" : 0x02FC,
  "SMC-3 (no version claimed)" : 0x0480,
  "SPC (no version claimed)" : 0x0120,
  "SPC ANSI INCITS 301-1997" : 0x013C,
  "SPC T10/0995-D revision 11a" : 0x013B,
  "SPC-2 (no version claimed)" : 0x0260,
  "SPC-2 ISO/IEC 14776-452" : 0x0278,
  "SPC-2 ANSI INCITS 351-2001" : 0x0277,
  "SPC-2 T10/1236-D revision 20" : 0x0276,
  "SPC-2 T10/1236-D revision 12" : 0x0267,
  "SPC-2 T10/1236-D revision 18" : 0x0269,
  "SPC-2 T10/1236-D revision 19" : 0x0275,
  "SPC-3 (no version claimed)" : 0x0300,
  "SPC-3 ANSI INCITS 408-2005" : 0x0314,
  "SPC-3 T10/1416-D revision 23" : 0x0312,
  "SPC-3 T10/1416-D revision 7" : 0x0301,
  "SPC-3 T10/1416-D revision 21" : 0x0307,
  "SPC-3 T10/1416-D revision 22" : 0x030F,
  "SPC-4 (no version claimed)" : 0x0460,
  "SPC-4 T10/1731-D revision 16" : 0x0461,
  "SPI (no version claimed)" : 0x0AA0,
  "SPI ANSI INCITS 253-1995" : 0x0ABA,
  "SPI T10/0855-D revision 15a" : 0x0AB9,
  "SPI ANSI INCITS 253-1995 with SPI Amnd ANSI INCITS 253/AM1-1998" : 0x0ABC,
  "SPI T10/0855-D revision 15a with SPI Amnd revision 3a" : 0x0ABB,
  "SPI-2 (no version claimed)" : 0x0AE0,
  "SPI-2 ANSI INCITS 302-1999" : 0x0AFC,
  "SPI-2 T10/1142-D revision 20b" : 0x0AFB,
  "SPI-3 (no version claimed)" : 0x0B00,
  "SPI-3 ANSI INCITS 336-2000" : 0x0B1C,
  "SPI-3 T10/1302-D revision 14" : 0x0B1A,
  "SPI-3 T10/1302-D revision 10" : 0x0B18,
  "SPI-3 T10/1302-D revision 13a" : 0x0B19,
  "SPI-4 (no version claimed)" : 0x0B40,
  "SPI-4 ANSI INCITS 362-2002" : 0x0B56,
  "SPI-4 T10/1365-D revision 7" : 0x0B54,
  "SPI-4 T10/1365-D revision 9" : 0x0B55,
  "SPI-4 T10/1365-D revision 10" : 0x0B59,
  "SPI-5 (no version claimed)" : 0x0B60,
  "SPI-5 ANSI INCITS 367-2003" : 0x0B7C,
  "SPI-5 T10/1525-D revision 6" : 0x0B7B,
  "SPI-5 T10/1525-D revision 3" : 0x0B79,
  "SPI-5 T10/1525-D revision 5" : 0x0B7A,
  "SPL (no version claimed)" : 0x20A0,
  "SRP (no version claimed)" : 0x0940,
  "SRP ANSI INCITS 365-2002" : 0x095C,
  "SRP T10/1415-D revision 16a" : 0x0955,
  "SRP T10/1415-D revision 10" : 0x0954,
  "SSA-PH2 (no version claimed)" : 0x1360,
  "SSA-PH2 ANSI INCITS 293-1996" : 0x137C,
  "SSA-PH2 T10.1/1145-D revision 09c" : 0x137B,
  "SSA-PH3 (no version claimed)" : 0x1380,
  "SSA-PH3 ANSI INCITS 307-1998" : 0x139C,
  "SSA-PH3 T10.1/1146-D revision 05b" : 0x139B,
  "SSA-S2P (no version claimed)" : 0x0880,
  "SSA-S2P ANSI INCITS 294-1996" : 0x089C,
  "SSA-S2P T10.1/1121-D revision 07b" : 0x089B,
  "SSA-S3P (no version claimed)" : 0x0860,
  "SSA-S3P ANSI INCITS 309-1998" : 0x087C,
  "SSA-S3P T10.1/1051-D revision 05b" : 0x087B,
  "SSA-TL1 (no version claimed)" : 0x0840,
  "SSA-TL1 ANSI INCITS 295-1996" : 0x085C,
  "SSA-TL1 T10.1/0989-D revision 10b" : 0x085B,
  "SSA-TL2 (no version claimed)" : 0x0820,
  "SSA-TL2 ANSI INCITS 308-1998" : 0x083C,
  "SSA-TL2 T10.1/1147-D revision 05b" : 0x083B,
  "SSC (no version claimed)" : 0x0200,
  "SSC ANSI INCITS 335-2000" : 0x021C,
  "SSC T10/0997-D revision 22" : 0x0207,
  "SSC T10/0997-D revision 17" : 0x0201,
  "SSC-2 (no version claimed)" : 0x0360,
  "SSC-2 ANSI INCITS 380-2003" : 0x037D,
  "SSC-2 T10/1434-D revision 9" : 0x0375,
  "SSC-2 T10/1434-D revision 7" : 0x0374,
  "SSC-3 (no version claimed)" : 0x0400,
  "SSC-3 T10/1611-D revision 04a" : 0x0403,
  "SSC-4 (no version claimed)" : 0x0520,
  "SST (no version claimed)" : 0x0920,
  "SST T10/1380-D revision 8b" : 0x0935,
  "UAS (no version claimed)" : 0x1740,
  "Universal Serial Bus Specification, Revision 1.1" : 0x1728,
  "Universal Serial Bus Specification, Revision 2.0" : 0x1729,
  "USB Mass Storage Class Bulk-Only Transport, Revision 1.0" : 0x1730,
  "Version Descriptor Not Supported or No Standard Identified" : 0x0000,

    },
    default = "reserved",
)
