#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 
from construct import *
#===============================================================================
# Exceptions
#===============================================================================

class CommandExceptions(Exception):
    pass

class InvalidCommandOptions(CommandExceptions):
    """A value was passed that is not in the set of command options"""
    pass

#===============================================================================
# Base Classes
#===============================================================================
class SCSICommand(object):
    def getCommand(self,**kw):
        """generates the CDB.
        
        See class documentation for options
        
        Exceptions:
        InvalidCommandOption
        """     
        
        defaults = self._getCommandDefaults()
        
        # check to see if the option is part of defaults
        for key in kw.keys():
            if not defaults.has_key(key):
                # TODO: should this return an explanation
                raise InvalidCommandOptions()
        #now set default values for any unspecified value
        for key in defaults:
            if not kw.has_key(key) and None != defaults[key]:
                kw[key] = defaults[key]
        return self._getCommandStruct().build(Container(**kw))
    
    def _getCommandDefaults(self):
        raise NotImplementedError()
    
    
class SCSIReadCommand(SCSICommand):
     def basic(self,device,raw=False):
         """Performs the basic implementation of the SCSI command
         
         Options:
         raw  - [Bool:False] if True returns a raw response array,
                otherwise returns the response as a Construct. 
                See class definition for specification of the response
         
         """
         # set Trim = True, we only want to return the specific data and no 
         # extra data
         return self.extended(device,self.getCommand(),True, raw)


class SCSIWriteCommand(SCSICommand):
    def basic(self,device, data_buffer, data_length):
        """Basic implementation of the SCSI command using default values"""
        return self.extended(device, 
                             self.getCommand(command_length = data_length),
                             data_buffer, data_length)
    
    def extended(self, device, command, data_buffer, data_length):
        return device.commandOut(command, data_buffer, data_length)
