#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 
from construct import * 
from xiv_xsf.scsy.commands.core import SCSIReadCommand
from xiv_xsf.scsy.utils import ArbitrarySizeUnsignedInteger

class ReadBuffer(SCSIReadCommand):
    #---------------------------------------------------------- Helper Functions
    default_payload = 2**18 # this is nexta centric
    
    def _getCommandDefaults(self):    
        return dict(control=0, operation_code=0x3c, mode=1, command_id=0,
                    command_length = self.default_payload)
    
    def _getCommandStruct(self):
        return Struct("READ_BUFFER_command",
            Const(UBInt8("operation_code"), 0x3c),
            EmbeddedBitStruct(
                Padding(3), # reserved
                Const(Bits("mode", 5), 0x1),
                ),
            UBInt32("command_id"),
            ArbitrarySizeUnsignedInteger(Bytes("command_length", 3), 3), 
            UBInt8("control"),
            )
            
    #-------------------------------------------------------------- Core Methods
    def extended(self,device, command, trim=True, raw=True):
        """SCSI READ_BUFFER command
        
        NOTE: There is no processing of the output so raw is ignored
        """
        return device.commandIn(command,
                         self._getCommandStruct().parse(command).command_length,
                         trim
                         )
