#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 
from xiv_xsf.scsy.scsi_specifications.primary_commands.sense import *


"""
sense_test - sets of test vectors to test output of the sense parser

These vectors have been gather from the internet, some are in posts, 
some are from GPL-2 code, so KEEP THESE IN AN EXTERNAL FILE
""" 

def runTest():
    # test vectors are taken from sg3_utils_1.26/examples/sg_sense_test.c
    testVector1Desc = """-------------------------------------------------------------------------------
 Descriptor format, current;  Sense key: Illegal Request
 Additional sense: Logical unit is in process of becoming ready
  Descriptor type: Sense key specific: Field pointer
    Error in Command byte 3 bit 0
  Descriptor type: Information
    0x01020304aabbccdd
  Descriptor type: Command specific
    0x01020304aabbccdd
 Raw sense data (in hex):
        72 05 04 01 00 00 00 20  02 06 00 00 c8 00 03 00    
        00 0a 80 00 01 02 03 04  aa bb cc dd 01 0a 00 00    
        01 02 03 04 aa bb cc dd
"""
    
    testVector1 = array('B',[ 0x72, 0x5, 0x4, 0x1, 0, 0, 0, 32,
                             0x2, 0x6, 0, 0, 0xc8, 0x0, 0x3, 0,
                             0, 0xa, 0x80, 0, 1, 2, 3, 4, 0xaa, 0xbb, 0xcc, 0xdd,                           
                             1, 0xa, 0, 0, 1, 2, 3, 4,0xaa, 0xbb, 0xcc, 0xdd,
                            ]
    ).tostring()

    testVector2Desc = """-------------------------------------------------------------------------------
 Descriptor format, current;  Sense key: Medium Error
 Additional sense: Logical unit is in process of becoming ready
  Descriptor type: Sense key specific: Actual retry count
    0x0003
  Descriptor type: Information
    0x01020304aabbccdd
  Descriptor type: Command specific
    0x01020304aabbccdd
 Raw sense data (in hex):
        72 03 04 01 00 00 00 20  02 06 00 00 c8 00 03 00    
        00 0a 80 00 01 02 03 04  aa bb cc dd 01 0a 00 00    
        01 02 03 04 aa bb cc dd                             
"""
    
    testVector2 = array('B',[0x72, 0x3, 0x4, 0x1, 0, 0, 0, 32,
                            0x2, 0x6, 0, 0, 0xc8, 0x0, 0x3, 0,
                            0, 0xa, 0x80, 0, 1, 2, 3, 4, 0xaa, 0xbb, 0xcc, 0xdd,
                            1, 0xa, 0, 0, 1, 2, 3, 4, 0xaa, 0xbb, 0xcc, 0xdd
                            ]).tostring()
    testVector3Desc = """-------------------------------------------------------------------------------
 Descriptor format, current;  Sense key: No Sense
 Additional sense: Logical unit is in process of becoming ready
  Descriptor type: Sense key specific: Progress indication: 0 %
 Raw sense data (in hex):
        72 00 04 01 00 00 00 08  02 06 00 00 c8 00 03 00 
"""
                            
    testVector3 = array('B',[0x72, 0x0, 0x4, 0x1, 0, 0, 0, 8,
                            0x2, 0x6, 0, 0, 0xc8, 0x0, 0x3, 0]).tostring()

    testVector4Desc = """-------------------------------------------------------------------------------
 Descriptor format, <<<deferred>>>;  Sense key: Copy Aborted
 Additional sense: Logical unit is in process of becoming ready
  Descriptor type: Sense key specific: Segment pointer
 Relative to start of parameter list, byte 3 bit 0
  Descriptor type: Field replaceable unit
    code=0x55
  Descriptor type: Block commands
    Incorrect Length Indicator (ILI) set
  Descriptor type: Unknown or vendor specific [0x85]
    00 20 33 44 
 Raw sense data (in hex):
        73 0a 04 01 00 00 00 16  02 06 00 00 c8 00 03 00    
        03 02 00 55 05 02 00 20  85 04 00 20 33 44
"""        

  
    testVector4 = array('B',[0x73, 0xa, 0x4, 0x1, 0, 0, 0, 22,
                            0x2, 0x6, 0, 0, 0xc8, 0x0, 0x3, 0,
                            0x3, 0x2, 0, 0x55,
                            0x5, 0x2, 0, 0x20,
                            0x85, 0x4, 0, 0x20, 0x33, 0x44]).tostring()

        # Fixed format, <<<deferred>>>;  Sense key: Illegal Request
        # Additional sense: Logical unit is in process of becoming ready
        #  Info fld=0x11223344 [287454020]  FMK EOM ILI
        #  Sense Key Specific: Error in Command byte 5 bit 7
        # Raw sense data (in hex):
        #        f1 00 f5 11 22 33 44 0a  00 00 00 00 04 01 00 cf    
        #        00 05     
    
    
    testVector5 = array('B',[0xf1, 0, (0xf0 | 0x5), 0x11, 0x22,
                            0x33, 0x44, 0xa,
                            0x0, 0x0, 0, 0, 0x4, 0x1, 0, 0xcf, 0, 5,]).tostring()
        # Descriptor format, current;  Sense key: No Sense
        # Additional sense: Logical unit is in process of becoming ready
        #  Descriptor type: ATA Return
        #    extended=1  error=0x0  sector_count=0x1122
        #    lba=0x887766554433
        #    device=0x1  status=0x2
        # Raw sense data (in hex):
        #        72 00 04 01 00 00 00 0e  09 0c 01 00 11 22 66 33    
        #        77 44 88 55 01 02
    
    testVector6 = array('B',[0x72, 0x0, 0x4, 0x1, 0, 0, 0, 14,
                            0x9, 0xc, 1, 0, 0x11, 0x22, 0x66, 0x33,
                            0x77, 0x44, 0x88, 0x55, 0x1, 0x2]).tostring()

        # Fixed format, <<<deferred>>>;  Sense key: Illegal Request
        # Additional sense: CDB decryption error
        #  Info fld=0x11223344 [287454020]  FMK EOM ILI
        #  Field replaceable unit code: 187
        #  Sense Key Specific: Error in Command byte 2 bit 1
        # Raw sense data (in hex):
        #        f1 00 e5 11 22 33 44 0a  00 00 00 00 24 01 bb c9    
        #        00 02   
           
    testVector7 = array('B',[0xf1, 0, 0xe5, 0x11, 0x22, 0x33, 0x44, 0xa,
                            0x0, 0x0, 0x0, 0x0, 0x24, 0x1, 0xbb,
                            0xc9, 0x0, 0x2]).tostring()
    
    print testVector1Desc
    print sense_data.parse(testVector1)
#    
#    print testVector2Desc
#    print sense_data.parse(testVector2)
#    
#    print testVector3Desc
#    print sense_data.parse(testVector3)

#    print testVector4Desc
#    print sense_data.parse(testVector4)
#    print "".join("0x%02X " % ord(i) for i in sense_data.parse(testVector4).data.sense_data_descriptor[3].vendor_specific)
#    print sense_data.parse(testVector4).data.__dict__
    print sense_data.parse(testVector5)
    print sense_data.parse(testVector6)
    print sense_data.parse(testVector7)
#    

if __name__ == "__main__":
    runTest()
