#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 
from xiv_xsf.scsy.raw.raw_device import *
import fcntl 
from construct import *
from platform import processor
import os
import array

#SCSI_VERSION_2 = 0x02
#DK_PASSTHRU = 0x17
#size of sc_passthrough = 152
#size of ushort = 2
#size of uint = 4
#size of unsigned long long = 8
#size of char * = 4

# structure for HO-UX 11i V2
SC_PASSTHROUGH_CDB_LEN = 64
ushort      = UNInt16
uchar       = Byte
uint        = UNInt32
ulonglong   = UNInt64
cptr        = UNInt32

#taken from /usr/include/scsi.h#sc_passthru
aix_sc_passthrough_powerpc = Struct("AIX_SC_PASSTHROUGH_POWERPC",
    ushort("version"),
    uchar("status_validity"),
    uchar("scsi_bus_status"),
    uchar("adap_status_type"),
    uchar("adapter_status"),
    uchar("adap_set_flags"),
    uchar("add_device_status"),
    
     
    uchar("adap_q_status"),
    uchar("q_tag_mag"),
    uchar("flags"),
    uchar("devflags"),
    uchar("q_flags"),
    Padding(1), # manually do the alignment
    ushort("command_length"),
    
    
    ushort("einval_length"),
    ushort("autosense_length"),
    uint("timeout_value"),
    
    ulonglong("data_length"),
    
    ulonglong("scsi_id"),
    
    ulonglong("lun_id"),
    
    cptr("buffer"),
    cptr("autosense_buffer_ptr"),
    
    Bytes("scsi_cdb",SC_PASSTHROUGH_CDB_LEN),
    
    ulonglong("world_wide_name"),
    
    ulonglong("node_name"),
    
    uint("variable_cdb_len"),
    cptr("variable_cdb_ptr"),
    ulonglong("residual"),
    Value("total_bytes_xfer", lambda ctx: ctx.data_length - ctx.residual),
    )


class Device(RawSCSIDevice):
    SCSI_VERSION_2      = 0x02
    DK_PASSTHRU         = 0x17
    SC_PASSTHROUGH_SIZE = 152
    SCSI_TIMEOUT        = 15
    READ_TRANSFER_TYPE  = 1
    WRITE_TRANSFER_TYPE = 2
    
    
    def __init__(self):
        self.handle = None
    

    def openHandle(self, device_path):
        
        # TODO: get right flags for open
        # TODO: catch file open exceptions
        self.handle = open(device_path,"r")
 
    def closeHandle(self):
        if None != self.handle:
            #os.close(self.handle)
            self.handle.close()
            self.handle = None
        
    def sendRawCommand(self, direction_read, cdb,
                       data_ptr, data_len):
        
        if None == self.handle:
            raise DeviceNotOpen
        
        #CDB as a string
        cdb_len = len(cdb)
        cdb_buffer = cdb + "\00" * (SC_PASSTHROUGH_CDB_LEN-cdb_len)

        sense_buffer = array.array('B',[0] * 252)
        sense_ptr, sense_len = sense_buffer.buffer_info()  
        
        flags  = 0
        if True == direction_read:
            flags = flags | self.READ_TRANSFER_TYPE
        else:
            flags = flags | self.WRITE_TRANSFER_TYPE

        data =  aix_sc_passthrough_powerpc.parse("\x00" * self.SC_PASSTHROUGH_SIZE)   
        assert (len(aix_sc_passthrough_powerpc.build(data)) == self.SC_PASSTHROUGH_SIZE)
        
        data.version                = self.SCSI_VERSION_2
        data.command_length         = cdb_len
        data.scsi_cdb               = cdb_buffer
        data.autosense_length       = sense_len
        data.autosense_buffer_ptr   = sense_ptr
        data.timeout_value          = self.SCSI_TIMEOUT
        data.data_length            = data_len
        data.buffer                 = data_ptr
        data.flags                  = flags
        
        # TODO: add try catch
        # throws an IOError
        # max data length is 1024 bytes - longer will call a segmentation violation
        
        adata = array.array("B",aix_sc_passthrough_powerpc.build(data))
        try:
            resp =  fcntl.ioctl(self.handle,self.DK_PASSTHRU,adata,1)
            response = aix_sc_passthrough_powerpc.parse(adata)
        except IOError as error:
            response = aix_sc_passthrough_powerpc.parse(adata)
            if 2 == response.scsi_bus_status:
                raise SenseReceived(sense_buffer)
            else:
                raise error
        
        return response
      
