#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 
from xiv_xsf.scsy.raw.raw_device import *
import fcntl 
from construct import *
from platform import processor
import os
import array


# structure for HO-UX 11i V2
hpux_sctl_io = AlignedStruct("HPUX_SCTL_IO",
    UNInt32("flags"),
    UNInt32("cdb_length"),
    Bytes("cdb",16),
    UNInt32("data_ptr"),
    UNInt32("data_length"),
    UNInt32("max_msecs"),
    UNInt32("data_xfer"),
    UNInt32("cdb_status"),
    Bytes("sense",256),
    UNInt32("sense_status"),
    Byte("sense_xfer"),
    Bytes("reserved",64),  # reserved
    Value("total_bytes_xfer", lambda ctx: ctx.data_xfer)
    )


class Device(RawSCSIDevice):
    # The following values were taken from
    # /usr/include/sys/scsi/impl/uscsi.h
    SIOC_READ        = 0x00001 
    SIOC_WRITE       = 0x00000 
    
    def __init__(self):
        self.handle = None
    

    def openHandle(self, device_path):
        
        # TODO: get right flags for open
        # TODO: catch file open exceptions
        self.handle = os.open(device_path,os.O_RDONLY,017)
 
    def closeHandle(self):
        if None != self.handle:
            os.close(self.handle)
            self.handle = None
        
    def sendRawCommand(self, direction_read, cdb,
                       data_ptr, data_len):
        
        if None == self.handle:
            raise DeviceNotOpen
        
        #CDB as a string
        cdb_len = len(cdb)
        cdb_buffer = cdb + "\00" * (16-cdb_len)

        flags  = 0
        if True == direction_read:
            flags = flags | self.SIOC_READ
        else:
            flags = flags | self.SIOC_WRITE

        data = hpux_sctl_io.build(Container(
                   flags = flags, 
                   cdb_length = cdb_len, 
                   cdb = cdb_buffer,
                   data_ptr = data_ptr, # P - to data buffer
                   data_length = data_len, # i
                   max_msecs = SCSI_TIMEOUT, # h - timeout
                   data_xfer = 0, # set on return 
                   cdb_status = 0, # set in response 
                   sense = "\00" * 256,
                   sense_status = 0, # is set in response
                   sense_xfer = 0, # is set in response
                   reserved = "\00" * 64,
                   total_bytes_xfer = 0, # helper function
                   ) )

        # TODO: add try catch
        # throws an IOError
        # max data length is 1024 bytes - longer will call a segmentation violation
        pdata = array.array("B",data)
        resp =  fcntl.ioctl(self.handle,0xC1745316,pdata,1)
        response = hpux_sctl_io.parse(pdata)
        
        if 2 == response.cdb_status:
            raise SenseReceived(response.sense)
        
        return response
      
