#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 
#from construct import *
from xiv_xsf.scsy.raw.api_utils.constants import *


# structure taken from scsi.sg.h
# sg_io_hdr


scsi_hdr_linux_i386 = Struct("scsi_hdr",
     OSInt("interface_id"),     # [i] 'S' for SCSI generic (required) */
     OSInt("dxfer_direction"),  # [i] data transfer direction  */
     Byte("cmd_len"),             # SCSI command length ( <= 16 bytes) */
     Byte("mx_sb_len"),           # max length to write to sbp */
     OSUshort("iovec_count"),      # [i] 0 implies no scatter gather */
     OSUInt("dxfer_lenv"),       # [i] byte count of data transfer */
     OSPointer("dxferp"),           # [i], [*io] points to data transfer memory
                                  #      or scatter gather list */
     OSPointer("cmdp"),             # [i], [*i] points to command to perform */
     OSPointer("sbp"),              # [i], [*o] points to sense_buffer memory */
     OSUInt("timeout"),          # [i] MAX_UINT->no timeout (unit: millisec) */
     OSUInt("flags"),            # [i] 0 -> default, see SG_FLAG... */
     OSInt("pack_id"),          # [i->o] unused internally (normally) */
     OSPointer("usr_ptr"),          # [i->o] unused internally */
     Byte("status"),              # [o] scsi status */
     Byte("masked_status"),       # [o] shifted, masked scsi status */
     Byte("msg_status"),          # [o] messaging level data (optional) */
     Byte("sb_len_wr"),           # [o] byte count actually written to sbp */
     OSUshort("host_status"),      # [o] errors from host adapter */
     OSUshort("driver_status"),    # [o] errors from software driver */
     OSInt("dxfer_len"),        # [o] dxfer_len - actual_transferred */
     OSUInt("duration"),         # [o] time taken by cmd (unit: millisec) */
     OSUInt("info"),             # [o] auxiliary information */
     Value("total_bytes_xfer", lambda ctx: ctx.dxfer_lenv - ctx.dxfer_len),
     )


def testSize(data_length):
    from struct import calcsize
    """
    Confirms that structure size returned by Struct is same as the
    the size calculated by the pack or the known size.
    
    Sizes may change depending on type size of alignment issues
    
    returns True is sizes match
    """
    
    # TODO: this should raise an OS alignment exception
    expected_size =  calcsize("iiBBHIPPPIIiPBBBBHHiII")

    return  bool(data_length == expected_size)

if __name__ == '__main__':
    pass
