#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 
from xiv_xsf.scsy.raw.raw_device import *
from array import *
import struct 
import fcntl 
from construct import *
from platform import processor
from struct import pack

if 'i386' == processor():
  UPInt32 = ULInt32
  SPInt16 = SLInt16
  SPInt32 = SLInt32
else:
  UPInt32 = UBInt32
  SPInt16 = SBInt16
  SPInt32 = SBInt32

sunos_uscsi_cmd32_x86 = Struct("SunOsUSCSI",
    UPInt32("uscsi_flags"),
    SPInt16("uscsi_status"),
    SPInt16("uscsi_timeout"),
    UPInt32("uscsi_cdb"),
    UPInt32("uscsi_bufaddr"),
    SPInt32("uscsi_buflen"),
    SPInt32("uscsi_resid"),
    Byte("uscsi_cdblen"),
    Byte("uscsi_rqlen"),
    Byte("uscsi_rqstatus"),
    Byte("uscsi_rqresid"),
    UPInt32("uscsi_rqbuf"),
    Padding(4),
    Value("total_bytes_xfer", lambda ctx: ctx.uscsi_buflen - ctx.uscsi_resid)
    )

# The following values were taken from

class Device(RawSCSIDevice):
    # The following values were taken from
    # /usr/include/sys/scsi/impl/uscsi.h
    USCSI_RQENABLE   = 0x10000
    USCSI_READ       = 0x00008 
    USCSI_WRITE      = 0x00000 
    
    def __init__(self):
        self.handle = None
    

    def openHandle(self, device_path):
        
        # TODO: get right flags for open
        # TODO: catch file open exceptions
        self.handle = open(device_path,'r')
 
    def closeHandle(self):
        if None != self.handle:
            self.handle.close()
            self.handle = None
        
    def sendRawCommand(self, direction_read, cdb,
                       data_ptr, data_len):
        
        if None == self.handle:
            raise DeviceNotOpen
        
        cdb_buffer = array('B',cdb)
        cdb_ptr, cdb_len = cdb_buffer.buffer_info()

        flags  = self.USCSI_RQENABLE
        if True == direction_read:
            flags = flags | self.USCSI_READ
        else:
            flags = flags | self.USCSI_WRITE
   
        sense_buffer = array('B',[0] * 252)
        sense_ptr, sense_len = sense_buffer.buffer_info()                

        data= sunos_uscsi_cmd32_x86.build(Container(
                   uscsi_flags = flags,  # i - flags
                   uscsi_status = 0, # set on return 
                   uscsi_timeout = SCSI_TIMEOUT, # h - timeout
                   uscsi_cdb = cdb_ptr, # P - to cdb
                   uscsi_bufaddr = data_ptr, # P - to data buffer
                   uscsi_buflen = data_len, # i
                   uscsi_resid = 0, # set in response 
                   uscsi_cdblen = cdb_len, # B - 0 < 16
                   uscsi_rqlen = sense_len, # B - 32
                   uscsi_rqstatus = 0, # is set in response
                   uscsi_rqresid = 0, # is set in response
                   uscsi_rqbuf = sense_ptr, # P - sense buffer
                   total_bytes_xfer = 0, # helper function
                   ) )

        
        # TODO: add try catch
        # throws an IOError
        # max data length is 1024 bytes - longer will call a segmentation violation
        resp =  fcntl.ioctl(self.handle,0x4C9,data)
        
        response = sunos_uscsi_cmd32_x86.parse(resp)
        
        if 2 == response.uscsi_rqstatus:
            raise SenseReceived(sense_buffer)
        
        return response
      
