#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 
""" Selfcontained sets of exmaples for using the scsy packages"""
from construct import *

def getDevicePath():
   import sys

   if len(sys.argv) >= 2:
      return sys.argv[1]
   else:
#    return '/dev/sda'
#    return '/dev/mpath/mpath0'
#    return '/dev/dsk/c1t0d0s0'
#    return '/dev/rdsk/c2t4d0s2'
#    return '/dev/dsk/c1t0d0s0'
    return "\\\\.\\F:"
    # HPUX 11.23 hp2.ps.xiv
    return "/dev/rdsk/c38t8d1"

def list_commands():
    """Determines the dynamic commands callable from device
    
    Will specify if the [B]asic, [E]xtended and get[C]ommand functions
    are available. 
    Does not yet show helper functions
    """
    
    from xiv_xsf.scsy.device import Device
    dev = Device()
    for command in dir(dev):
        if (not command.startswith('_')) and (not command in ['open','close']):
            options = "B"
            if hasattr(getattr(dev,command), 'extended'):
                options = options + "E"
            if hasattr(getattr(dev,command), 'getCommand'):
                options = options + "C"
            print command+"[%s]" % options,
            
def expanded_basic_test():
    """
    Shows how to perform a INQUIRY without the device object
    using the raw device and the Inquiry command
    """
    
    from xiv_xsf.scsy.commands.inquiry import Inquiry
    from xiv_xsf.scsy.raw import RawDevice
    
    device = RawDevice()
    device.openHandle(getDevicePath())
    
    inq = Inquiry()
    basic_response =inq.basic(device, True)  
    print basic_response

def force_sense():
    """
    Sends an invalid INQUIRY CDB to for a check sense
    """
    
    from xiv_xsf.scsy.device import SenseReceived
    
    from xiv_xsf.scsy.commands.inquiry import Inquiry
    from xiv_xsf.scsy.raw import RawDevice
    
    device = RawDevice()
    device.openHandle(getDevicePath())
    
    inq = Inquiry()
    command = inq.getCommand(evpd = False, page_code = 0x83, allocation_length=252)
    try:
        basic_response =inq.extended(device, command,True, True)
        print "Error: Sense was not raised"
    except SenseReceived as e:
        print "Success"
        print "Sense code received:", e.getSense().data.sense_key 

def test_unit_ready():
    from xiv_xsf.scsy.device import Device
    device = Device()
    device.open(getDevicePath())
    print device.testunitready()

def read_capacity():
    from xiv_xsf.scsy.device import Device
    device = Device()
    device.open(getDevicePath())
    print device.readcapacity10()
    print device.readcapacity16()
                
def basic_test():
    from xiv_xsf.scsy.device import Device
    device = Device()
    device.open(getDevicePath())
    response =  device.inquiry()
    print "Vendor  : %s\nProduct : %s\nRevision: %s" % (
       response.vendor_identification,
       response.product_identification,
       response.product_revision_level)
    
def evpd_page_0():
    from xiv_xsf.scsy.device import Device
    device = Device()
    device.open(getDevicePath())
    print list(device.inquiry.evpd00())

def evpd_page_80():
    from xiv_xsf.scsy.device import Device
    device = Device()
    device.open(getDevicePath())
    print device.inquiry.evpd80()

def evpd_page_83():
    from xiv_xsf.scsy.device import Device, SenseReceived
    device = Device()
    try:
        device.open(getDevicePath())
        print device.inquiry.evpd83()
    except IOError as (errno, strerror):
        print "I/O error({0}): {1}".format(errno, strerror)
    except SenseReceived as e:
        print "Unsupported Command:", e.getSense().data.sense_key
    finally:
        device.close()
    
def ascii_info():
    """ ASCII info is not explicitly supported by inquiry. We must do the 
    following:
    1. determine if it is supported by the device
    2. call the command manually with a raw output
    3. parse the response
    """
    
    from xiv_xsf.scsy.device import Device
    from xiv_xsf.scsy.commands.inquiry.vpd import ascii_info
    
    dev = Device()
    
    dev.open(getDevicePath())
    supported_pages = list(dev.inquiry.evpd00())
    
    for page_id in supported_pages:
        if 0x01 <= page_id <= 0x7F:
            print "Querying Page:", page_id
            command = dev.inquiry.getCommand(evpd=True, page_code=page_id, 
                                             allocation_length=252)
            raw_resp = dev.inquiry.extended(command,raw=True, trim=True)
            print ascii_info.parse(raw_resp)

xcli_resp = Struct(
    "XCLI_Response",
    UBInt32("response_length"),
    Peek(GreedyRepeater(Byte("raw_response"))),
    String("response", lambda ctx: min(ctx.response_length,len(ctx.raw_response))),
    Value("is_valid_response", lambda ctx: len(ctx.raw_response) >= ctx.response_length),
    # calculate the real buffer size, i.e. sizeof(int32)+response_length
    Value("required_buffer_size", lambda ctx: 4 + ctx.response_length),
    )
            
def phase9client():
    """manually sends a phase 9 XCLI command"""
    from xiv_xsf.scsy.device import Device, SenseReceived, DeviceNotOpen
    dev = Device()

    try:
        dev.open(getDevicePath())
        device_info = dev.inquiry()
        if (device_info.vendor_identification in ['XIV', 'IBM'] and
            device_info.product_identification in ['2810XIV','NEXTRA'] and
            9 == int(float(device_info.product_revision_level))):
        
            sample_xcli_cmd = '<command id="0" type="system_counters_get">\n'+\
                            '<option name="xiv-mode" value="yes" />\n</command>'

            if True == dev.writebuffer(sample_xcli_cmd, len(sample_xcli_cmd)):
                resp_cdb = dev.readbuffer.getCommand() 
                resp_buf = dev.readbuffer.extended(resp_cdb)
                parsed_response = xcli_resp.parse(resp_buf)

                if parsed_response.is_valid_response:
                    print "\n\n--XCLI response [%d]--\n%s" % (
                                parsed_response.response_length, 
                                parsed_response.response)
                else:
                    print "Buffer too small, correct size is %d" % ( 
                            parsed_response.required_buffer_size)
        else:
            print "This is not a phase 9 nextra device"
    except DeviceNotOpen:
        print "Dough! forgot to open the device"
    except IOError as (errno, strerror):
        print "Caught an I/O error({0}): {1}".format(errno, strerror)
    except SenseReceived as e:
        print "Sense code received:", e.getSense().data.sense_key
    finally:
        dev.close()
                  
def title(title):
  print "\n"* 2
  print "*" * 78
  lt = len(title)
  print "*" * int((76-lt)/2), title, "*" * int((76-lt)/2)
  print "*" * 78
    
if __name__ == "__main__":  
    title("List Commands")
    list_commands()

    title("Basic tests (INQUIRY)")
    basic_test()

    title("Basic tests (INQUIRY) expanded method")
    expanded_basic_test()

    title("ASCII Info")
    ascii_info()

    title("EVPD Page 0")
    evpd_page_0()

    title("EVPD Page 80")
    evpd_page_80()

    title("EVPD Page 83")
    evpd_page_83()

    title("Phase 9 Client")
    phase9client()

    title("Force Check Sense")
    force_sense()
     
    title("Test Unit Ready")
    test_unit_ready() 
     
    title("Read Capacity")
    read_capacity()