#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 
from construct import *

def DocStruct(docstring, name = None, file = None):
    if None == name:
        name = "DocStruct"
    if None == file:
        file = __file__
    return type(name, (Subconstruct,), 
                        {"__doc__" : docstring,
                         "__file__" : file})
#    return DocConstruct(subcon)

#class DocStruct(Subconstruct):
#    def __init__(self,docstring, subcon):
#        self.__doc__ = docstring
#        Subconstruct.__init__(self,subcon)        
#        

class WithDefaults(Adapter):
    def __init__(self, subcon, defaults):
            Adapter.__init__(self, subcon)
            self.defaults = defaults
    def _encode(self, obj, context):
            for k, v in self.defaults.iteritems():
                    if not hasattr(obj, k):
                            setattr(obj, k, v)
            return obj
    def _decode(self, obj, context):
            return obj

class ArbitrarySizeUnsignedInteger(Adapter):
    def __init__(self, subcon, size):
        Adapter.__init__(self, subcon)
        self.size = size
    def _encode(self, obj, context):
        if int(obj) > (2**(self.size * 8)) - 1:
            raise ValueError("%s bits aren't enough to store %s" % (self.size * 8, obj))
        if int(obj) < 0:
            raise ValueError("%s is unsigned" % self.__class__.__name__)
        buffer = list(self._yield_bytes_from_integer(int(obj), self.size))
        buffer.reverse()
        return "".join(buffer)
    def _yield_bytes_from_integer(self, integer, expected_bytes):
        while expected_bytes > 0:
            byte = chr(integer % 256)
            integer = integer >> 8
            expected_bytes -= 1
            yield byte
    def _decode(self, obj, context):
        integer = 0
        for byte in obj:
            integer = integer << 8
            integer += ord(byte)
        return integer
