# **********************************************************
# Copyright 2008 VMware, Inc.  All rights reserved.
# -- VMware Confidential
# **********************************************************/
use strict;
use XML::Simple;
use FindBin qw($RealBin $RealScript);

my $xmlDoc = XMLin("-", keyattr => "", ForceArray => 1, KeepRoot => 1);

# Get command name
my $command = $xmlDoc->{Command}[0]->{Name}[0];

my $opaques = $xmlDoc->{Command}[0]->{ConnectSpec}[0]->{Opaque};

# Get target management system directory
my $scriptDirPath = @{$opaques}[0];
my $outputFilePath = $xmlDoc->{Command}[0]->{OutputFile}[0];

if (not -e $scriptDirPath) {
   die "Invalid management system directory path '$scriptDirPath'. " .
         "Path does not exist.\n";
}

if (not -d $scriptDirPath) {
   die "Invalid management system directory path '$scriptDirPath'. " .
         "Path is not a directory.\n";
}

my $scriptPath = File::Spec->catfile($scriptDirPath, "command.pl");

if (not -e $scriptPath) {
   die "Invalid management system directory '$scriptDirPath'. " .
         "Directory does not contain command.pl script.\n";
}

print "Original input:\n";
print XMLout($xmlDoc, keyattr => "", KeepRoot => 1) . "\n";

shift(@{$opaques});
my $opaque = @{$opaques}[0];
my @lunsToSkip;
my @portsToSkip;

if ($opaque =~ /^skipLunsOnFailover=(.+)/) {
   @lunsToSkip = split(/,/, $1);
   shift(@{$opaques});
} elsif ($opaque =~ /^skipPorts=(.+)/) {
   @portsToSkip = split(/,/, $1);
   shift(@{$opaques});
}

# Filter out LUNs specified in skipLunsOnFailover
if ($command eq "failover" or $command eq "testFailover") {
   if (@lunsToSkip) {
      my %lunsToSkipHash = {};
      foreach my $lunKeyToSkip (@lunsToSkip) {
         $lunsToSkipHash{$lunKeyToSkip} = 1;
      }
      my @finalLunKeys = ();
      foreach my $replicaLunKey (
         @{$xmlDoc->{Command}[0]->{ReplicaLunKeyList}[0]->{ReplicaLunKey}}) {
         if (exists($lunsToSkipHash{$replicaLunKey})) {
            print "Skipping LUN '$replicaLunKey'\n";
         } else {
            push(@finalLunKeys, $replicaLunKey);
         }
      }

      $xmlDoc->{Command}[0]->{ReplicaLunKeyList}[0]->{ReplicaLunKey} = \@finalLunKeys;

      my @finalAccessList = ();
      foreach my $replicaLun (
         @{$xmlDoc->{Command}[0]->{LunAccess}[0]->{ReplicaLun}}) {
         my $key = $replicaLun->{key};
         if (exists($lunsToSkipHash{$key})) {
            print "Removing LUN '$key' from LunAccess List\n";
         } else {
            push(@finalAccessList, $replicaLun);
         }
      }

      $xmlDoc->{Command}[0]->{LunAccess}[0]->{ReplicaLun} = \@finalAccessList;

   }
}

print "Executing $scriptPath with modified input:\n";
print XMLout($xmlDoc, KeepRoot => 1) . "\n";

open(my $scriptInput, "| \"$^X\" \"$scriptPath\"");
XMLout($xmlDoc, KeepRoot => 1, OutputFile => $scriptInput);
close($scriptInput);

# Filter out storage ports specified in skipPorts
if ($command eq "discoverArrays") {
   if (@portsToSkip) {
      my %portsToSkipHash = {};
      foreach my $portId (@portsToSkip) {
         $portsToSkipHash{$portId} = 1;
      }

      my $xmlDoc = XMLin($outputFilePath, keyattr => "", ForceArray => 1, KeepRoot => 1);

      my @arrayNodes = @{$xmlDoc->{Response}[0]->{ArrayList}[0]->{Array}};
      foreach my $arrayNode (@arrayNodes) {
         my @portNodes = @{$arrayNode->{StoragePortList}[0]->{StoragePort}};

         my $i = 0;
         while ($i <= $#portNodes) {
            my $portId = $portNodes[$i]->{id};
            if (exists($portsToSkipHash{$portId})) {
               print "Removing storage port '$portId'\n";
               splice(@portNodes, $i, 1);
            } else {
               ++$i;
            }
         }

         $arrayNode->{StoragePortList}[0]->{StoragePort} = \@portNodes;
      }

      XMLout($xmlDoc, KeepRoot => 1, OutputFile => $outputFilePath);
   }
}
